@@ -32,6 +32,7 @@ PHPExpression::~PHPExpression() {}
 
 phpLexerToken::Vet_t PHPExpression::CreateExpression(const wxString& text)
 {
+    m_exprStartsWithOpenTag = false;
     // Extract the expression at the end of the input text
     std::stack<phpLexerToken::Vet_t> stack;
     phpLexerToken::Vet_t tokens;
@@ -46,7 +47,7 @@ phpLexerToken::Vet_t PHPExpression::CreateExpression(const wxString& text)
         lastToken = token;
         switch(token.type) {
         case kPHP_T_OPEN_TAG:
-            // skip the open tag
+            if(current) current->push_back(token);
             break;
         // the following are tokens that once seen
         // we should start a new expression:
@@ -105,6 +106,13 @@ phpLexerToken::Vet_t PHPExpression::CreateExpression(const wxString& text)
         case kPHP_T_REQUIRE:
         case kPHP_T_REQUIRE_ONCE:
         case kPHP_T_USE:
+        case kPHP_T_INT_CAST:
+        case kPHP_T_DOUBLE_CAST:
+        case kPHP_T_STRING_CAST:
+        case kPHP_T_OBJECT_CAST:
+        case kPHP_T_ARRAY_CAST:
+        case kPHP_T_BOOL_CAST:
+        case kPHP_T_UNSET_CAST:
         case '.':
         case ';':
         case '{':
@@ -116,6 +124,7 @@ phpLexerToken::Vet_t PHPExpression::CreateExpression(const wxString& text)
         case '?':
         case '|':
         case '@':
+        case '<':
             if(current) current->clear();
             break;
         case '(':
@@ -154,7 +163,13 @@ phpLexerToken::Vet_t PHPExpression::CreateExpression(const wxString& text)
         }
     }
 
-    if(current) {
+    if(current && !current->empty()) {
+        if(current->at(0).type == kPHP_T_OPEN_TAG) {
+            if(current->at(0).text == "<?") {
+                m_exprStartsWithOpenTag = true;
+            }
+            current->erase(current->begin());
+        }
         result.swap(*current);
     }
     return result;
@@ -269,12 +284,12 @@ PHPEntityBase::Ptr_t PHPExpression::Resolve(PHPLookupTable& lookpTable, const wx
                     // return the type hint
                     actualType = currentToken->Cast<PHPEntityVariable>()->GetTypeHint();
                 }
-                
+
                 wxString fixedpath;
                 if(!actualType.IsEmpty() && FixReturnValueNamespace(lookpTable, parentToken, actualType, fixedpath)) {
                     actualType.swap(fixedpath);
                 }
-                
+
                 if(!actualType.IsEmpty()) {
                     currentToken = lookpTable.FindScope(actualType);
                 }
@@ -337,13 +352,13 @@ wxString PHPExpression::DoSimplifyExpression(int depth, PHPSourceFile::Ptr_t sou
                 if(!innerClass) return "";
                 firstToken = innerClass->GetFullName(); // Is always in absolute path
                 firstTokenType = kPHP_T_SELF;
-                
+
             } else if(token.type == kPHP_T_STATIC) {
                 // Same as $this: replace it with the current class absolute path
                 if(!innerClass) return "";
                 firstToken = innerClass->GetFullName(); // Is always in absolute path
                 firstTokenType = kPHP_T_STATIC;
-                
+
             } else if(token.type == kPHP_T_VARIABLE) {
                 // the expression being evaluated starts with a variable (e.g. $a->something()->)
                 // in this case, use the current scope ('scope') and replace it with the real type
@@ -434,7 +449,7 @@ wxString PHPExpression::DoSimplifyExpression(int depth, PHPSourceFile::Ptr_t sou
                 // If the first token before the simplication was 'parent'
                 // keyword, we need to carry this over
                 part.m_textType = firstTokenType;
-            } 
+            }
 
             part.m_operator = token.type;
             part.m_operatorText = token.text;
