@@ -71,6 +71,7 @@ wxDEFINE_EVENT(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_OPEN_RESOURCE, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_EDITOR_CONTEXT_MENU, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_FIND_IN_FILES_DISMISSED, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_CMD_FIND_IN_FILES_SHOWING, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_EDITOR_TIP_DWELL_END, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_CMD_RETAG_COMPLETED, wxCommandEvent);
 wxDEFINE_EVENT(wxEVT_NOTIFY_PAGE_CLOSING, wxNotifyEvent);
@@ -131,6 +132,7 @@ wxDEFINE_EVENT(wxEVT_CONTEXT_MENU_VIRTUAL_FOLDER, clContextMenuEvent);
 wxDEFINE_EVENT(wxEVT_CONTEXT_MENU_FILE, clContextMenuEvent);
 wxDEFINE_EVENT(wxEVT_CONTEXT_MENU_PROJECT, clContextMenuEvent);
 wxDEFINE_EVENT(wxEVT_CONTEXT_MENU_WORKSPACE, clContextMenuEvent);
+wxDEFINE_EVENT(wxEVT_CONTEXT_MENU_TAB_LABEL, clContextMenuEvent);
 wxDEFINE_EVENT(wxEVT_CMD_COLOURS_FONTS_UPDATED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_FILE_LOADED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CL_FRAME_TITLE, clCommandEvent); 
@@ -149,3 +151,4 @@ wxDEFINE_EVENT(wxEVT_DND_FILE_DROPPED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_RESTART_CODELITE, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_SHOW_WORKSPACE_TAB, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_SHOW_OUTPUT_TAB, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_PAGE_MODIFIED_UPDATE_UI, clCommandEvent);
