@@ -33,6 +33,7 @@
 #include "procutils.h"
 #include <wx/tokenzr.h>
 #include <map>
+#include <wx/msgdlg.h>
 
 void FileUtils::OpenFileExplorer(const wxString& path)
 {
@@ -107,8 +108,15 @@ void FileUtils::OpenTerminal(const wxString& path)
     cmd = GTKGetTerminal("");
 
 #elif defined(__WXMAC__)
+    strPath = path;
+    if(strPath.Contains(" ")) {
+        strPath.Prepend("\\\"").Append("\\\"");
+    }
     // osascript -e 'tell app "Terminal" to do script "echo hello"'
     cmd << "osascript -e 'tell app \"Terminal\" to do script \"cd " << strPath << "\"'";
+    CL_DEBUG(cmd);
+    ::system(cmd.mb_str(wxConvUTF8).data());
+    return;
 #endif
     if(cmd.IsEmpty()) return;
     ::wxExecute(cmd);
@@ -129,7 +137,8 @@ bool FileUtils::WriteFileContent(const wxFileName& fn, const wxString& content,
 
 bool FileUtils::ReadFileContent(const wxFileName& fn, wxString& data, const wxMBConv& conv)
 {
-    wxFFile file(fn.GetFullPath().GetData(), wxT("rb"));
+    wxString filename = fn.GetFullPath();
+    wxFFile file(filename, wxT("rb"));
     if(file.IsOpened() == false) {
         // Nothing to be done
         return false;
@@ -157,13 +166,17 @@ void FileUtils::OSXOpenDebuggerTerminalAndGetTTY(const wxString& path, wxString&
     tty.Clear();
     wxString command;
     wxString tmpfile;
+    wxString escapedPath = path;
+    if(escapedPath.Contains(" ")) {
+        escapedPath.Prepend("\"").Append("\"");
+    }
     tmpfile << "/tmp/terminal.tty." << ::wxGetProcessId();
-    command << "osascript -e 'tell app \"Terminal\" to do script \"cd " << path << " && tty > " << tmpfile
+    command << "osascript -e 'tell app \"Terminal\" to do script \"tty > " << tmpfile
             << " && clear && sleep 12345\"'";
     CL_DEBUG("Executing: %s", command);
     long res = ::wxExecute(command);
     if(res == 0) {
-        CL_WARNING("Failed to execute command");
+        CL_WARNING("Failed to execute command:\n%s", command);
         return;
     }
 
@@ -187,20 +200,23 @@ void FileUtils::OSXOpenDebuggerTerminalAndGetTTY(const wxString& path, wxString&
         wxString psCommand;
         psCommand << "ps -A -o ppid,command";
         wxString psOutput = ProcUtils::SafeExecuteCommand(psCommand);
+        CL_DEBUG("PS output:\n%s\n", psOutput);
         wxArrayString lines = ::wxStringTokenize(psOutput, "\n", wxTOKEN_STRTOK);
         for(size_t u = 0; u < lines.GetCount(); ++u) {
-            wxString ppidString = lines.Item(u).BeforeFirst(' ');
-            wxString pidCommand = lines.Item(u).AfterFirst(' ');
-            ppidString.Trim().Trim(false);
-            pidCommand.Trim().Trim(false);
-            if(pidCommand.Contains("sleep") && pidCommand.Contains("12345")) {
+            wxString l = lines.Item(u);
+            l.Trim().Trim(false);
+            if(l.Contains("sleep") && l.Contains("12345")) {
                 // we got a match
+                CL_DEBUG("Got a match!");
+                wxString ppidString = l.BeforeFirst(' ');
                 ppidString.ToCLong(&pid);
                 break;
             }
         }
         break;
     }
+    CL_DEBUG("PID is: %d\n", (int)pid);
+    CL_DEBUG("TTY is: %s\n", tty);
 }
 
 void
@@ -208,7 +224,18 @@ FileUtils::OpenSSHTerminal(const wxString& sshClient, const wxString& connectStr
 {
 #ifdef __WXMSW__
     wxString command;
-    command << "cmd /C \"" << sshClient << " -P " << port << " " << connectString << " -pw " << password << "\"";
+    wxFileName putty(sshClient);
+    if(!putty.Exists()) {
+        wxMessageBox(_("Can't launch PuTTY. Don't know where it is ...."), "CodeLite", wxOK | wxCENTER | wxICON_ERROR);
+        return;
+    }
+    
+    wxString puttyClient = putty.GetFullPath();
+    if(puttyClient.Contains(" ")) {
+        puttyClient.Prepend("\"").Append("\"");
+    }
+
+    command << "cmd /C \"" << puttyClient << " -P " << port << " " << connectString << " -pw " << password << "\"";
     ::wxExecute(command, wxEXEC_ASYNC | wxEXEC_HIDE_CONSOLE);
 
 #elif defined(__WXGTK__)
@@ -308,3 +335,34 @@ wxString FileUtils::EncodeURI(const wxString& uri)
     }
     return encoded;
 }
+
+bool FileUtils::FuzzyMatch(const wxString& needle, const wxString& haystack)
+{
+    wxArrayString parts = ::wxStringTokenize(needle, " \t", wxTOKEN_STRTOK);
+    for(size_t i = 0; i < parts.size(); ++i) {
+        wxString pattern = parts.Item(i);
+        pattern = pattern.Lower();
+        wxString lchaystack = haystack.Lower();
+        if(!lchaystack.Contains(pattern)) {
+            return false;
+        }
+    }
+    return true;
+}
+
+bool FileUtils::IsHidden(const wxFileName& filename)
+{
+#ifdef __WXMSW__
+    DWORD dwAttrs = GetFileAttributes(filename.GetFullPath().c_str());
+    if(dwAttrs == INVALID_FILE_ATTRIBUTES) return false;
+    return (dwAttrs & FILE_ATTRIBUTE_HIDDEN) || (filename.GetFullName().StartsWith("."));
+#else
+    // is it enough to test for file name?
+    return filename.GetFullName().StartsWith(".");
+#endif
+}
+
+bool FileUtils::IsHidden(const wxString& filename)
+{
+    return IsHidden(filename);
+}
