@@ -36,6 +36,7 @@
 #include "tag_tree.h"
 #include "istorage.h"
 #include "codelite_exports.h"
+#include "cl_command_event.h"
 
 class ITagsStorage;
 
@@ -51,13 +52,15 @@ class WXDLLIMPEXP_CL ParseRequest : public ThreadRequest
     wxString _file;
     wxString _dbfile;
     wxString _tags;
-    int      _type;
+    int _type;
+    wxArrayString m_definitions;
+    wxArrayString m_includePaths;
 
 public:
-    wxEvtHandler*            _evtHandler;
+    wxEvtHandler* _evtHandler;
     std::vector<std::string> _workspaceFiles;
-    bool                     _quickRetag;
-    int                      _uid;
+    bool _quickRetag;
+    int _uid;
 
 public:
     enum {
@@ -71,40 +74,67 @@ public:
     };
 
 public:
-
     // ctor/dtor
-    ParseRequest(wxEvtHandler *handler) : _type (PR_FILESAVED), _evtHandler(handler), _quickRetag(false), _uid(-1) {}
-    virtual ~ParseRequest() ;
+    ParseRequest(wxEvtHandler* handler)
+        : _type(PR_FILESAVED)
+        , _evtHandler(handler)
+        , _quickRetag(false)
+        , _uid(-1)
+    {
+    }
+    virtual ~ParseRequest();
 
     // accessors
-    void setFile  (const wxString &file     );
-    void setDbFile(const wxString &dbfile   );
-    void setTags  (const wxString &tags     );
 
-    //Getters
-    const wxString& getDbfile() const {
+    void SetDefinitions(const wxArrayString& definitions)
+    {
+        this->m_definitions = definitions;
+    }
+    void SetIncludePaths(const wxArrayString& includePaths)
+    {
+        this->m_includePaths = includePaths;
+    }
+    const wxArrayString& GetDefinitions() const
+    {
+        return m_definitions;
+    }
+    const wxArrayString& GetIncludePaths() const
+    {
+        return m_includePaths;
+    }
+    void setFile(const wxString& file);
+    void setDbFile(const wxString& dbfile);
+    void setTags(const wxString& tags);
+
+    // Getters
+    const wxString& getDbfile() const
+    {
         return _dbfile;
     }
 
-    const wxString& getFile() const {
+    const wxString& getFile() const
+    {
         return _file;
     }
 
-    const wxString& getTags() const {
+    const wxString& getTags() const
+    {
         return _tags;
     }
 
-    void setType(int _type) {
+    void setType(int _type)
+    {
         this->_type = _type;
     }
-    int getType() const {
+    int getType() const
+    {
         return _type;
     }
     // copy ctor
-    ParseRequest(const ParseRequest& rhs) ;
+    ParseRequest(const ParseRequest& rhs);
 
     // assignment operator
-    ParseRequest &operator=(const ParseRequest& rhs);
+    ParseRequest& operator=(const ParseRequest& rhs);
 };
 
 /**
@@ -117,16 +147,17 @@ public:
 class WXDLLIMPEXP_CL ParseThread : public WorkerThread
 {
     friend class ParseThreadST;
-    wxStopWatch                 m_watch;
-    wxArrayString               m_searchPaths;
-    wxArrayString               m_excludePaths;
-    bool                        m_crawlerEnabled;
-
+    wxStopWatch m_watch;
+    wxArrayString m_searchPaths;
+    wxArrayString m_excludePaths;
+    bool m_crawlerEnabled;
+    wxCriticalSection m_cs;
+    
 public:
-    void SetCrawlerEnabeld (bool b                    );
-    void SetSearchPaths    (const wxArrayString &paths, const wxArrayString &exlucdePaths);
-    void GetSearchPaths    (wxArrayString &paths, wxArrayString &excludePaths);
-    bool IsCrawlerEnabled  ();
+    void SetCrawlerEnabeld(bool b);
+    void SetSearchPaths(const wxArrayString& paths, const wxArrayString& exlucdePaths);
+    void GetSearchPaths(wxArrayString& paths, wxArrayString& excludePaths);
+    bool IsCrawlerEnabled();
 private:
     /**
      * Default constructor.
@@ -138,36 +169,36 @@ private:
      */
     virtual ~ParseThread();
 
-    void       DoStoreTags   (const wxString &tags, const wxString &filename, int &count, ITagsStoragePtr db);
-    TagTreePtr DoTreeFromTags(const wxString &tags, int &count);
+    void DoStoreTags(const wxString& tags, const wxString& filename, int& count, ITagsStoragePtr db);
+    TagTreePtr DoTreeFromTags(const wxString& tags, int& count);
     void DoNotifyReady(wxEvtHandler* caller, int requestType);
 
 private:
-
     /**
      * Process request from the editor.
      * \param request the request to process
      */
-    void ProcessRequest(ThreadRequest *request);
+    void ProcessRequest(ThreadRequest* request);
     /**
      * @brief parse include files and retrieve a list of all
      * include files that should be tagged and inserted into
      * the external database
      * @param filename
      */
-    void ParseIncludeFiles(ParseRequest *req, const wxString &filename, ITagsStoragePtr db);
+    void ParseIncludeFiles(ParseRequest* req, const wxString& filename, ITagsStoragePtr db);
 
-    void ProcessSimple            (ParseRequest *req);
-    void ProcessIncludes          (ParseRequest *req);
-    void ProcessParseAndStore     (ParseRequest *req);
-    void ProcessDeleteTagsOfFiles (ParseRequest *req);
-    void ProcessSimpleNoIncludes  (ParseRequest *req);
-    void ProcessIncludeStatements (ParseRequest *req);
-    void ProcessColourRequest     (ParseRequest *req);
-    void GetFileListToParse(const wxString &filename, wxArrayString &arrFiles);
-    void ParseAndStoreFiles(ParseRequest *req, const wxArrayString &arrFiles, int initalCount, ITagsStoragePtr db);
+    void ProcessSimple(ParseRequest* req);
+    void ProcessIncludes(ParseRequest* req);
+    void ProcessParseAndStore(ParseRequest* req);
+    void ProcessDeleteTagsOfFiles(ParseRequest* req);
+    void ProcessSimpleNoIncludes(ParseRequest* req);
+    void ProcessIncludeStatements(ParseRequest* req);
+    void ProcessColourRequest(ParseRequest* req);
+    void ProcessMacroRequest(ParseRequest* req);
+    void GetFileListToParse(const wxString& filename, wxArrayString& arrFiles);
+    void ParseAndStoreFiles(ParseRequest* req, const wxArrayString& arrFiles, int initalCount, ITagsStoragePtr db);
 
-    void FindIncludedFiles(ParseRequest *req, std::set<wxString> *newSet);
+    void FindIncludedFiles(ParseRequest* req, std::set<wxString>* newSet);
 };
 
 class WXDLLIMPEXP_CL ParseThreadST
