@@ -51,7 +51,6 @@ class DbgCmdHandler;
 class DbgCmdCLIHandler;
 class IProcess;
 
-
 typedef std::map<wxString, DbgCmdHandler*> HandlersMap_t;
 
 extern const wxEventType wxEVT_GDB_STOP_DEBUGGER;
@@ -69,6 +68,9 @@ class DbgGdb : public wxEvtHandler, public IDebugger
     bool m_break_at_main;
     bool m_attachedMode;
     bool m_goingDown;
+    bool m_reverseDebugging;
+    wxStringSet_t m_reversableCommands;
+    bool m_isRecording;
 
 public:
     int m_internalBpId;
@@ -104,6 +106,9 @@ public:
 
     const std::vector<BreakpointInfo>& GetBpList() const { return m_bpList; }
 
+    void SetIsRecording(bool isRecording) { this->m_isRecording = isRecording; }
+    bool IsRecording() const { return m_isRecording; }
+
 public:
     DbgGdb();
     virtual ~DbgGdb();
@@ -153,6 +158,10 @@ public:
     virtual bool Jump(wxString filename, int line);
     virtual bool ListRegisters();
     virtual bool UpdateWatch(const wxString& name);
+    virtual void EnableReverseDebugging(bool b);
+    virtual void EnableRecording(bool b);
+    virtual bool IsReverseDebuggingEnabled() const;
+    
     /**
      * @brief restart the debugger (execute 'run')
      * @return true on success, false otherwise
