@@ -37,24 +37,15 @@ class ExternalToolsPlugin : public IPlugin
 {
     clToolBar* m_tb;
     wxEvtHandler* topWin;
-    IProcess* m_process;
     wxMenu* m_parentMenu;
 
 protected:
     void OnSettings(wxCommandEvent& e);
-    void OnLaunchExternalTool(wxCommandEvent& e);
-    void OnLaunchExternalToolUI(wxUpdateUIEvent& e);
-    void OnStopExternalTool(wxCommandEvent& e);
-    void OnStopExternalToolUI(wxUpdateUIEvent& e);
-    void DoLaunchTool(const ToolInfo& ti);
+    void OnShowRunningTools(wxCommandEvent& e);
     void DoRecreateToolbar();
-    bool IsRedirectedToolRunning();
-    void OnProcessEnd(clProcessEvent& event);
-    void OnProcessOutput(clProcessEvent& event);
     void DoCreatePluginMenu();
-    void OnRecreateTB(wxCommandEvent& e);
-    void DoClearNativeToolbarItems(wxToolBar* toolbar);
-    void DoAppendToolsToNativeToolbar(wxToolBar* toolbar);
+    void OnRecreateTB();
+    void OnLaunchExternalTool(wxCommandEvent& e);
 
 public:
     ExternalToolsPlugin(IManager* manager);
