@@ -16,7 +16,7 @@
 static HelpPlugin* thePlugin = NULL;
 
 // Define the plugin entry point
-extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
     if(thePlugin == 0) {
         thePlugin = new HelpPlugin(manager);
@@ -24,17 +24,17 @@ extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
     return thePlugin;
 }
 
-extern "C" EXPORT PluginInfo GetPluginInfo()
+CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
-    PluginInfo info;
+    static PluginInfo info;
     info.SetAuthor(wxT("Eran Ifrah"));
     info.SetName(wxT("HelpPlugin"));
     info.SetDescription(wxT("Provide help based on selected words"));
     info.SetVersion(wxT("v1.0"));
-    return info;
+    return &info;
 }
 
-extern "C" EXPORT int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
+CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
 HelpPlugin::HelpPlugin(IManager* manager)
     : IPlugin(manager)
@@ -151,6 +151,8 @@ wxString HelpPlugin::DoBuildQueryString()
     case FileExtManager::TypeJava:
         language << settings.GetJavaDocset();
         break;
+    default:
+        break;
     }
 
     wxString q;
