@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : LLDBPlugin.cpp
 //
 // -------------------------------------------------------------------------
@@ -66,7 +66,7 @@ static LLDBPlugin* thePlugin = NULL;
     }
 
 // Define the plugin entry point
-extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
     if(thePlugin == 0) {
         thePlugin = new LLDBPlugin(manager);
@@ -74,17 +74,17 @@ extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
     return thePlugin;
 }
 
-extern "C" EXPORT PluginInfo GetPluginInfo()
+CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
-    PluginInfo info;
+    static PluginInfo info;
     info.SetAuthor(wxT("eran"));
     info.SetName(wxT("LLDBDebuggerPlugin"));
     info.SetDescription(_("LLDB Debugger for CodeLite"));
     info.SetVersion(wxT("v1.0"));
-    return info;
+    return &info;
 }
 
-extern "C" EXPORT int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
+CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
 LLDBPlugin::LLDBPlugin(IManager* manager)
     : IPlugin(manager)
@@ -139,9 +139,7 @@ LLDBPlugin::LLDBPlugin(IManager* manager)
     EventNotifier::Get()->Connect(
         wxEVT_DBG_UI_ENABLE_ALL_BREAKPOINTS, clDebugEventHandler(LLDBPlugin::OnDebugEnableAllBreakpoints), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_DBG_UI_DISABLE_ALL_BREAKPOINTS,
-                                  clDebugEventHandler(LLDBPlugin::OnDebugDisableAllBreakpoints),
-                                  NULL,
-                                  this);
+        clDebugEventHandler(LLDBPlugin::OnDebugDisableAllBreakpoints), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_DBG_UI_NEXT_INST, clDebugEventHandler(LLDBPlugin::OnDebugNextInst), NULL, this);
     EventNotifier::Get()->Connect(
         wxEVT_DBG_UI_SHOW_CURSOR, clDebugEventHandler(LLDBPlugin::OnDebugShowCursor), NULL, this);
@@ -197,9 +195,7 @@ void LLDBPlugin::UnPlug()
     EventNotifier::Get()->Disconnect(
         wxEVT_DBG_UI_ENABLE_ALL_BREAKPOINTS, clDebugEventHandler(LLDBPlugin::OnDebugEnableAllBreakpoints), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_DBG_UI_DISABLE_ALL_BREAKPOINTS,
-                                     clDebugEventHandler(LLDBPlugin::OnDebugDisableAllBreakpoints),
-                                     NULL,
-                                     this);
+        clDebugEventHandler(LLDBPlugin::OnDebugDisableAllBreakpoints), NULL, this);
     EventNotifier::Get()->Disconnect(
         wxEVT_DBG_UI_NEXT_INST, clDebugEventHandler(LLDBPlugin::OnDebugNextInst), NULL, this);
     EventNotifier::Get()->Disconnect(
@@ -307,9 +303,8 @@ void LLDBPlugin::OnDebugStart(clDebugEvent& event)
         wxString errMsg;
         ProjectPtr pProject = clCxxWorkspaceST::Get()->FindProjectByName(event.GetProjectName(), errMsg);
         if(!pProject) {
-            ::wxMessageBox(wxString() << _("Could not locate project: ") << event.GetProjectName(),
-                           "LLDB Debugger",
-                           wxICON_ERROR | wxOK | wxCENTER);
+            ::wxMessageBox(wxString() << _("Could not locate project: ") << event.GetProjectName(), "LLDB Debugger",
+                wxICON_ERROR | wxOK | wxCENTER);
             return;
         }
 
@@ -322,9 +317,8 @@ void LLDBPlugin::OnDebugStart(clDebugEvent& event)
 
         BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetProjBuildConf(pProject->GetName(), wxEmptyString);
         if(!bldConf) {
-            ::wxMessageBox(wxString() << _("Could not locate the requested buid configuration"),
-                           "LLDB Debugger",
-                           wxICON_ERROR | wxOK | wxCENTER);
+            ::wxMessageBox(wxString() << _("Could not locate the requested buid configuration"), "LLDB Debugger",
+                wxICON_ERROR | wxOK | wxCENTER);
             return;
         }
 
@@ -348,7 +342,7 @@ void LLDBPlugin::OnDebugStart(clDebugEvent& event)
         }
 
         // Determine the executable to debug, working directory and arguments
-        EnvSetter env(NULL, NULL, pProject ? pProject->GetName() : wxString());
+        EnvSetter env(NULL, NULL, pProject ? pProject->GetName() : wxString(), bldConf->GetName());
         wxString exepath = bldConf->GetCommand();
         wxString args;
         wxString workingDirectory;
@@ -440,7 +434,8 @@ void LLDBPlugin::OnDebugStart(clDebugEvent& event)
                 wxString message;
                 message << _("Could not connect to codelite-lldb at '")
                         << (settings.IsUsingRemoteProxy() ? settings.GetTcpConnectString() :
-                                                            m_connector.GetConnectString()) << "'";
+                                                            m_connector.GetConnectString())
+                        << "'";
                 ::wxMessageBox(message, "CodeLite", wxICON_ERROR | wxOK | wxCENTER);
                 return;
             }
@@ -719,36 +714,45 @@ void LLDBPlugin::DestroyUI()
 
 void LLDBPlugin::InitializeUI()
 {
+    wxWindow* parent = m_mgr->GetDockingManager()->GetManagedWindow();
     if(!m_callstack) {
-        m_callstack = new LLDBCallStackPane(EventNotifier::Get()->TopFrame(), &m_connector);
-        m_mgr->GetDockingManager()->AddPane(
-            m_callstack,
-            wxAuiPaneInfo().MinSize(200, 200).Bottom().Position(0).CloseButton().Caption("Callstack").Name(
-                LLDB_CALLSTACK_PANE_NAME));
+        m_callstack = new LLDBCallStackPane(parent, &m_connector);
+        m_mgr->GetDockingManager()->AddPane(m_callstack, wxAuiPaneInfo()
+                                                             .MinSize(200, 200)
+                                                             .Bottom()
+                                                             .Position(0)
+                                                             .CloseButton()
+                                                             .Caption("Callstack")
+                                                             .Name(LLDB_CALLSTACK_PANE_NAME));
     }
 
     if(!m_breakpointsView) {
-        m_breakpointsView = new LLDBOutputView(EventNotifier::Get()->TopFrame(), this);
-        m_mgr->GetDockingManager()->AddPane(
-            m_breakpointsView,
-            wxAuiPaneInfo().MinSize(200, 200).Bottom().Position(1).CloseButton().Caption("Breakpoints").Name(
-                LLDB_BREAKPOINTS_PANE_NAME));
+        m_breakpointsView = new LLDBOutputView(parent, this);
+        m_mgr->GetDockingManager()->AddPane(m_breakpointsView, wxAuiPaneInfo()
+                                                                   .MinSize(200, 200)
+                                                                   .Bottom()
+                                                                   .Position(1)
+                                                                   .CloseButton()
+                                                                   .Caption("Breakpoints")
+                                                                   .Name(LLDB_BREAKPOINTS_PANE_NAME));
     }
 
     if(!m_localsView) {
-        m_localsView = new LLDBLocalsView(EventNotifier::Get()->TopFrame(), this);
-        m_mgr->GetDockingManager()->AddPane(
-            m_localsView,
-            wxAuiPaneInfo().MinSize(200, 200).Bottom().Position(0).CloseButton().Caption("Locals & Watches").Name(
-                LLDB_LOCALS_PANE_NAME));
+        m_localsView = new LLDBLocalsView(parent, this);
+        m_mgr->GetDockingManager()->AddPane(m_localsView, wxAuiPaneInfo()
+                                                              .MinSize(200, 200)
+                                                              .Bottom()
+                                                              .Position(0)
+                                                              .CloseButton()
+                                                              .Caption("Locals & Watches")
+                                                              .Name(LLDB_LOCALS_PANE_NAME));
     }
 
     if(!m_threadsView) {
-        m_threadsView = new LLDBThreadsView(EventNotifier::Get()->TopFrame(), this);
+        m_threadsView = new LLDBThreadsView(parent, this);
         m_mgr->GetDockingManager()->AddPane(
-            m_threadsView,
-            wxAuiPaneInfo().MinSize(200, 200).Bottom().Position(0).CloseButton().Caption("Threads").Name(
-                LLDB_THREADS_PANE_NAME));
+            m_threadsView, wxAuiPaneInfo().MinSize(200, 200).Bottom().Position(0).CloseButton().Caption("Threads").Name(
+                               LLDB_THREADS_PANE_NAME));
     }
 }
 
@@ -854,9 +858,8 @@ void LLDBPlugin::OnBuildStarting(clBuildEvent& event)
 {
     if(m_connector.IsRunning()) {
         // lldb session is active, prompt the user
-        if(::wxMessageBox(_("A debug session is running\nCancel debug session and continue building?"),
-                          "CodeLite",
-                          wxICON_QUESTION | wxYES_NO | wxYES_DEFAULT | wxCENTER) == wxYES) {
+        if(::wxMessageBox(_("A debug session is running\nCancel debug session and continue building?"), "CodeLite",
+               wxICON_QUESTION | wxYES_NO | wxYES_DEFAULT | wxCENTER) == wxYES) {
             clDebugEvent dummy;
             OnDebugStop(dummy);
             event.Skip();
@@ -1008,9 +1011,8 @@ bool LLDBPlugin::DoInitializeDebugger(clDebugEvent& event, bool redirectOutput,
 
     if(m_connector.IsRunning()) {
         // Another debug session is already in progress
-        ::wxMessageBox(_("Another debug session is already in progress. Please stop it first"),
-                       "CodeLite",
-                       wxOK | wxCENTER | wxICON_WARNING);
+        ::wxMessageBox(_("Another debug session is already in progress. Please stop it first"), "CodeLite",
+            wxOK | wxCENTER | wxICON_WARNING);
         return false;
     }
 
