@@ -13,6 +13,7 @@ EditorOptionsGeneralEdit::EditorOptionsGeneralEdit(wxWindow* parent)
     m_pgPropSmartQuotes->SetValue(options->GetAutoCompleteDoubleQuotes());
     m_pgPropWrapBrackets->SetValue(options->IsWrapSelectionBrackets());
     m_pgPropWrapQuotes->SetValue(options->IsWrapSelectionWithQuotes());
+    m_pgPropZoomUsingCtrlScroll->SetValue(options->IsMouseZoomEnabled());
 }
 
 EditorOptionsGeneralEdit::~EditorOptionsGeneralEdit()
@@ -31,4 +32,5 @@ void EditorOptionsGeneralEdit::Save(OptionsConfigPtr options)
     options->SetAutoCompleteDoubleQuotes(m_pgPropSmartQuotes->GetValue().GetBool());
     options->SetWrapSelectionBrackets(m_pgPropWrapBrackets->GetValue().GetBool());
     options->SetWrapSelectionWithQuotes(m_pgPropWrapQuotes->GetValue().GetBool());
+    options->SetMouseZoomEnabled(m_pgPropZoomUsingCtrlScroll->GetValue().GetBool());
 }
