@@ -867,7 +867,7 @@ void CodeLiteApp::MSWReadRegistry()
         // Supprot for wxWidgets
         if(strWx.IsEmpty() == false) {
             // we have WX installed on this machine, set the path of WXWIN & WXCFG to point to it
-            EnvMap envs = vars.GetVariables(wxT("Default"), false, wxT(""));
+            EnvMap envs = vars.GetVariables(wxT("Default"), false, wxEmptyString, wxEmptyString);
 
             if(!envs.Contains(wxT("WXWIN"))) {
                 vars.AddVariable(wxT("Default"), wxT("WXWIN"), strWx);
@@ -883,7 +883,7 @@ void CodeLiteApp::MSWReadRegistry()
         // Support for UnitTest++
         if(strUnitTestPP.IsEmpty() == false) {
             // we have UnitTest++ installed on this machine
-            EnvMap envs = vars.GetVariables(wxT("Default"), false, wxT(""));
+            EnvMap envs = vars.GetVariables(wxT("Default"), false, wxEmptyString, wxEmptyString);
 
             if(!envs.Contains(wxT("UNIT_TEST_PP_SRC_DIR"))) {
                 vars.AddVariable(wxT("Default"), wxT("UNIT_TEST_PP_SRC_DIR"), strUnitTestPP);
