@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : breakpointpropertiesdlg.cpp
 //
 // -------------------------------------------------------------------------
@@ -29,47 +29,43 @@
 #include "breakpointpropertiesdlg.h"
 #include "windowattrmanager.h"
 
-
-
-BreakptPropertiesDlg::BreakptPropertiesDlg( wxWindow* parent )
-    :	BreakpointPropertiesDlgBase( parent )
+BreakptPropertiesDlg::BreakptPropertiesDlg(wxWindow* parent)
+    : BreakpointPropertiesDlgBase(parent)
 {
-    its_a_breakpt = true; 			// Default to breakpoint for new items
-    whichBreakcheck = wbc_line;	// and assume it'll be a line-number type
-    WindowAttrManager::Load(this, wxT("BreakptPropertiesDlgAttr"), NULL);
+    its_a_breakpt = true;       // Default to breakpoint for new items
+    whichBreakcheck = wbc_line; // and assume it'll be a line-number type
+    SetName("BreakptPropertiesDlg");
+    WindowAttrManager::Load(this);
 }
 
-BreakptPropertiesDlg::~BreakptPropertiesDlg()
-{
-    WindowAttrManager::Save(this, wxT("BreakptPropertiesDlgAttr"), NULL);
-}
+BreakptPropertiesDlg::~BreakptPropertiesDlg() {}
 
 // Insert the data from an existing breakpoint into the dialog fields
-void BreakptPropertiesDlg::EnterBPData( const BreakpointInfo &bp )
+void BreakptPropertiesDlg::EnterBPData(const BreakpointInfo& bp)
 {
     // The class BreakpointInfo& b will become the new bp, so copy the old ids
     b.debugger_id = bp.debugger_id;
     b.internal_id = bp.internal_id;
 
-    if (bp.bp_type == BP_type_watchpt) {
-        its_a_breakpt = false;	// UpdateUI will then tick the checkbox
+    if(bp.bp_type == BP_type_watchpt) {
+        its_a_breakpt = false; // UpdateUI will then tick the checkbox
         m_radioWatchtype->SetSelection(bp.watchpoint_type);
         m_textWatchExpression->SetValue(bp.watchpt_data);
     } else {
         its_a_breakpt = true;
-        if (bp.memory_address.IsEmpty() == false) {
+        if(bp.memory_address.IsEmpty() == false) {
             m_checkBreakMemory->SetValue(true);
             m_textBreakMemory->Clear();
             *m_textBreakMemory << bp.memory_address;
             whichBreakcheck = wbc_memory;
         } else {
             m_textFilename->SetValue(bp.file);
-            if (bp.lineno != -1) {
+            if(bp.lineno != -1) {
                 m_checkLineno->SetValue(true);
                 m_textLineno->Clear();
                 *m_textLineno << bp.lineno;
                 whichBreakcheck = wbc_line;
-            } else if (!bp.function_name.IsEmpty()) {
+            } else if(!bp.function_name.IsEmpty()) {
                 m_checkBreakFunction->SetValue(true);
                 m_textFunctionname->SetValue(bp.function_name);
                 m_checkRegex->SetValue(bp.regex == true);
@@ -78,15 +74,22 @@ void BreakptPropertiesDlg::EnterBPData( const BreakpointInfo &bp )
         }
     }
 
-    // We need temporarily to Disconnect this event, otherwise it's impossible to edit a watchpoint while the debugger's running
+    // We need temporarily to Disconnect this event, otherwise it's impossible to edit a watchpoint while the debugger's
+    // running
     // as SetSelection(1) causes a wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGING event, which is vetoed
-    m_choicebook->Disconnect( wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGING, wxChoicebookEventHandler( BreakptPropertiesDlg::OnPageChanging ), NULL, this );
-    if (its_a_breakpt) {
+    m_choicebook->Disconnect(wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGING,
+                             wxChoicebookEventHandler(BreakptPropertiesDlg::OnPageChanging),
+                             NULL,
+                             this);
+    if(its_a_breakpt) {
         m_choicebook->SetSelection(0);
     } else {
         m_choicebook->SetSelection(1);
     }
-    m_choicebook->Connect( wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGING, wxChoicebookEventHandler( BreakptPropertiesDlg::OnPageChanging ), NULL, this );
+    m_choicebook->Connect(wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGING,
+                          wxChoicebookEventHandler(BreakptPropertiesDlg::OnPageChanging),
+                          NULL,
+                          this);
 
     m_checkDisable->SetValue(!bp.is_enabled);
     m_checkTemp->SetValue(bp.is_temp);
@@ -96,37 +99,40 @@ void BreakptPropertiesDlg::EnterBPData( const BreakpointInfo &bp )
     m_textCommands->SetValue(bp.commandlist);
 }
 
-void BreakptPropertiesDlg::EndModal( int retCode )
+void BreakptPropertiesDlg::EndModal(int retCode)
 {
-    if (retCode != wxID_OK) {
+    if(retCode != wxID_OK) {
         return wxDialog::EndModal(retCode);
     }
 
     long l;
     wxString contents;
     int selectedPage = m_choicebook->GetSelection();
-    if (m_choicebook->GetPageText((size_t)selectedPage) == _("Watchpoint")) {
+    if(m_choicebook->GetPageText((size_t)selectedPage) == _("Watchpoint")) {
         b.bp_type = BP_type_watchpt;
         b.watchpoint_type = (WatchpointType)m_radioWatchtype->GetSelection();
         b.watchpt_data = m_textWatchExpression->GetValue();
-        if (b.watchpt_data.IsEmpty()) {
-            wxMessageBox(_("You don't seem to have entered a variable for the watchpoint to watch. Please try again."), wxT(":/"), wxICON_ERROR);
+        if(b.watchpt_data.IsEmpty()) {
+            wxMessageBox(_("You don't seem to have entered a variable for the watchpoint to watch. Please try again."),
+                         wxT(":/"),
+                         wxICON_ERROR);
             return;
         }
     } else {
-        
+
         // reset the fields to only the proper ones are copied
         b.lineno = wxNOT_FOUND;
         b.memory_address.Clear();
         b.file.Clear();
         b.function_name.Clear();
-        
-        // It's some flavour of breakpoint (assume standard for now). Only insert enabled data, in case a lineno sort is now a function bp
+
+        // It's some flavour of breakpoint (assume standard for now). Only insert enabled data, in case a lineno sort is
+        // now a function bp
         b.bp_type = BP_type_break;
-        switch (whichBreakcheck) {
+        switch(whichBreakcheck) {
         case wbc_line:
             contents = m_textLineno->GetValue();
-            if ( ! contents.ToLong(&l, 0) ) {
+            if(!contents.ToLong(&l, 0)) {
                 wxMessageBox(_("The breakpoint's line-number is invalid. Please try again."), _(":/"), wxICON_ERROR);
                 return;
             }
@@ -136,8 +142,10 @@ void BreakptPropertiesDlg::EndModal( int retCode )
 
         case wbc_function:
             b.function_name = m_textFunctionname->GetValue();
-            if (b.function_name.IsEmpty()) {
-                wxMessageBox(_("You don't seem to have entered a name for the function. Please try again."), _(":/"), wxICON_ERROR);
+            if(b.function_name.IsEmpty()) {
+                wxMessageBox(_("You don't seem to have entered a name for the function. Please try again."),
+                             _(":/"),
+                             wxICON_ERROR);
                 return;
             }
             b.regex = m_checkRegex->IsChecked();
@@ -151,7 +159,7 @@ void BreakptPropertiesDlg::EndModal( int retCode )
         }
     }
 
-    b.is_enabled = ! m_checkDisable->GetValue();
+    b.is_enabled = !m_checkDisable->GetValue();
     b.is_temp = m_checkTemp->GetValue();
     b.ignore_number = m_spinIgnore->GetValue();
     b.conditions = m_textCond->GetValue();
@@ -162,65 +170,68 @@ void BreakptPropertiesDlg::EndModal( int retCode )
 
 void BreakptPropertiesDlg::OnCheckBreakLineno(wxCommandEvent& event)
 {
-    if (event.IsChecked()) {
+    if(event.IsChecked()) {
         whichBreakcheck = wbc_line;
     }
 }
 
 void BreakptPropertiesDlg::OnCheckBreakFunction(wxCommandEvent& event)
 {
-    if (event.IsChecked()) {
+    if(event.IsChecked()) {
         whichBreakcheck = wbc_function;
     }
 }
 
 void BreakptPropertiesDlg::OnCheckBreakMemory(wxCommandEvent& event)
 {
-    if (event.IsChecked()) {
+    if(event.IsChecked()) {
         whichBreakcheck = wbc_memory;
     }
 }
 
-void BreakptPropertiesDlg::OnBrowse( wxCommandEvent& event )
+void BreakptPropertiesDlg::OnBrowse(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     wxString newfilepath, filepath(m_textFilename->GetValue());
-    if ((!filepath.IsEmpty()) && wxFileName::FileExists(filepath)) {
+    if((!filepath.IsEmpty()) && wxFileName::FileExists(filepath)) {
         newfilepath = wxFileSelector(_("Select file:"), filepath.c_str());
     } else {
         newfilepath = wxFileSelector(_("Select file:"));
     }
 
-    if (!newfilepath.IsEmpty()) {
+    if(!newfilepath.IsEmpty()) {
         m_textFilename->SetValue(newfilepath);
     }
 }
 
-void BreakptPropertiesDlg::OnCheckBreakLinenoUI( wxUpdateUIEvent& event )
+void BreakptPropertiesDlg::OnCheckBreakLinenoUI(wxUpdateUIEvent& event)
 {
     m_checkLineno->SetValue(whichBreakcheck == wbc_line);
     m_textLineno->Enable(m_checkLineno->IsChecked() && m_checkLineno->IsEnabled());
 }
 
-void BreakptPropertiesDlg::OnCheckBreakFunctionUI( wxUpdateUIEvent& event )
+void BreakptPropertiesDlg::OnCheckBreakFunctionUI(wxUpdateUIEvent& event)
 {
     m_checkBreakFunction->SetValue(whichBreakcheck == wbc_function);
     m_textFunctionname->Enable(m_checkBreakFunction->IsChecked() && m_checkBreakFunction->IsEnabled());
     m_checkRegex->Enable(m_textFunctionname->IsEnabled());
 }
 
-void BreakptPropertiesDlg::OnCheckBreakMemoryUI( wxUpdateUIEvent& event )
+void BreakptPropertiesDlg::OnCheckBreakMemoryUI(wxUpdateUIEvent& event)
 {
     m_checkBreakMemory->SetValue(whichBreakcheck == wbc_memory);
     m_textBreakMemory->Enable(m_checkBreakMemory->IsChecked() && m_checkBreakMemory->IsEnabled());
     // Disable the filename textctrl if the memory check is ticked
-    m_textFilename->Enable(! m_textBreakMemory->IsEnabled());
+    m_textFilename->Enable(!m_textBreakMemory->IsEnabled());
 }
 
 void BreakptPropertiesDlg::OnPageChanging(wxChoicebookEvent& event)
 {
-    if (b.debugger_id != -1) {
-        wxMessageBox(_("Sorry, you can't change a breakpoint to a watchpoint, or vice versa, while the debugger is running"), _("Not possible"), wxICON_ERROR | wxOK);
+    if(b.debugger_id != -1) {
+        wxMessageBox(
+            _("Sorry, you can't change a breakpoint to a watchpoint, or vice versa, while the debugger is running"),
+            _("Not possible"),
+            wxICON_ERROR | wxOK);
         event.Veto();
     }
 }
