@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : clang_driver.cpp
 //
 // -------------------------------------------------------------------------
@@ -267,7 +267,8 @@ FileTypeCmpArgs_t ClangDriver::DoPrepareCompilationArgs(const wxString& projectN
 
     // Build the TU file name
     wxFileName fnSourceFile(sourceFile);
-    pchfile << clCxxWorkspaceST::Get()->GetWorkspaceFileName().GetPath() << wxFileName::GetPathSeparator() << wxT(".clang");
+    pchfile << clCxxWorkspaceST::Get()->GetWorkspaceFileName().GetPath() << wxFileName::GetPathSeparator()
+            << wxT(".clang");
 
     {
         wxLogNull nl;
@@ -309,8 +310,8 @@ FileTypeCmpArgs_t ClangDriver::DoPrepareCompilationArgs(const wxString& projectN
 
             CompilerCommandLineParser cclp(compilationLine, cwd);
             cclp.MakeAbsolute(cwd);
-
             CL_DEBUG(wxT("Loaded compilation flags: %s"), compilationLine.c_str());
+            
             args.insert(args.end(), cclp.GetIncludesWithPrefix().begin(), cclp.GetIncludesWithPrefix().end());
             args.insert(args.end(), cclp.GetMacrosWithPrefix().begin(), cclp.GetMacrosWithPrefix().end());
             args.Add(cclp.GetStandardWithPrefix());
@@ -362,11 +363,11 @@ FileTypeCmpArgs_t ClangDriver::DoPrepareCompilationArgs(const wxString& projectN
     size_t workspaceFlags = LocalWorkspaceST::Get()->GetParserFlags();
     if(workspaceFlags & LocalWorkspace::EnableCpp11) {
         cppCompileArgs.Add(wxT("-std=c++11"));
-        cCompileArgs.Add(wxT("-std=c++11"));
+        //cCompileArgs.Add(wxT("-std=c++11"));
     }
     if(workspaceFlags & LocalWorkspace::EnableCpp14) {
         cppCompileArgs.Add(wxT("-std=c++14"));
-        cCompileArgs.Add(wxT("-std=c++14"));
+        //cCompileArgs.Add(wxT("-std=c++14"));
     }
 
     ///////////////////////////////////////////////////////////////////////
@@ -397,11 +398,11 @@ FileTypeCmpArgs_t ClangDriver::DoPrepareCompilationArgs(const wxString& projectN
 
         if(buildConf->IsClangC11()) {
             cppCompileArgs.Add(wxT("-std=c++11"));
-            cCompileArgs.Add(wxT("-std=c++11"));
+            //cCompileArgs.Add(wxT("-std=c++11"));
         }
         if(buildConf->IsClangC14()) {
             cppCompileArgs.Add(wxT("-std=c++14"));
-            cCompileArgs.Add(wxT("-std=c++14"));
+            //cCompileArgs.Add(wxT("-std=c++14"));
         }
     }
 
