@@ -36,42 +36,85 @@
 /////////////////////////////////////////////////////////////////
 /////////////////////////////////////////////////////////////////
 
-WatchesTable::WatchesTable( wxWindow* parent )
-    : DebuggerTreeListCtrlBase( parent )
+WatchesTable::WatchesTable(wxWindow* parent)
+    : DebuggerTreeListCtrlBase(parent)
 {
     InitTable();
-    m_DBG_USERR        = DBG_USERR_WATCHTABLE;
+    m_DBG_USERR = DBG_USERR_WATCHTABLE;
     m_QUERY_NUM_CHILDS = QUERY_NUM_CHILDS;
-    m_LIST_CHILDS      = LIST_WATCH_CHILDS;
+    m_LIST_CHILDS = LIST_WATCH_CHILDS;
 
-    //Load the right click menu
+    // Load the right click menu
     m_rclickMenu = wxXmlResource::Get()->LoadMenu(wxT("dbg_watch_rmenu"));
-    Connect(XRCID("del_expr"),          wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnDeleteWatch), NULL, this);
-    Connect(XRCID("del_expr_all"),      wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnDeleteAll), NULL, this);
-    Connect(XRCID("edit_expr"),         wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuEditExpr), NULL, this);
-    Connect(XRCID("copy_value"),        wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuCopyValue), NULL, this);
-    Connect(XRCID("add_watch"),         wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnNewWatch_Internal), NULL, this);
-    Connect(XRCID("copy_both"),         wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuCopyBoth), NULL, this);
+    Connect(
+        XRCID("del_expr"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(WatchesTable::OnDeleteWatch), NULL, this);
+    Connect(XRCID("del_expr_all"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnDeleteAll),
+            NULL,
+            this);
+    Connect(XRCID("edit_expr"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuEditExpr),
+            NULL,
+            this);
+    Connect(XRCID("copy_value"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuCopyValue),
+            NULL,
+            this);
+    Connect(XRCID("add_watch"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnNewWatch_Internal),
+            NULL,
+            this);
+    Connect(XRCID("copy_both"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuCopyBoth),
+            NULL,
+            this);
 
-    Connect(XRCID("watches_df_natural"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuDisplayFormat), NULL, this);
-    Connect(XRCID("watches_df_hex"),    wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuDisplayFormat), NULL, this);
-    Connect(XRCID("watches_df_bin"),    wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuDisplayFormat), NULL, this);
-    Connect(XRCID("watches_df_octal"),  wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuDisplayFormat), NULL, this);
-    Connect(XRCID("watches_df_decimal"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuDisplayFormat), NULL, this);
+    Connect(XRCID("watches_df_natural"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuDisplayFormat),
+            NULL,
+            this);
+    Connect(XRCID("watches_df_hex"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuDisplayFormat),
+            NULL,
+            this);
+    Connect(XRCID("watches_df_bin"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuDisplayFormat),
+            NULL,
+            this);
+    Connect(XRCID("watches_df_octal"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuDisplayFormat),
+            NULL,
+            this);
+    Connect(XRCID("watches_df_decimal"),
+            wxEVT_COMMAND_MENU_SELECTED,
+            wxCommandEventHandler(WatchesTable::OnMenuDisplayFormat),
+            NULL,
+            this);
 
     // UI events
-    Connect(XRCID("edit_expr"),wxEVT_UPDATE_UI, wxUpdateUIEventHandler( WatchesTable::OnMenuEditExprUI), NULL, this);
-    Connect(XRCID("del_expr"),wxEVT_UPDATE_UI, wxUpdateUIEventHandler( WatchesTable::OnDeleteWatchUI), NULL, this);
-    
-    EventNotifier::Get()->Connect(wxEVT_DEBUGGER_TYPE_RESOLVE_ERROR, clCommandEventHandler(WatchesTable::OnTypeResolveError), NULL, this);
-    SetDropTarget( new WatchDropTarget(this) );
+    Connect(XRCID("edit_expr"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(WatchesTable::OnMenuEditExprUI), NULL, this);
+    Connect(XRCID("del_expr"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(WatchesTable::OnDeleteWatchUI), NULL, this);
+
+    EventNotifier::Get()->Connect(
+        wxEVT_DEBUGGER_TYPE_RESOLVE_ERROR, clCommandEventHandler(WatchesTable::OnTypeResolveError), NULL, this);
+    SetDropTarget(new WatchDropTarget(this));
 }
 
 WatchesTable::~WatchesTable()
 {
-    EventNotifier::Get()->Connect(wxEVT_DEBUGGER_TYPE_RESOLVE_ERROR, clCommandEventHandler(WatchesTable::OnTypeResolveError), NULL, this);
-    
-    if (m_rclickMenu) {
+    EventNotifier::Get()->Connect(
+        wxEVT_DEBUGGER_TYPE_RESOLVE_ERROR, clCommandEventHandler(WatchesTable::OnTypeResolveError), NULL, this);
+
+    if(m_rclickMenu) {
         delete m_rclickMenu;
         m_rclickMenu = NULL;
     }
@@ -93,59 +136,53 @@ void WatchesTable::Clear()
 void WatchesTable::InitTable()
 {
     m_listTable->AddColumn(_("Expression"), 150);
-    m_listTable->AddColumn(_("Value"),      500);
-    m_listTable->AddColumn(_("Type"),       200);
+    m_listTable->AddColumn(_("Value"), 500);
+    m_listTable->AddColumn(_("Type"), 200);
     m_listTable->AddRoot(_("Watches"));
 }
 
-void WatchesTable::OnListKeyDown( wxTreeEvent& event )
+void WatchesTable::OnListKeyDown(wxTreeEvent& event)
 {
-    if (event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_NUMPAD_DELETE) {
+    if(event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_NUMPAD_DELETE) {
 
         wxTreeItemId item = m_listTable->GetSelection();
-        if(item.IsOk() == false)
-            return;
+        if(item.IsOk() == false) return;
 
         DoDeleteWatch(item);
         m_listTable->Delete(item);
 
     } else {
         event.Skip();
-
     }
 }
 
-void WatchesTable::OnItemRightClick(wxTreeEvent &event)
+void WatchesTable::OnItemRightClick(wxTreeEvent& event)
 {
     wxUnusedVar(event);
-    if (m_rclickMenu) {
+    if(m_rclickMenu) {
         PopupMenu(m_rclickMenu);
     }
 }
 
-void WatchesTable::OnNewWatch(wxCommandEvent &event)
+void WatchesTable::OnNewWatch(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     wxString expr = wxGetTextFromUser(_("Expression to watch:"), _("New watch"));
-    if (expr.IsEmpty() == false) {
+    if(expr.IsEmpty() == false) {
         AddExpression(expr);
         RefreshValues(false);
     }
 }
 
-void WatchesTable::OnNewWatchUI(wxUpdateUIEvent &event)
-{
-    event.Enable(true);
-}
+void WatchesTable::OnNewWatchUI(wxUpdateUIEvent& event) { event.Enable(true); }
 
-
-void WatchesTable::OnDeleteAll(wxCommandEvent &event)
+void WatchesTable::OnDeleteAll(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     Clear();
 }
 
-void WatchesTable::OnDeleteAllUI(wxUpdateUIEvent &event)
+void WatchesTable::OnDeleteAllUI(wxUpdateUIEvent& event)
 {
     wxTreeItemId root = m_listTable->GetRootItem();
 
@@ -155,51 +192,66 @@ void WatchesTable::OnDeleteAllUI(wxUpdateUIEvent &event)
     event.Enable(root.IsOk() && child.IsOk());
 }
 
-void WatchesTable::OnDeleteWatch(wxCommandEvent &event)
+void WatchesTable::OnDeleteWatch(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     wxTreeItemId item = m_listTable->GetSelection();
-    if(item.IsOk() == false)
-        return;
+    if(item.IsOk() == false) return;
 
     DoDeleteWatch(item);
     m_listTable->Delete(item);
 }
 
-void WatchesTable::OnDeleteWatchUI(wxUpdateUIEvent &event)
+void WatchesTable::OnDeleteWatchUI(wxUpdateUIEvent& event)
 {
     wxTreeItemId item = m_listTable->GetSelection();
     event.Enable(item.IsOk() && m_listTable->GetItemParent(item) == m_listTable->GetRootItem());
 }
 
-void WatchesTable::AddExpression(const wxString &expr)
+void WatchesTable::AddExpression(const wxString& expr)
 {
-    IDebugger *dbgr = DebuggerMgr::Get().GetActiveDebugger();
-    if( dbgr && ManagerST::Get()->DbgCanInteract() ) {
+    IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
+    if(dbgr && ManagerST::Get()->DbgCanInteract()) {
         dbgr->ResolveType(expr, DBG_USERR_WATCHTABLE);
 
     } else {
         DebuggerEventData dummy;
         dummy.m_expression = expr;
-        dummy.m_evaluated  = expr;
+        dummy.m_evaluated = expr;
         OnTypeResolved(dummy);
     }
 }
 
+void WatchesTable::UpdateVariableObjects()
+{
+    IDebugger *debugger = DebuggerMgr::Get().GetActiveDebugger();
+    CHECK_PTR_RET(debugger);
+
+    wxTreeItemId root = m_listTable->GetRootItem();
+    wxTreeItemIdValue cookieOne;
+    wxTreeItemId item = m_listTable->GetFirstChild(root, cookieOne);
+    while( item.IsOk() ) {
+        wxString gdbID = DoGetGdbId(item);
+        if(!gdbID.IsEmpty()) {
+            debugger->UpdateWatch(gdbID);
+        }
+        item = m_listTable->GetNextChild(root, cookieOne);
+    }
+}
+
 void WatchesTable::RefreshValues(bool repositionEditor)
 {
-    //indicate in the global manager if we want to actually reposition the editor's position after the dbgr->QueryFileLine() refresh
+    // indicate in the global manager if we want to actually reposition the editor's position after the
+    // dbgr->QueryFileLine() refresh
     ManagerST::Get()->SetRepositionEditor(repositionEditor);
 
     // loop over the childrens, if we got a valid variable object, re-evaluate it
     wxTreeItemId root = m_listTable->GetRootItem();
-    if(root.IsOk() == false)
-        return;
+    if(root.IsOk() == false) return;
 
     // Obtain the debugger and make sure that we can interact with it
-    IDebugger *dbgr = DoGetDebugger();
-    if(!dbgr)
-        return;
+    IDebugger* dbgr = DoGetDebugger();
+    if(!dbgr) return;
 
     // rese tree items colour to black
     DoResetItemColour(root, 0);
@@ -211,11 +263,11 @@ void WatchesTable::RefreshValues(bool repositionEditor)
     // for those items, create a variable object
     wxTreeItemIdValue cookieOne;
     wxTreeItemId item = m_listTable->GetFirstChild(root, cookieOne);
-    while( item.IsOk() ) {
+    while(item.IsOk()) {
 
         DbgTreeItemData* data = static_cast<DbgTreeItemData*>(m_listTable->GetItemData(item));
         if(data && data->_gdbId.IsEmpty()) {
-            dbgr->CreateVariableObject(m_listTable->GetItemText(item), true, m_DBG_USERR);
+            dbgr->CreateVariableObject(m_listTable->GetItemText(item), false, m_DBG_USERR);
             m_createVarItemId[m_listTable->GetItemText(item)] = item;
         }
 
@@ -232,7 +284,7 @@ wxArrayString WatchesTable::GetExpressions()
         wxTreeItemIdValue cookie;
         wxTreeItemId item = m_listTable->GetFirstChild(root, cookie);
         while(item.IsOk()) {
-            expressions.Add( m_listTable->GetItemText(item) ) ;
+            expressions.Add(m_listTable->GetItemText(item));
             item = m_listTable->GetNextChild(root, cookie);
         }
     }
@@ -240,28 +292,26 @@ wxArrayString WatchesTable::GetExpressions()
     return expressions;
 }
 
-void WatchesTable::OnMenuEditExpr(wxCommandEvent &event)
+void WatchesTable::OnMenuEditExpr(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     wxTreeItemId item = m_listTable->GetSelection();
-    if(item.IsOk() == false)
-        return;
+    if(item.IsOk() == false) return;
 
-    IDebugger *dbgr = DoGetDebugger();
+    IDebugger* dbgr = DoGetDebugger();
     if(!dbgr) {
         return;
     }
 
     wxString newExpr = wxGetTextFromUser(_("Update expression:"), _("Update Watch"), m_listTable->GetItemText(item));
-    if(newExpr.IsEmpty())
-        return;
+    if(newExpr.IsEmpty()) return;
 
     DoUpdateExpression(item, newExpr);
 }
 
-void WatchesTable::DoUpdateExpression(const wxTreeItemId& item, const wxString &newExpr)
+void WatchesTable::DoUpdateExpression(const wxTreeItemId& item, const wxString& newExpr)
 {
-    IDebugger *dbgr = DoGetDebugger();
+    IDebugger* dbgr = DoGetDebugger();
     if(!dbgr) {
         return;
     }
@@ -275,7 +325,7 @@ void WatchesTable::OnMenuCopyBoth(wxCommandEvent& event)
 {
     wxTreeItemId item = m_listTable->GetSelection();
     if(item.IsOk()) {
-        CopyToClipboard( m_listTable->GetItemText(item) + wxT(" ") + m_listTable->GetItemText(item, 1) );
+        CopyToClipboard(m_listTable->GetItemText(item) + wxT(" ") + m_listTable->GetItemText(item, 1));
     }
 }
 
@@ -283,14 +333,14 @@ void WatchesTable::OnMenuCopyValue(wxCommandEvent& event)
 {
     wxTreeItemId item = m_listTable->GetSelection();
     if(item.IsOk()) {
-        CopyToClipboard( m_listTable->GetItemText(item, 1) );
+        CopyToClipboard(m_listTable->GetItemText(item, 1));
     }
 }
 
 void WatchesTable::OnNewWatch_Internal(wxCommandEvent& event)
 {
     wxString expr = event.GetString();
-    if( expr.empty() == false ) {
+    if(expr.empty() == false) {
         AddExpression(expr);
         RefreshValues(false);
     }
@@ -299,9 +349,9 @@ void WatchesTable::OnNewWatch_Internal(wxCommandEvent& event)
 void WatchesTable::OnCreateVariableObject(const DebuggerEventData& event)
 {
     wxString expr = event.m_expression;
-    IDebugger *dbgr = DoGetDebugger();
+    IDebugger* dbgr = DoGetDebugger();
     std::map<wxString, wxTreeItemId>::iterator iter = m_createVarItemId.find(expr);
-    if( iter != m_createVarItemId.end() ) {
+    if(iter != m_createVarItemId.end()) {
         wxTreeItemId item = iter->second;
         m_createVarItemId.erase(iter);
 
@@ -314,8 +364,7 @@ void WatchesTable::OnCreateVariableObject(const DebuggerEventData& event)
                 // set the type
                 m_listTable->SetItemText(item, 2, event.m_variableObject.typeName);
                 // refresh this item only
-                if(dbgr)
-                    DoRefreshItem(dbgr, item, true);
+                if(dbgr) DoRefreshItem(dbgr, item, true);
 
                 // Query the debugger to see if this node has a children
                 // In case it does, we add a dummy node so we will get the [+] sign
@@ -330,7 +379,6 @@ void WatchesTable::OnCreateVariableObject(const DebuggerEventData& event)
                 DoRefreshItem(dbgr, item, true);
             }
         }
-
     }
 }
 
@@ -338,22 +386,19 @@ void WatchesTable::OnListChildren(const DebuggerEventData& event)
 {
     wxString gdbId = event.m_expression;
     std::map<wxString, wxTreeItemId>::iterator iter = m_listChildItemId.find(gdbId);
-    if(iter == m_listChildItemId.end())
-        return;
+    if(iter == m_listChildItemId.end()) return;
 
     wxTreeItemId item = iter->second;
     m_listChildItemId.erase(iter);
 
     if(event.m_userReason == m_QUERY_NUM_CHILDS) {
-        if(event.m_varObjChildren.empty() == false)
-            m_listTable->AppendItem(item, wxT("<dummy>"));
+        if(event.m_varObjChildren.empty() == false) m_listTable->AppendItem(item, wxT("<dummy>"));
 
     } else if(event.m_userReason == m_LIST_CHILDS) {
         if(event.m_varObjChildren.empty() == false) {
-            for(size_t i=0; i<event.m_varObjChildren.size(); i++) {
-                IDebugger *dbgr = DebuggerMgr::Get().GetActiveDebugger();
-                if(!dbgr || !ManagerST::Get()->DbgCanInteract())
-                    return;
+            for(size_t i = 0; i < event.m_varObjChildren.size(); i++) {
+                IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
+                if(!dbgr || !ManagerST::Get()->DbgCanInteract()) return;
 
                 VariableObjChild ch = event.m_varObjChildren.at(i);
                 if(ch.varName == wxT("public") || ch.varName == wxT("private") || ch.varName == wxT("protected")) {
@@ -364,7 +409,7 @@ void WatchesTable::OnListChildren(const DebuggerEventData& event)
 
                 } else {
 
-                    DbgTreeItemData *data = new DbgTreeItemData();
+                    DbgTreeItemData* data = new DbgTreeItemData();
                     data->_gdbId = ch.gdbId;
                     wxTreeItemId child = m_listTable->AppendItem(item, ch.varName, -1, -1, data);
                     m_listTable->SetItemText(child, 2, ch.type);
@@ -378,7 +423,6 @@ void WatchesTable::OnListChildren(const DebuggerEventData& event)
                     dbgr->EvaluateVariableObject(data->_gdbId, m_DBG_USERR);
                     // ask the value for this node
                     m_gdbIdToTreeId[data->_gdbId] = child;
-
                 }
             }
         }
@@ -390,7 +434,7 @@ void WatchesTable::OnItemExpanding(wxTreeEvent& event)
     wxTreeItemIdValue cookie;
     wxTreeItemId child = m_listTable->GetFirstChild(event.GetItem(), cookie);
 
-    IDebugger *dbgr = DoGetDebugger();
+    IDebugger* dbgr = DoGetDebugger();
     if(!dbgr) {
         // dont allow the expansion of this item
         event.Veto();
@@ -401,7 +445,7 @@ void WatchesTable::OnItemExpanding(wxTreeEvent& event)
         // a dummy node, replace it with the real node content
         m_listTable->Delete(child);
 
-        DbgTreeItemData *data = (DbgTreeItemData*) m_listTable->GetItemData(event.GetItem());
+        DbgTreeItemData* data = (DbgTreeItemData*)m_listTable->GetItemData(event.GetItem());
         if(data) {
             if(data->_gdbId.IsEmpty() == false) {
                 dbgr->UpdateVariableObject(data->_gdbId, m_DBG_USERR);
@@ -458,7 +502,7 @@ void WatchesTable::OnMenuDisplayFormat(wxCommandEvent& event)
     }
 
     wxTreeItemId item = m_listTable->GetSelection();
-    IDebugger *  dbgr = DoGetDebugger();
+    IDebugger* dbgr = DoGetDebugger();
     if(!dbgr || !item.IsOk()) {
         return;
     }
@@ -473,11 +517,10 @@ void WatchesTable::OnMenuDisplayFormat(wxCommandEvent& event)
 
 void WatchesTable::OnUpdateVariableObject(const DebuggerEventData& event)
 {
-    if(event.m_varObjUpdateInfo.refreshIds.IsEmpty())
-        return;
+    if(event.m_varObjUpdateInfo.refreshIds.IsEmpty()) return;
 
     wxArrayString itemsToRefresh = event.m_varObjUpdateInfo.refreshIds;
-    IDebugger *dbgr = DoGetDebugger();
+    IDebugger* dbgr = DoGetDebugger();
     if(dbgr) {
         DoRefreshItemRecursively(dbgr, m_listTable->GetRootItem(), itemsToRefresh);
     }
@@ -487,31 +530,30 @@ void WatchesTable::OnTypeResolved(const DebuggerEventData& event)
 {
     wxString expr = ::DbgPrependCharPtrCastIfNeeded(event.m_expression, event.m_evaluated);
 
-    //make sure that the expression does not exist
+    // make sure that the expression does not exist
     wxTreeItemId root = m_listTable->GetRootItem();
     if(!root.IsOk()) {
         return;
     }
 
-    IDebugger *dbgr = DebuggerMgr::Get().GetActiveDebugger();
+    IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
     if(!dbgr) {
         return;
     }
 
     // Obtain the debugger and make sure that we can interact with it
-    if( !ManagerST::Get()->DbgCanInteract() )
-        return;
+    if(!ManagerST::Get()->DbgCanInteract()) return;
 
     // Append the new item and call the debugger to create a new variable object for this
     // expression
     wxTreeItemId item = m_listTable->AppendItem(root, expr, -1, -1, new DbgTreeItemData());
-    dbgr->CreateVariableObject(expr, true, m_DBG_USERR);
+    dbgr->CreateVariableObject(expr, false, m_DBG_USERR);
     m_createVarItemId[expr] = item;
 }
 
 void WatchesTable::OnRefresh(wxCommandEvent& event)
 {
-    IDebugger *dbgr = DebuggerMgr::Get().GetActiveDebugger();
+    IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
     if(!dbgr || !ManagerST::Get()->DbgCanInteract()) {
         return;
     }
@@ -524,9 +566,9 @@ void WatchesTable::OnRefresh(wxCommandEvent& event)
     wxTreeItemIdValue cookieOne;
     wxTreeItemId root = m_listTable->GetRootItem();
     wxTreeItemId item = m_listTable->GetFirstChild(root, cookieOne);
-    while( item.IsOk() ) {
+    while(item.IsOk()) {
 
-        watches.Add( m_listTable->GetItemText(item) );
+        watches.Add(m_listTable->GetItemText(item));
         DbgTreeItemData* data = static_cast<DbgTreeItemData*>(m_listTable->GetItemData(item));
         if(data && data->_gdbId.IsEmpty()) {
             dbgr->DeleteVariableObject(data->_gdbId);
@@ -535,25 +577,25 @@ void WatchesTable::OnRefresh(wxCommandEvent& event)
     }
     m_createVarItemId.clear();
     Clear();
-    for(size_t i=0; i<watches.GetCount(); ++i) {
-        AddExpression( watches.Item(i) );
+    for(size_t i = 0; i < watches.GetCount(); ++i) {
+        AddExpression(watches.Item(i));
     }
 }
 
 void WatchesTable::OnRefreshUI(wxUpdateUIEvent& event)
 {
-    IDebugger *dbgr = DebuggerMgr::Get().GetActiveDebugger();
-    event.Enable(dbgr && ManagerST::Get()->DbgCanInteract() );
+    IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
+    event.Enable(dbgr && ManagerST::Get()->DbgCanInteract());
 }
 
 void WatchesTable::OnTypeResolveError(clCommandEvent& event)
 {
     DebuggerEventData* ded = dynamic_cast<DebuggerEventData*>(event.GetClientObject());
-    if ( ded && ded->m_userReason == m_DBG_USERR) {
+    if(ded && ded->m_userReason == m_DBG_USERR) {
         // this event was meant for us
         // could not resolve type
         wxTreeItemId id = DoFindItemByExpression(ded->m_expression);
-        if ( id.IsOk() ) {
+        if(id.IsOk()) {
             // update
             m_listTable->SetItemText(id, 1, ded->m_text);
         } else {
@@ -563,7 +605,6 @@ void WatchesTable::OnTypeResolveError(clCommandEvent& event)
         }
     } else {
         event.Skip();
-        
     }
 }
 
@@ -571,6 +612,6 @@ void WatchesTable::OnTypeResolveError(clCommandEvent& event)
 
 bool WatchDropTarget::OnDropText(wxCoord x, wxCoord y, const wxString& text)
 {
-    m_parent->AddExpression( text );
+    m_parent->AddExpression(text);
     return false; // so the text won't get cut from the editor...
 }
