@@ -41,6 +41,10 @@
 #include "event_notifier.h"
 #include "plugin.h"
 #include <algorithm>
+#include "clWorkspaceView.h"
+#include "DefaultWorkspacePage.h"
+#include "clFileOrFolderDropTarget.h"
+#include "clTreeCtrlPanel.h"
 
 #define OPEN_CONFIG_MGR_STR _("<Open Configuration Manager...>")
 
@@ -49,17 +53,20 @@ WorkspaceTab::WorkspaceTab(wxWindow* parent, const wxString& caption)
     , m_caption(caption)
     , m_isLinkedToEditor(true)
     , m_dlg(NULL)
+    , m_view(NULL)
 {
     long link = EditorConfigST::Get()->GetInteger(wxT("LinkWorkspaceViewToEditor"), 1);
     m_isLinkedToEditor = link ? true : false;
 
     CreateGUIControls();
     ConnectEvents();
-    m_themeHelper = NULL;//new ThemeHandlerHelper(this);
+    m_themeHelper = NULL; // new ThemeHandlerHelper(this);
     int sashPos = clConfig::Get().Read(kConfigWorkspaceTabSashPosition, wxNOT_FOUND);
     if(sashPos != wxNOT_FOUND) {
         m_splitter->SetSashPosition(sashPos);
     }
+    SetDropTarget(new clFileOrFolderDropTarget(this));
+    Bind(wxEVT_DND_FOLDER_DROPPED, &WorkspaceTab::OnFolderDropped, this);
 }
 
 WorkspaceTab::~WorkspaceTab()
@@ -104,14 +111,20 @@ WorkspaceTab::~WorkspaceTab()
 
 void WorkspaceTab::CreateGUIControls()
 {
-    wxSizer* sz = GetSizer();
 #ifdef __WXMAC__
     m_workspaceConfig->SetWindowVariant(wxWINDOW_VARIANT_SMALL);
     m_choiceActiveProject->SetWindowVariant(wxWINDOW_VARIANT_SMALL);
 #endif
-    // Construct the tree
-    m_fileView = new FileViewTree(this, wxID_ANY);
-    sz->Add(m_fileView, 1, wxEXPAND | wxALL, 2);
+    //// Construct the tree
+    int index = m_simpleBook->FindPage(m_panelCxx);
+    if(index != wxNOT_FOUND) {
+        // set the C++ workspace view name to fit its workspace type
+        m_simpleBook->SetPageText(index, clCxxWorkspaceST::Get()->GetWorkspaceType());
+    }
+    m_view = new clWorkspaceView(m_simpleBook);
+    m_view->AddPage(new DefaultWorkspacePage(m_simpleBook), _("Default"));
+    m_view->SelectPage(_("Default"));
+    m_view->SetDefaultPage(_("Default"));
 }
 
 void WorkspaceTab::FreezeThaw(bool freeze /*=true*/)
@@ -202,10 +215,7 @@ void WorkspaceTab::OnCollapseAll(wxCommandEvent& e)
     }
 }
 
-void WorkspaceTab::OnCollapseAllUI(wxUpdateUIEvent& e)
-{
-    e.Enable(ManagerST::Get()->IsWorkspaceOpen());
-}
+void WorkspaceTab::OnCollapseAllUI(wxUpdateUIEvent& e) { e.Enable(ManagerST::Get()->IsWorkspaceOpen()); }
 
 void WorkspaceTab::OnGoHome(wxCommandEvent& e)
 {
@@ -224,10 +234,7 @@ void WorkspaceTab::OnGoHome(wxCommandEvent& e)
     ManagerST::Get()->ShowWorkspacePane(m_caption);
 }
 
-void WorkspaceTab::OnGoHomeUI(wxUpdateUIEvent& e)
-{
-    e.Enable(!ManagerST::Get()->GetActiveProjectName().IsEmpty());
-}
+void WorkspaceTab::OnGoHomeUI(wxUpdateUIEvent& e) { e.Enable(!ManagerST::Get()->GetActiveProjectName().IsEmpty()); }
 
 void WorkspaceTab::OnProjectSettings(wxCommandEvent& e)
 {
@@ -241,10 +248,7 @@ void WorkspaceTab::OnProjectSettingsUI(wxUpdateUIEvent& e)
     e.Enable(!ManagerST::Get()->GetActiveProjectName().IsEmpty());
 }
 
-static int wxStringCmpFunc(const wxString& item1, const wxString& item2)
-{
-    return item1.CmpNoCase(item2);
-}
+static int wxStringCmpFunc(const wxString& item1, const wxString& item2) { return item1.CmpNoCase(item2); }
 
 void WorkspaceTab::OnShowFile(wxCommandEvent& e)
 {
@@ -296,10 +300,7 @@ void WorkspaceTab::OnWorkspaceLoaded(wxCommandEvent& e)
     }
 }
 
-void WorkspaceTab::OnEditorClosing(wxCommandEvent& e)
-{
-    e.Skip();
-}
+void WorkspaceTab::OnEditorClosing(wxCommandEvent& e) { e.Skip(); }
 
 void WorkspaceTab::OnWorkspaceClosed(wxCommandEvent& e)
 {
@@ -332,8 +333,7 @@ void WorkspaceTab::OnProjectRemoved(clCommandEvent& e)
     SendCmdEvent(wxEVT_FILE_VIEW_REFRESHED);
 }
 
-struct wxStringSorter
-{
+struct wxStringSorter {
     bool operator()(WorkspaceConfigurationPtr one, WorkspaceConfigurationPtr two) const
     {
         return one->GetName().Lower().CmpNoCase(two->GetName().Lower()) < 0;
@@ -343,15 +343,15 @@ struct wxStringSorter
 void WorkspaceTab::DoWorkspaceConfig()
 {
     // Update the workspace configuration
-    BuildMatrixPtr matrix = WorkspaceST::Get()->GetBuildMatrix();
+    BuildMatrixPtr matrix = clCxxWorkspaceST::Get()->GetBuildMatrix();
     std::list<WorkspaceConfigurationPtr> confs = matrix->GetConfigurations();
 
     m_workspaceConfig->Freeze();
     m_workspaceConfig->Enable(true);
     m_workspaceConfig->Clear();
-    
+
     confs.sort(wxStringSorter());
-    
+
     for(std::list<WorkspaceConfigurationPtr>::iterator iter = confs.begin(); iter != confs.end(); iter++) {
         m_workspaceConfig->Append((*iter)->GetName());
     }
@@ -381,7 +381,7 @@ void WorkspaceTab::OnConfigurationManagerChoice(wxCommandEvent& e)
         ProcessEvent(e);
         return;
     }
-    
+
     CallAfter(&WorkspaceTab::DoConfigChanged);
 }
 
@@ -420,7 +420,7 @@ void WorkspaceTab::DoUpdateChoiceWithProjects()
 
     wxWindowUpdateLocker locker(m_choiceActiveProject);
     m_choiceActiveProject->Clear();
-    if(WorkspaceST::Get()->IsOpen()) {
+    if(clCxxWorkspaceST::Get()->IsOpen()) {
         m_choiceActiveProject->Append(projects);
         m_choiceActiveProject->SetStringSelection(ManagerST::Get()->GetActiveProjectName());
     }
@@ -431,10 +431,7 @@ void WorkspaceTab::OnConfigurationManagerChoiceUI(wxUpdateUIEvent& event)
     event.Enable(ManagerST::Get()->IsWorkspaceOpen());
 }
 
-void WorkspaceTab::OnWorkspaceOpenUI(wxUpdateUIEvent& event)
-{
-    event.Enable(ManagerST::Get()->IsWorkspaceOpen());
-}
+void WorkspaceTab::OnWorkspaceOpenUI(wxUpdateUIEvent& event) { event.Enable(ManagerST::Get()->IsWorkspaceOpen()); }
 
 void WorkspaceTab::OpenProjectSettings(const wxString& project)
 {
@@ -486,10 +483,7 @@ void WorkspaceTab::OpenProjectSettings(const wxString& project)
     }
 }
 
-void WorkspaceTab::ProjectSettingsDlgClosed()
-{
-    m_dlg = NULL;
-}
+void WorkspaceTab::ProjectSettingsDlgClosed() { m_dlg = NULL; }
 
 void WorkspaceTab::OnActiveProjectChanged(clProjectSettingsEvent& e)
 {
@@ -512,7 +506,7 @@ void WorkspaceTab::DoGoHome()
         wxTreeItemId sel = arr.Item(0);
         if(sel.IsOk() && m_fileView->ItemHasChildren(sel)) m_fileView->Expand(sel);
     }
-    ManagerST::Get()->ShowWorkspacePane(m_caption);
+    //ManagerST::Get()->ShowWorkspacePane(m_caption);
 }
 
 void WorkspaceTab::DoConfigChanged()
@@ -529,3 +523,9 @@ void WorkspaceTab::DoConfigChanged()
 
     ManagerST::Get()->UpdateParserPaths(true);
 }
+
+void WorkspaceTab::OnFolderDropped(clCommandEvent& event)
+{
+    // pass it on to the tree view
+    m_fileView->CallAfter(&FileViewTree::FolderDropped, event.GetStrings());
+}
