@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : CompilersDetectorManager.cpp
 //
 // -------------------------------------------------------------------------
@@ -31,6 +31,7 @@
 #include "CompilerLocatorMSVC10.h" // VS 2010
 #include "CompilerLocatorMSVC11.h" // VS 2012
 #include "CompilerLocatorMSVC12.h" // VS 2013
+#include "CompilerLocatorMSVC14.h" // VS 2015
 #include "CompilerLocatorCLANG.h"
 #include "CompilerLocatorCygwin.h"
 #include <wx/utils.h>
@@ -54,6 +55,7 @@ CompilersDetectorManager::CompilersDetectorManager()
     m_detectors.push_back(ICompilerLocator::Ptr_t(new CompilerLocatorMSVC10()));
     m_detectors.push_back(ICompilerLocator::Ptr_t(new CompilerLocatorMSVC11()));
     m_detectors.push_back(ICompilerLocator::Ptr_t(new CompilerLocatorMSVC12()));
+    m_detectors.push_back(ICompilerLocator::Ptr_t(new CompilerLocatorMSVC14()));	
     m_detectors.push_back(ICompilerLocator::Ptr_t(new CompilerLocatorCygwin()));
 
 #elif defined(__WXGTK__)
