@@ -8,7 +8,7 @@
 EclipseCXXThemeImporter::EclipseCXXThemeImporter()
 {
     SetKeywords0("and and_eq asm auto bitand bitor bool break case catch char class compl const const_cast "
-                 "continue default delete do double dynamic_cast else enum explicit export extern false "
+                 "continue default delete do double dynamic_cast else enum explicit export extern false final "
                  "float for friend goto if inline int long mutable namespace new not not_eq operator or "
                  "or_eq private protected public register reinterpret_cast return short signed sizeof "
                  "static static_cast struct switch template this throw true try typedef typeid typename "
