@@ -11,30 +11,20 @@
 #include <algorithm>
 #include <wx/dnd.h>
 #include <wx/regex.h>
+#include "clTabRendererCurved.h"
+#include "clTabRendererSquare.h"
 
 #if defined(WXUSINGDLL_CL) || defined(USE_SFTP) || defined(PLUGINS_DIR)
 #define CL_BUILD 1
 #endif
 
-#ifdef __WXMSW__
-int clTabInfo::Y_SPACER = 3;
-#else
-int clTabInfo::Y_SPACER = 3;
-#endif
-
-int clTabInfo::X_SPACER = 5;
-int clTabInfo::BOTTOM_AREA_HEIGHT = 3;
-int clTabInfo::MAJOR_CURVE_WIDTH = 15;
-int clTabInfo::SMALL_CURVE_WIDTH = 4;
-// int clTabInfo::TAB_HEIGHT = 30;
-static int OVERLAP_WIDTH = 20;
-static int V_OVERLAP_WIDTH = 3;
-
 #if CL_BUILD
+#include "file_logger.h"
 #include "cl_command_event.h"
 #include "event_notifier.h"
 #include "codelite_events.h"
 #include "drawingutils.h"
+#include "editor_config.h"
 #endif
 
 wxDEFINE_EVENT(wxEVT_BOOK_PAGE_CHANGING, wxBookCtrlEvent);
@@ -45,20 +35,16 @@ wxDEFINE_EVENT(wxEVT_BOOK_PAGE_CLOSE_BUTTON, wxBookCtrlEvent);
 wxDEFINE_EVENT(wxEVT_BOOK_TAB_DCLICKED, wxBookCtrlEvent);
 wxDEFINE_EVENT(wxEVT_BOOK_NAVIGATING, wxBookCtrlEvent);
 wxDEFINE_EVENT(wxEVT_BOOK_TABAREA_DCLICKED, wxBookCtrlEvent);
-
-#define IS_VERTICAL_TABS(style) ((style & kNotebook_RightTabs) || (style & kNotebook_LeftTabs))
+wxDEFINE_EVENT(wxEVT_BOOK_TAB_CONTEXT_MENU, wxBookCtrlEvent);
 
 extern void Notebook_Init_Bitmaps();
 
-Notebook::Notebook(wxWindow* parent,
-                   wxWindowID id,
-                   const wxPoint& pos,
-                   const wxSize& size,
-                   long style,
-                   const wxString& name)
+Notebook::Notebook(
+    wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name)
     : wxPanel(parent, id, pos, size, wxNO_BORDER | wxWANTS_CHARS | wxTAB_TRAVERSAL, name)
 {
     static bool once = false;
+
     if(!once) {
         // Add PNG and Bitmap handler
         wxImage::AddHandler(new wxPNGHandler);
@@ -67,12 +53,18 @@ Notebook::Notebook(wxWindow* parent,
         once = true;
     }
 
-    wxBoxSizer* sizer = new wxBoxSizer(wxVERTICAL);
-    SetSizer(sizer);
-
     m_tabCtrl = new clTabCtrl(this, style);
     m_windows = new WindowStack(this);
 
+    wxBoxSizer* sizer;
+    if(IsVerticalTabs()) {
+        sizer = new wxBoxSizer(wxHORIZONTAL);
+    } else {
+        sizer = new wxBoxSizer(wxVERTICAL);
+    }
+
+    SetSizer(sizer);
+
     if(GetStyle() & kNotebook_BottomTabs) {
         sizer->Add(m_windows, 1, wxEXPAND);
         sizer->Add(m_tabCtrl, 0, wxEXPAND);
@@ -88,7 +80,7 @@ Notebook::~Notebook() {}
 
 void Notebook::AddPage(wxWindow* page, const wxString& label, bool selected, const wxBitmap& bmp)
 {
-    clTabInfo::Ptr_t tab(new clTabInfo(GetStyle(), page, label, bmp));
+    clTabInfo::Ptr_t tab(new clTabInfo(m_tabCtrl, GetStyle(), page, label, bmp));
     tab->SetActive(selected, GetStyle());
     m_tabCtrl->AddPage(tab);
 }
@@ -97,7 +89,7 @@ void Notebook::DoChangeSelection(wxWindow* page) { m_windows->Select(page); }
 
 bool Notebook::InsertPage(size_t index, wxWindow* page, const wxString& label, bool selected, const wxBitmap& bmp)
 {
-    clTabInfo::Ptr_t tab(new clTabInfo(GetStyle(), page, label, bmp));
+    clTabInfo::Ptr_t tab(new clTabInfo(m_tabCtrl, GetStyle(), page, label, bmp));
     tab->SetActive(selected, GetStyle());
     return m_tabCtrl->InsertPage(index, tab);
 }
@@ -159,7 +151,11 @@ void Notebook::SetTabDirection(wxDirection d)
     flags &= ~kNotebook_BottomTabs;
     flags &= ~kNotebook_LeftTabs;
     flags &= ~kNotebook_RightTabs;
-
+#if 0
+    if(d == wxBOTTOM || d == wxRIGHT) {
+        flags |= kNotebook_BottomTabs;
+    }
+#else
     if(d == wxBOTTOM) {
         flags |= kNotebook_BottomTabs;
     } else if(d == wxRIGHT) {
@@ -167,356 +163,8 @@ void Notebook::SetTabDirection(wxDirection d)
     } else if(d == wxLEFT) {
         flags |= kNotebook_LeftTabs;
     }
-    SetStyle(flags);
-}
-
-//----------------------------------------------------------
-// Tab label
-//----------------------------------------------------------
-void clTabInfo::Draw(wxDC& dc, const clTabInfo::Colours& colours, size_t style)
-{
-    const int TOP_SMALL_HEIGHT = 2;
-    wxColour bgColour(IsActive() ? colours.activeTabBgColour : colours.inactiveTabBgColour);
-    wxColour penColour(IsActive() ? colours.activeTabPenColour : colours.inactiveTabPenColour);
-    wxFont font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-    dc.SetTextForeground(IsActive() ? colours.activeTabTextColour : colours.inactiveTabTextColour);
-    dc.SetFont(font);
-
-    if(style & kNotebook_BottomTabs) {
-        // Bottom tabs
-        {
-            wxPoint points[6];
-            points[0] = m_rect.GetTopLeft();
-
-            points[1].x = points[0].x + MAJOR_CURVE_WIDTH;
-            points[1].y = m_rect.GetBottomLeft().y - TOP_SMALL_HEIGHT;
-
-            points[2].x = points[1].x + SMALL_CURVE_WIDTH;
-            points[2].y = points[1].y + TOP_SMALL_HEIGHT;
-
-            points[3].x = points[0].x + (m_rect.GetWidth() - (MAJOR_CURVE_WIDTH + SMALL_CURVE_WIDTH));
-            points[3].y = points[2].y;
-
-            points[4].x = points[3].x + SMALL_CURVE_WIDTH;
-            points[4].y = points[1].y;
-
-            points[5] = m_rect.GetTopRight();
-
-            dc.SetPen(penColour);
-            dc.SetBrush(bgColour);
-            dc.DrawPolygon(6, points);
-        }
-        {
-            wxPoint points[6];
-            points[0] = m_rect.GetTopLeft();
-            points[0].x += 1;
-
-            points[1].x = points[0].x + MAJOR_CURVE_WIDTH;
-            points[1].y = m_rect.GetBottomLeft().y - TOP_SMALL_HEIGHT - 1;
-
-            points[2].x = points[1].x + SMALL_CURVE_WIDTH;
-            points[2].y = points[1].y + TOP_SMALL_HEIGHT;
-
-            points[3].x = points[0].x + (m_rect.GetWidth() - 2 - (MAJOR_CURVE_WIDTH + SMALL_CURVE_WIDTH));
-            points[3].y = points[2].y;
-
-            points[4].x = points[3].x + SMALL_CURVE_WIDTH;
-            points[4].y = points[1].y;
-
-            points[5] = m_rect.GetTopRight();
-            points[5].x -= 2;
-
-            dc.SetPen(IsActive() ? colours.activeTabInnerPenColour : colours.inactiveTabInnerPenColour);
-            dc.SetBrush(bgColour);
-            dc.DrawPolygon(6, points);
-        }
-    } else if(IS_VERTICAL_TABS(style)) {
-
-        // Left side tabs
-        wxRect rotatedRect(0, 0, m_rect.GetHeight(), m_rect.GetWidth());
-        wxBitmap b(rotatedRect.GetSize());
-
-        wxMemoryDC tmpDC(b);
-        tmpDC.SetPen(colours.tabAreaColour);
-        tmpDC.SetBrush(colours.tabAreaColour);
-        tmpDC.DrawRectangle(rotatedRect);
-        tmpDC.SetFont(font);
-        tmpDC.SetTextForeground(IsActive() ? colours.activeTabTextColour : colours.inactiveTabTextColour);
-
-        tmpDC.SetPen(penColour);
-        tmpDC.SetBrush(bgColour);
-        if(IsActive()) {
-            {
-                wxPoint points[6];
-                points[0] = rotatedRect.GetBottomLeft();
-
-                points[1].x = points[0].x + MAJOR_CURVE_WIDTH;
-                points[1].y = rotatedRect.GetLeftTop().y + TOP_SMALL_HEIGHT;
-
-                points[2].x = points[1].x + SMALL_CURVE_WIDTH;
-                points[2].y = points[1].y - TOP_SMALL_HEIGHT;
-
-                points[3].x = points[0].x + (rotatedRect.GetWidth() - (MAJOR_CURVE_WIDTH + SMALL_CURVE_WIDTH));
-                points[3].y = points[2].y;
-
-                points[4].x = points[3].x + SMALL_CURVE_WIDTH;
-                points[4].y = points[3].y + TOP_SMALL_HEIGHT;
-
-                points[5] = rotatedRect.GetBottomRight();
-
-                tmpDC.SetPen(penColour);
-                tmpDC.SetBrush(bgColour);
-                tmpDC.DrawPolygon(6, points);
-            }
-
-            {
-                wxPoint points[6];
-                points[0] = rotatedRect.GetBottomLeft();
-                points[0].x += 1;
-
-                points[1].x = points[0].x + MAJOR_CURVE_WIDTH;
-                points[1].y = rotatedRect.GetLeftTop().y + TOP_SMALL_HEIGHT + 1;
-
-                points[2].x = points[1].x + SMALL_CURVE_WIDTH;
-                points[2].y = points[1].y - TOP_SMALL_HEIGHT;
-
-                points[3].x = points[0].x + (rotatedRect.GetWidth() - 2 - (MAJOR_CURVE_WIDTH + SMALL_CURVE_WIDTH));
-                points[3].y = points[2].y;
-
-                points[4].x = points[3].x + SMALL_CURVE_WIDTH;
-                points[4].y = points[3].y + TOP_SMALL_HEIGHT;
-
-                points[5] = rotatedRect.GetBottomRight();
-                points[5].x -= 2;
-
-                tmpDC.SetPen(IsActive() ? colours.activeTabInnerPenColour : colours.inactiveTabInnerPenColour);
-                tmpDC.SetBrush(bgColour);
-                tmpDC.DrawPolygon(6, points);
-            }
-        } else {
-            // Inactive tabs
-            wxDirection direction = wxNORTH;
-            wxPoint basePoint = ((style & kNotebook_LeftTabs) ? rotatedRect.GetLeftTop() : rotatedRect.GetRightTop());
-            {
-                wxPoint pt = basePoint;
-                pt.x -= 1;
-                wxRect gr(pt, wxSize(1, rotatedRect.GetHeight()));
-                tmpDC.SetPen(*wxTRANSPARENT_PEN);
-                tmpDC.GradientFillLinear(gr, colours.inactiveTabPenColour, bgColour, direction);
-            }
-            {
-                wxPoint pt = basePoint;
-                wxRect gr(pt, wxSize(1, rotatedRect.GetHeight()));
-                tmpDC.SetPen(*wxTRANSPARENT_PEN);
-                tmpDC.GradientFillLinear(gr, colours.inactiveTabInnerPenColour, bgColour, direction);
-            }
-            {
-                wxPoint pt = basePoint;
-                pt.x += 1;
-                wxRect gr(pt, wxSize(1, rotatedRect.GetHeight()));
-                tmpDC.SetPen(*wxTRANSPARENT_PEN);
-                tmpDC.GradientFillLinear(gr, colours.inactiveTabPenColour, bgColour, direction);
-            }
-        }
-
-        // Vertical tabs
-        // Draw bitmap
-        if(m_bitmap.IsOk()) {
-            tmpDC.DrawBitmap(m_bitmap, m_bmpY, m_bmpX);
-        }
-
-        tmpDC.DrawText(m_label, m_textY, m_textX);
-        if(IsActive() && (style & kNotebook_CloseButtonOnActiveTab)) {
-            tmpDC.DrawBitmap(colours.closeButton, m_bmpCloseY, m_bmpCloseX);
-        }
-        tmpDC.SelectObject(wxNullBitmap);
-        wxImage img = b.ConvertToImage();
-        img = img.Rotate90((style & kNotebook_RightTabs));
-        b = wxBitmap(img);
-        dc.DrawBitmap(b, m_rect.GetTopLeft());
-
-    } else {
-        // Default tabs (placed at the top)
-        {
-            wxPoint points[6];
-            points[0] = m_rect.GetBottomLeft();
-
-            points[1].x = points[0].x + MAJOR_CURVE_WIDTH;
-            points[1].y = m_rect.GetLeftTop().y + TOP_SMALL_HEIGHT;
-
-            points[2].x = points[1].x + SMALL_CURVE_WIDTH;
-            points[2].y = points[1].y - TOP_SMALL_HEIGHT;
-
-            points[3].x = points[0].x + (m_rect.GetWidth() - (MAJOR_CURVE_WIDTH + SMALL_CURVE_WIDTH));
-            points[3].y = points[2].y;
-
-            points[4].x = points[3].x + SMALL_CURVE_WIDTH;
-            points[4].y = points[3].y + TOP_SMALL_HEIGHT;
-
-            points[5] = m_rect.GetBottomRight();
-
-            dc.SetPen(penColour);
-            dc.SetBrush(bgColour);
-            dc.DrawPolygon(6, points);
-        }
-
-        {
-            wxPoint points[6];
-            points[0] = m_rect.GetBottomLeft();
-            points[0].x += 1;
-
-            points[1].x = points[0].x + MAJOR_CURVE_WIDTH;
-            points[1].y = m_rect.GetLeftTop().y + TOP_SMALL_HEIGHT + 1;
-
-            points[2].x = points[1].x + SMALL_CURVE_WIDTH;
-            points[2].y = points[1].y - TOP_SMALL_HEIGHT;
-
-            points[3].x = points[0].x + (m_rect.GetWidth() - 2 - (MAJOR_CURVE_WIDTH + SMALL_CURVE_WIDTH));
-            points[3].y = points[2].y;
-
-            points[4].x = points[3].x + SMALL_CURVE_WIDTH;
-            points[4].y = points[3].y + TOP_SMALL_HEIGHT;
-
-            points[5] = m_rect.GetBottomRight();
-            points[5].x -= 2;
-
-            dc.SetPen(IsActive() ? colours.activeTabInnerPenColour : colours.inactiveTabInnerPenColour);
-            dc.SetBrush(bgColour);
-            dc.DrawPolygon(6, points);
-        }
-    }
-
-    if(!IS_VERTICAL_TABS(style)) {
-        // Draw bitmap
-        if(m_bitmap.IsOk()) {
-            dc.DrawBitmap(m_bitmap, m_bmpX + m_rect.GetX(), m_bmpY);
-        }
-        dc.DrawText(m_label, m_textX + m_rect.GetX(), m_textY);
-        if(IsActive() && (style & kNotebook_CloseButtonOnActiveTab)) {
-            dc.DrawBitmap(colours.closeButton, m_bmpCloseX + m_rect.GetX(), m_bmpCloseY);
-        }
-    }
-}
-
-clTabInfo::clTabInfo(size_t style, wxWindow* page, const wxString& text, const wxBitmap& bmp)
-    : m_label(text)
-    , m_bitmap(bmp)
-    , m_window(page)
-    , m_active(false)
-{
-    CalculateOffsets(style);
-}
-
-clTabInfo::clTabInfo()
-    : m_window(NULL)
-    , m_active(false)
-    , m_textX(wxNOT_FOUND)
-    , m_textY(wxNOT_FOUND)
-    , m_bmpX(wxNOT_FOUND)
-    , m_bmpY(wxNOT_FOUND)
-    , m_bmpCloseX(wxNOT_FOUND)
-    , m_bmpCloseY(wxNOT_FOUND)
-{
-
-    CalculateOffsets(0);
-}
-
-void clTabInfo::CalculateOffsets(size_t style)
-{
-    wxBitmap b(1, 1);
-    wxMemoryDC memDC(b);
-    m_bmpCloseX = wxNOT_FOUND;
-    m_bmpCloseY = wxNOT_FOUND;
-
-    wxFont font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-    memDC.SetFont(font);
-
-    wxSize sz = memDC.GetTextExtent(m_label);
-    wxSize fixedHeight = memDC.GetTextExtent("Tp");
-    if(IS_VERTICAL_TABS(style)) {
-        m_height = fixedHeight.GetHeight() + (5 * Y_SPACER);
-    } else {
-        m_height = fixedHeight.GetHeight() + (4 * Y_SPACER);
-    }
-
-#ifdef __WXGTK__
-    // On GTK, limit the tab height
-    if(m_height >= 30) {
-        m_height = 30;
-    }
 #endif
-
-    m_width = 0;
-    if(!IS_VERTICAL_TABS(style) || true) {
-        m_width += MAJOR_CURVE_WIDTH;
-        m_width += SMALL_CURVE_WIDTH;
-    }
-    m_width += X_SPACER;
-
-    // bitmap
-    m_bmpX = wxNOT_FOUND;
-    m_bmpY = wxNOT_FOUND;
-
-    if(m_bitmap.IsOk()) {
-        m_bmpX = m_width;
-        m_width += X_SPACER;
-        m_width += m_bitmap.GetWidth();
-        m_bmpY = ((m_height - m_bitmap.GetHeight()) / 2);
-    }
-
-    // Text
-    m_textX = m_width;
-    m_textY = ((m_height - sz.y) / 2);
-    m_width += sz.x;
-
-    // x button
-    if((style & kNotebook_CloseButtonOnActiveTab)) {
-        m_width += X_SPACER;
-        m_bmpCloseX = m_width;
-        m_bmpCloseY = ((m_height - 12) / 2);
-        m_width += 12; // X button is 10 pixels in size
-    }
-
-    m_width += X_SPACER;
-    if(!IS_VERTICAL_TABS(style) || true) {
-        m_width += MAJOR_CURVE_WIDTH;
-        m_width += SMALL_CURVE_WIDTH;
-    }
-
-    // Update the rect width
-    m_rect.SetWidth(m_width);
-
-    if((style & kNotebook_RightTabs) || (style & kNotebook_LeftTabs)) {
-
-        // swap the x and y coordinates
-        wxSwap(m_height, m_width);
-        wxSwap(m_bmpCloseY, m_bmpCloseX);
-        wxSwap(m_bmpY, m_bmpX);
-        wxSwap(m_textX, m_textY);
-
-        m_rect.SetWidth(m_width);
-        m_rect.SetHeight(m_height);
-        m_rect.SetX(0);
-        m_rect.SetY(0);
-    }
-}
-
-void clTabInfo::SetBitmap(const wxBitmap& bitmap, size_t style)
-{
-    this->m_bitmap = bitmap;
-    CalculateOffsets(style);
-}
-
-void clTabInfo::SetLabel(const wxString& label, size_t style)
-{
-    this->m_label = label;
-    CalculateOffsets(style);
-}
-
-void clTabInfo::SetActive(bool active, size_t style)
-{
-    this->m_active = active;
-    CalculateOffsets(style);
+    SetStyle(flags);
 }
 
 //----------------------------------------------------------
@@ -532,33 +180,24 @@ clTabCtrl::clTabCtrl(wxWindow* notebook, size_t style)
     , m_closeButtonClickedIndex(wxNOT_FOUND)
     , m_contextMenu(NULL)
 {
-    wxBitmap bmp(1, 1);
-    wxMemoryDC memDC(bmp);
-    wxFont font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-    memDC.SetFont(font);
-
-    wxSize sz = memDC.GetTextExtent("Tp");
-    m_height = sz.GetHeight() + (4 * clTabInfo::Y_SPACER);
-    m_vTabsWidth = sz.GetHeight() + (5 * clTabInfo::Y_SPACER);
-#ifdef __WXGTK__
-    // On GTK, limit the tab height
-    if(m_height >= 30) {
-        m_height = 30;
-    }
-#endif
-    SetDropTarget(new clTabCtrlDropTarget(this));
-    if(IsVerticalTabs()) {
-        SetSizeHints(wxSize(m_vTabsWidth, -1));
-        SetSize(m_vTabsWidth, -1);
+    SetBackgroundStyle(wxBG_STYLE_PAINT);
+#if CL_BUILD
+    if(EditorConfigST::Get()->GetOptions()->GetOptions() & OptionsConfig::Opt_TabStyleMinimal) {
+        m_art.reset(new clTabRendererSquare);
     } else {
-        SetSizeHints(wxSize(-1, m_height));
-        SetSize(-1, m_height);
+        m_art.reset(new clTabRendererCurved);
     }
+#else
+    m_art.reset(new clTabRendererCurved); // Default art
+#endif
+    DoSetBestSize();
 
+    SetDropTarget(new clTabCtrlDropTarget(this));
     Bind(wxEVT_PAINT, &clTabCtrl::OnPaint, this);
     Bind(wxEVT_ERASE_BACKGROUND, &clTabCtrl::OnEraseBG, this);
     Bind(wxEVT_SIZE, &clTabCtrl::OnSize, this);
     Bind(wxEVT_LEFT_DOWN, &clTabCtrl::OnLeftDown, this);
+    Bind(wxEVT_RIGHT_UP, &clTabCtrl::OnRightUp, this);
     Bind(wxEVT_LEFT_UP, &clTabCtrl::OnLeftUp, this);
     Bind(wxEVT_MOTION, &clTabCtrl::OnMouseMotion, this);
     Bind(wxEVT_MIDDLE_UP, &clTabCtrl::OnMouseMiddleClick, this);
@@ -576,6 +215,32 @@ clTabCtrl::clTabCtrl(wxWindow* notebook, size_t style)
     m_history.reset(new clTabHistory());
 }
 
+void clTabCtrl::DoSetBestSize()
+{
+    wxBitmap bmp(1, 1);
+    wxMemoryDC memDC(bmp);
+    wxFont font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
+    memDC.SetFont(font);
+
+    wxSize sz = memDC.GetTextExtent("Tp");
+
+    m_height = sz.GetHeight() + (4 * GetArt()->ySpacer);
+    m_vTabsWidth = sz.GetHeight() + (5 * GetArt()->ySpacer);
+#ifdef __WXGTK__
+    // On GTK, limit the tab height
+    if(m_height >= 30) {
+        m_height = 30;
+    }
+#endif
+    if(IsVerticalTabs()) {
+        SetSizeHints(wxSize(m_vTabsWidth, -1));
+        SetSize(m_vTabsWidth, -1);
+    } else {
+        SetSizeHints(wxSize(-1, m_height));
+        SetSize(-1, m_height);
+    }
+}
+
 bool clTabCtrl::ShiftRight(clTabInfo::Vec_t& tabs)
 {
     // Move the first tab from the list and adjust the remainder
@@ -587,7 +252,7 @@ bool clTabCtrl::ShiftRight(clTabInfo::Vec_t& tabs)
 
         for(size_t i = 0; i < tabs.size(); ++i) {
             clTabInfo::Ptr_t t = tabs.at(i);
-            t->GetRect().SetX(t->GetRect().x - width + OVERLAP_WIDTH);
+            t->GetRect().SetX(t->GetRect().x - width + GetArt()->overlapWidth);
         }
         return true;
     }
@@ -626,6 +291,7 @@ clTabCtrl::~clTabCtrl()
     Unbind(wxEVT_ERASE_BACKGROUND, &clTabCtrl::OnEraseBG, this);
     Unbind(wxEVT_SIZE, &clTabCtrl::OnSize, this);
     Unbind(wxEVT_LEFT_DOWN, &clTabCtrl::OnLeftDown, this);
+    Unbind(wxEVT_RIGHT_UP, &clTabCtrl::OnRightUp, this);
     Unbind(wxEVT_LEFT_UP, &clTabCtrl::OnLeftUp, this);
     Unbind(wxEVT_MOTION, &clTabCtrl::OnMouseMotion, this);
     Unbind(wxEVT_MIDDLE_UP, &clTabCtrl::OnMouseMiddleClick, this);
@@ -638,11 +304,19 @@ clTabCtrl::~clTabCtrl()
 void clTabCtrl::OnWindowKeyDown(wxKeyEvent& event)
 {
     if(GetStyle() & kNotebook_EnableNavigationEvent) {
-        if(event.ControlDown()) {
-            switch(event.GetKeyCode()) {
+#ifdef __WXOSX__
+        if(event.AltDown())
+#else
+        if(event.CmdDown())
+#endif
+        {
+            switch(event.GetUnicodeKey()) {
             case WXK_TAB:
             case WXK_PAGEDOWN:
             case WXK_PAGEUP: {
+#if CL_BUILD
+                CL_DEBUG("Firing navigation event");
+#endif
                 // Fire the navigation event
                 wxBookCtrlEvent e(wxEVT_BOOK_NAVIGATING);
                 e.SetEventObject(GetParent());
@@ -668,7 +342,9 @@ void clTabCtrl::OnEraseBG(wxEraseEvent& e) { wxUnusedVar(e); }
 
 void clTabCtrl::OnPaint(wxPaintEvent& e)
 {
-    wxBufferedPaintDC dc(this);
+    wxAutoBufferedPaintDC dc(this);
+    PrepareDC(dc);
+
     wxRect clientRect(GetClientRect());
     if(clientRect.width <= 3) return;
     if(clientRect.height <= 3) return;
@@ -679,13 +355,13 @@ void clTabCtrl::OnPaint(wxPaintEvent& e)
     if((GetStyle() & kNotebook_ShowFileListButton)) {
         if(IsVerticalTabs()) {
             rect.SetHeight(rect.GetHeight() - 16);
-            m_chevronRect = wxRect(rect.GetBottomLeft(), wxSize(rect.GetWidth(), 20));
+            m_chevronRect = wxRect(rect.GetTopLeft(), wxSize(rect.GetWidth(), 20));
             if(GetStyle() & kNotebook_RightTabs) {
-                m_chevronRect.x += clTabInfo::BOTTOM_AREA_HEIGHT;
+                m_chevronRect.x += GetArt()->bottomAreaHeight;
             } else {
                 m_chevronRect.x -= 2;
             }
-            m_chevronRect.SetWidth(m_chevronRect.GetWidth() - clTabInfo::BOTTOM_AREA_HEIGHT);
+            m_chevronRect.SetWidth(m_chevronRect.GetWidth() - GetArt()->bottomAreaHeight);
             rect.SetHeight(rect.GetHeight() + 16);
         } else {
             // Reduce the length of the tabs bitmap by 16 pixels (we will draw there the drop down
@@ -693,9 +369,9 @@ void clTabCtrl::OnPaint(wxPaintEvent& e)
             rect.SetWidth(rect.GetWidth() - 16);
             m_chevronRect = wxRect(rect.GetTopRight(), wxSize(20, rect.GetHeight()));
             if(GetStyle() & kNotebook_BottomTabs) {
-                m_chevronRect.y += clTabInfo::BOTTOM_AREA_HEIGHT;
+                m_chevronRect.y += GetArt()->bottomAreaHeight;
             }
-            m_chevronRect.SetHeight(m_chevronRect.GetHeight() - clTabInfo::BOTTOM_AREA_HEIGHT);
+            m_chevronRect.SetHeight(m_chevronRect.GetHeight() - GetArt()->bottomAreaHeight);
             rect.SetWidth(rect.GetWidth() + 16);
         }
     }
@@ -711,7 +387,7 @@ void clTabCtrl::OnPaint(wxPaintEvent& e)
     // Draw the tab area background colours
     clTabInfo::Ptr_t active_tab = GetActiveTabInfo();
     wxColour tabAreaBgCol = m_colours.tabAreaColour;
-    clTabInfo::Colours activeTabColours = m_colours;
+    clTabColours activeTabColours = m_colours;
 
 #if CL_BUILD
     if(active_tab && (GetStyle() & kNotebook_EnableColourCustomization)) {
@@ -738,6 +414,7 @@ void clTabCtrl::OnPaint(wxPaintEvent& e)
         // wxBitmap bmpTabs(rect.GetSize());
         // wxMemoryDC memDC(bmpTabs);
         wxGCDC gcdc(dc);
+        PrepareDC(gcdc);
 
         gcdc.SetPen(tabAreaBgCol);
         gcdc.SetBrush(tabAreaBgCol);
@@ -757,20 +434,22 @@ void clTabCtrl::OnPaint(wxPaintEvent& e)
             clColourEvent colourEvent(wxEVT_COLOUR_TAB);
             colourEvent.SetPage(tab->GetWindow());
             if((GetStyle() & kNotebook_EnableColourCustomization) && EventNotifier::Get()->ProcessEvent(colourEvent)) {
-                clTabInfo::Colours colours;
+                clTabColours colours;
                 colours.InitFromColours(colourEvent.GetBgColour(), colourEvent.GetFgColour());
-                tab->Draw(gcdc, colours, m_style);
+                m_art->Draw(gcdc, *tab.get(), colours, m_style);
             } else {
-                tab->Draw(gcdc, m_colours, m_style);
+                m_art->Draw(gcdc, *tab.get(), m_colours, m_style);
             }
+
 #else
-            tab->Draw(gcdc, m_colours, m_style);
+            m_art->Draw(gcdc, *tab.get(), m_colours, m_style);
 #endif
         }
 
         // Redraw the active tab
         if(activeTabInex != wxNOT_FOUND) {
-            m_visibleTabs.at(activeTabInex)->Draw(gcdc, activeTabColours, m_style);
+            clTabInfo::Ptr_t activeTab = m_visibleTabs.at(activeTabInex);
+            m_art->Draw(gcdc, *activeTab.get(), activeTabColours, m_style);
         }
 
         if(activeTabInex != wxNOT_FOUND) {
@@ -782,10 +461,10 @@ void clTabCtrl::OnPaint(wxPaintEvent& e)
 
         if((GetStyle() & kNotebook_ShowFileListButton)) {
             // Draw the chevron
-            wxCoord chevronX =
-                m_chevronRect.GetTopLeft().x + ((m_chevronRect.GetWidth() - m_colours.chevronDown.GetWidth()) / 2);
-            wxCoord chevronY =
-                m_chevronRect.GetTopLeft().y + ((m_chevronRect.GetHeight() - m_colours.chevronDown.GetHeight()) / 2);
+            wxCoord chevronX = m_chevronRect.GetTopLeft().x +
+                ((m_chevronRect.GetWidth() - m_colours.chevronDown.GetScaledHeight()) / 2);
+            wxCoord chevronY = m_chevronRect.GetTopLeft().y +
+                ((m_chevronRect.GetHeight() - m_colours.chevronDown.GetScaledHeight()) / 2);
             // dc.SetPen(activeTabColours.tabAreaColour);
             // dc.SetBrush(*wxTRANSPARENT_BRUSH);
             // dc.DrawRectangle(m_chevronRect);
@@ -799,7 +478,7 @@ void clTabCtrl::OnPaint(wxPaintEvent& e)
 
 void clTabCtrl::DoUpdateCoordiantes(clTabInfo::Vec_t& tabs)
 {
-    int majorDimension = 5;
+    int majorDimension = GetArt()->majorCurveWidth ? 5 : 0;
     if(IsVerticalTabs()) {
         majorDimension = 0;
     }
@@ -815,13 +494,13 @@ void clTabCtrl::DoUpdateCoordiantes(clTabInfo::Vec_t& tabs)
             tab->GetRect().SetY(majorDimension);
             tab->GetRect().SetWidth(tab->GetWidth());
             tab->GetRect().SetHeight(tab->GetHeight());
-            majorDimension += tab->GetHeight() - V_OVERLAP_WIDTH;
+            majorDimension += tab->GetHeight() - GetArt()->verticalOverlapWidth;
         } else {
             tab->GetRect().SetX(majorDimension);
             tab->GetRect().SetY(0);
             tab->GetRect().SetWidth(tab->GetWidth());
             tab->GetRect().SetHeight(tab->GetHeight());
-            majorDimension += tab->GetWidth() - OVERLAP_WIDTH;
+            majorDimension += tab->GetWidth() - GetArt()->overlapWidth;
         }
     }
 }
@@ -1163,88 +842,6 @@ wxWindow* clTabCtrl::GetPage(size_t index) const
 
 bool clTabCtrl::IsIndexValid(size_t index) const { return (index < m_tabs.size()); }
 
-clTabInfo::Colours::Colours() { InitDarkColours(); }
-
-void clTabInfo::Colours::InitFromColours(const wxColour& baseColour, const wxColour& textColour)
-{
-#if CL_BUILD
-    if(DrawingUtils::IsDark(baseColour)) {
-        activeTabTextColour = "WHITE";
-        activeTabBgColour = baseColour;
-        activeTabPenColour = baseColour.ChangeLightness(80);
-        activeTabInnerPenColour = baseColour.ChangeLightness(120);
-
-        inactiveTabTextColour = "WHITE";
-        inactiveTabBgColour = baseColour.ChangeLightness(110);
-        inactiveTabPenColour = inactiveTabBgColour.ChangeLightness(80);
-        inactiveTabInnerPenColour = inactiveTabBgColour.ChangeLightness(120);
-
-        tabAreaColour = baseColour.ChangeLightness(130);
-        // 12x12 bitmap
-        closeButton = wxXmlResource::Get()->LoadBitmap("notebook-dark-x");
-        chevronDown = wxXmlResource::Get()->LoadBitmap("chevron-down-grey");
-    } else {
-        activeTabTextColour = "BLACK";
-        activeTabBgColour = baseColour;
-        activeTabPenColour = baseColour.ChangeLightness(80);
-        activeTabInnerPenColour = "WHITE";
-
-        inactiveTabTextColour = "BLACK";
-        inactiveTabBgColour = baseColour.ChangeLightness(90);
-        inactiveTabPenColour = inactiveTabBgColour.ChangeLightness(80);
-        inactiveTabInnerPenColour = baseColour;
-
-        tabAreaColour = baseColour.ChangeLightness(130);
-        // 12x12 bitmap
-        closeButton = wxXmlResource::Get()->LoadBitmap("notebook-light-x");
-        chevronDown = wxXmlResource::Get()->LoadBitmap("chevron-down-black");
-    }
-#else
-    wxUnusedVar(baseColour);
-    wxUnusedVar(textColour);
-#endif
-}
-
-void clTabInfo::Colours::InitDarkColours()
-{
-    activeTabTextColour = "WHITE";
-    activeTabBgColour = wxColour("#211e1e");
-    activeTabPenColour = wxColour("#0e0d0d");
-    activeTabInnerPenColour = wxColour("#343131");
-
-    inactiveTabTextColour = wxColour("rgb(200, 200, 200)");
-    inactiveTabBgColour = wxColour("#393838");
-    inactiveTabPenColour = wxColour("#100f0f");
-    inactiveTabInnerPenColour = wxColour("#535252");
-
-    tabAreaColour = wxColour("#131111").ChangeLightness(115);
-    // 12x12 bitmap
-    closeButton = wxXmlResource::Get()->LoadBitmap("notebook-dark-x");
-    chevronDown = wxXmlResource::Get()->LoadBitmap("chevron-down-grey");
-}
-
-void clTabInfo::Colours::InitLightColours()
-{
-    activeTabTextColour = "#444444";
-    activeTabPenColour = "#b9b9b9";
-    activeTabInnerPenColour = "#ffffff";
-
-    inactiveTabTextColour = "#444444";
-//#ifdef __WXMSW__
-//    activeTabBgColour = "#FBFBFB";
-//#else
-    activeTabBgColour = "#f0f0f0";
-//#endif
-    inactiveTabBgColour = "#e5e5e5";
-    inactiveTabPenColour = "#b9b9b9";
-    inactiveTabInnerPenColour = "#ffffff";
-
-    tabAreaColour = "#dcdcdc"; // wxColour("rgb(64, 64, 64)");
-    // 12x12 bitmap
-    closeButton = wxXmlResource::Get()->LoadBitmap("notebook-light-x");
-    chevronDown = wxXmlResource::Get()->LoadBitmap("chevron-down-black");
-}
-
 int clTabCtrl::FindPage(wxWindow* page) const
 {
     for(size_t i = 0; i < m_tabs.size(); ++i) {
@@ -1293,9 +890,9 @@ bool clTabCtrl::RemovePage(size_t page, bool notify, bool deletePage)
         for(; iter != m_visibleTabs.end(); ++iter) {
             // update the remainding tabs coordinates
             if(IsVerticalTabs()) {
-                (*iter)->GetRect().SetY((*iter)->GetRect().GetY() - tab->GetHeight() + V_OVERLAP_WIDTH);
+                (*iter)->GetRect().SetY((*iter)->GetRect().GetY() - tab->GetHeight() + GetArt()->verticalOverlapWidth);
             } else {
-                (*iter)->GetRect().SetX((*iter)->GetRect().GetX() - tab->GetWidth() + OVERLAP_WIDTH);
+                (*iter)->GetRect().SetX((*iter)->GetRect().GetX() - tab->GetWidth() + GetArt()->overlapWidth);
             }
         }
     }
@@ -1414,16 +1011,23 @@ void clTabCtrl::SetMenu(wxMenu* menu)
 void clTabCtrl::OnContextMenu(wxContextMenuEvent& event)
 {
     event.Skip();
-    if(!m_contextMenu) return;
 
     wxPoint pt = ::wxGetMousePosition();
     pt = ScreenToClient(pt);
     int realPos, tabHit;
     TestPoint(pt, realPos, tabHit);
 
-    if((realPos != wxNOT_FOUND) && (realPos == GetSelection())) {
+    if((realPos != wxNOT_FOUND)) {
         // Show context menu for active tabs only
-        PopupMenu(m_contextMenu);
+        if(m_contextMenu && (realPos == GetSelection())) {
+            PopupMenu(m_contextMenu);
+        } else {
+            // fire an event for the selected tab
+            wxBookCtrlEvent menuEvent(wxEVT_BOOK_TAB_CONTEXT_MENU);
+            menuEvent.SetEventObject(this);
+            menuEvent.SetSelection(realPos);
+            GetParent()->GetEventHandler()->ProcessEvent(menuEvent);
+        }
     }
 }
 
@@ -1618,139 +1222,10 @@ void clTabCtrl::OnLeftDClick(wxMouseEvent& event)
     }
 }
 
-void clTabCtrl::DoDrawBottomBox(clTabInfo::Ptr_t activeTab,
-                                const wxRect& clientRect,
-                                wxDC& dc,
-                                const clTabInfo::Colours& colours)
+void clTabCtrl::DoDrawBottomBox(
+    clTabInfo::Ptr_t activeTab, const wxRect& clientRect, wxDC& dc, const clTabColours& colours)
 {
-    if(GetStyle() & kNotebook_LeftTabs) {
-        // Draw 3 lines on the right
-        dc.SetPen(colours.activeTabPenColour);
-        dc.SetBrush(colours.activeTabBgColour);
-        wxPoint topLeft = clientRect.GetTopRight();
-        wxSize rectSize(clTabInfo::BOTTOM_AREA_HEIGHT + 2, clientRect.height);
-        topLeft.x -= clTabInfo::BOTTOM_AREA_HEIGHT;
-        wxRect bottomRect(topLeft, rectSize);
-
-        // We intentionally move the rect out of the client rect
-        // so the top and bottom lines will be drawn out of screen
-        bottomRect.y -= 1;
-        bottomRect.height += 2;
-        dc.DrawRectangle(bottomRect);
-
-        // Draw a line under the active tab
-        // that will erase the line drawn by the above rect
-        wxPoint from, to;
-        from = activeTab->GetRect().GetTopRight();
-        to = activeTab->GetRect().GetBottomRight();
-        from.x = bottomRect.GetTopLeft().x;
-        to.x = bottomRect.GetTopLeft().x;
-        from.y += 2;
-        to.y -= 2;
-        
-        dc.SetPen(colours.activeTabBgColour);
-        dc.DrawLine(from, to);
-#ifdef __WXOSX__
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-#endif
-    } else if(GetStyle() & kNotebook_RightTabs) {
-        // Draw 3 lines on the right
-        dc.SetPen(colours.activeTabPenColour);
-        dc.SetBrush(colours.activeTabBgColour);
-        wxPoint topLeft = clientRect.GetTopLeft();
-        wxSize rectSize(clTabInfo::BOTTOM_AREA_HEIGHT + 2, clientRect.height);
-        wxRect bottomRect(topLeft, rectSize);
-
-        // We intentionally move the rect out of the client rect
-        // so the top and bottom lines will be drawn out of screen
-        bottomRect.y -= 1;
-        bottomRect.height += 2;
-        dc.DrawRectangle(bottomRect);
-
-        // Draw a line under the active tab
-        // that will erase the line drawn by the above rect
-        wxPoint from, to;
-        from = activeTab->GetRect().GetTopLeft();
-        to = activeTab->GetRect().GetBottomLeft();
-        from.x = bottomRect.GetTopRight().x;
-        to.x = bottomRect.GetTopRight().x;
-        from.y += 2;
-        to.y -= 2;
-        
-        dc.SetPen(colours.activeTabBgColour);
-        dc.DrawLine(from, to);
-#ifdef __WXOSX__
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-#endif
-
-    } else if(GetStyle() & kNotebook_BottomTabs) {
-        // Draw 3 lines at the top
-        dc.SetPen(colours.activeTabPenColour);
-        dc.SetBrush(colours.activeTabBgColour);
-        wxPoint topLeft = clientRect.GetTopLeft();
-        wxSize rectSize(clientRect.width, clTabInfo::BOTTOM_AREA_HEIGHT);
-        topLeft.y = 0;
-        wxRect bottomRect(topLeft, rectSize);
-        // We intentionally move the rect out of the client rect
-        // so the left and right lines will be drawn out of screen
-        bottomRect.x -= 1;
-        bottomRect.width += 2;
-        dc.DrawRectangle(bottomRect);
-
-        // Draw a line under the active tab
-        // that will erase the line drawn by the above rect
-        wxPoint from, to;
-        from = activeTab->GetRect().GetTopLeft();
-        to = activeTab->GetRect().GetTopRight();
-        from.y += clTabInfo::BOTTOM_AREA_HEIGHT - 1;
-        from.x += 2;
-        to.y += clTabInfo::BOTTOM_AREA_HEIGHT - 1;
-        to.x -= 2;
-
-        dc.SetPen(colours.activeTabBgColour);
-        dc.DrawLine(from, to);
-#ifdef __WXOSX__
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-#endif
-
-    } else {
-        // Draw 3 lines at the bottom
-        dc.SetPen(colours.activeTabPenColour);
-        dc.SetBrush(colours.activeTabBgColour);
-        wxPoint topLeft = clientRect.GetBottomLeft();
-        wxSize rectSize(clientRect.width, clTabInfo::BOTTOM_AREA_HEIGHT);
-        topLeft.y -= rectSize.GetHeight() - 1;
-        wxRect bottomRect(topLeft, rectSize);
-        // We intentionally move the rect out of the client rect
-        // so the left and right lines will be drawn out of screen
-        bottomRect.x -= 1;
-        bottomRect.width += 2;
-        dc.DrawRectangle(bottomRect);
-
-        // Draw a line under the active tab
-        // that will erase the line drawn by the above rect
-        wxPoint from, to;
-        from = activeTab->GetRect().GetBottomLeft();
-        to = activeTab->GetRect().GetBottomRight();
-        from.y -= clTabInfo::BOTTOM_AREA_HEIGHT - 1;
-        from.x += 2;
-        to.y -= clTabInfo::BOTTOM_AREA_HEIGHT - 1;
-        to.x -= 2;
-
-        dc.SetPen(colours.activeTabBgColour);
-        dc.DrawLine(from, to);
-#ifdef __WXOSX__
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-        dc.DrawLine(from, to);
-#endif
-    }
+    GetArt()->DrawBottomRect(activeTab, clientRect, dc, colours, GetStyle());
 }
 
 bool clTabCtrl::IsVerticalTabs() const { return (m_style & kNotebook_RightTabs) || (m_style & kNotebook_LeftTabs); }
@@ -1766,13 +1241,15 @@ bool clTabCtrl::ShiftBottom(clTabInfo::Vec_t& tabs)
 
         for(size_t i = 0; i < tabs.size(); ++i) {
             clTabInfo::Ptr_t t = tabs.at(i);
-            t->GetRect().SetY(t->GetRect().y - height + V_OVERLAP_WIDTH);
+            t->GetRect().SetY(t->GetRect().y - height + GetArt()->verticalOverlapWidth);
         }
         return true;
     }
     return false;
 }
 
+void clTabCtrl::OnRightUp(wxMouseEvent& event) { event.Skip(); }
+
 // ----------------------------------------------------------------------
 // clTabHistory
 // ----------------------------------------------------------------------
