@@ -36,47 +36,51 @@
 
 const wxString BuildConfig::OVERWRITE_GLOBAL_SETTINGS = "overwrite";
 const wxString BuildConfig::APPEND_TO_GLOBAL_SETTINGS = "append";
-const wxString BuildConfig::PREPEND_GLOBAL_SETTINGS   = "prepend";
+const wxString BuildConfig::PREPEND_GLOBAL_SETTINGS = "prepend";
 
-BuildConfig::BuildConfig(wxXmlNode *node)
+BuildConfig::BuildConfig(wxXmlNode* node)
     : m_commonConfig(node)
     , m_useSeparateDebugArgs(false)
     , m_pchInCommandLine(false)
     , m_clangC11(false)
+    , m_clangC14(false)
     , m_isGUIProgram(false)
     , m_isProjectEnabled(true)
     , m_pchPolicy(BuildConfig::kPCHPolicyReplace)
 {
-    if ( node ) {
+    if(node) {
         m_name = XmlUtils::ReadString(node, wxT("Name"));
         m_compilerType = XmlUtils::ReadString(node, wxT("CompilerType"));
         m_debuggerType = XmlUtils::ReadString(node, wxT("DebuggerType"));
         m_projectType = XmlUtils::ReadString(node, wxT("Type"));
-        m_buildCmpWithGlobalSettings = XmlUtils::ReadString(node, wxT("BuildCmpWithGlobalSettings"), APPEND_TO_GLOBAL_SETTINGS);
-        m_buildLnkWithGlobalSettings = XmlUtils::ReadString(node, wxT("BuildLnkWithGlobalSettings"), APPEND_TO_GLOBAL_SETTINGS);
-        m_buildResWithGlobalSettings = XmlUtils::ReadString(node, wxT("BuildResWithGlobalSettings"), APPEND_TO_GLOBAL_SETTINGS);
+        m_buildCmpWithGlobalSettings =
+            XmlUtils::ReadString(node, wxT("BuildCmpWithGlobalSettings"), APPEND_TO_GLOBAL_SETTINGS);
+        m_buildLnkWithGlobalSettings =
+            XmlUtils::ReadString(node, wxT("BuildLnkWithGlobalSettings"), APPEND_TO_GLOBAL_SETTINGS);
+        m_buildResWithGlobalSettings =
+            XmlUtils::ReadString(node, wxT("BuildResWithGlobalSettings"), APPEND_TO_GLOBAL_SETTINGS);
 
-        wxXmlNode *completion = XmlUtils::FindFirstByTagName(node, wxT("Completion"));
+        wxXmlNode* completion = XmlUtils::FindFirstByTagName(node, wxT("Completion"));
         if(completion) {
-            wxXmlNode * search_paths = XmlUtils::FindFirstByTagName(completion, wxT("SearchPaths"));
+            wxXmlNode* search_paths = XmlUtils::FindFirstByTagName(completion, wxT("SearchPaths"));
             if(search_paths) {
                 m_ccSearchPaths = search_paths->GetNodeContent();
                 m_ccSearchPaths.Trim().Trim(false);
             }
 
-            wxXmlNode * clang_pp = XmlUtils::FindFirstByTagName(completion, wxT("ClangPP"));
+            wxXmlNode* clang_pp = XmlUtils::FindFirstByTagName(completion, wxT("ClangPP"));
             if(clang_pp) {
                 m_clangPPFlags = clang_pp->GetNodeContent();
                 m_clangPPFlags.Trim().Trim(false);
             }
 
-            wxXmlNode * clang_cmp_flags = XmlUtils::FindFirstByTagName(completion, wxT("ClangCmpFlags"));
+            wxXmlNode* clang_cmp_flags = XmlUtils::FindFirstByTagName(completion, wxT("ClangCmpFlags"));
             if(clang_cmp_flags) {
                 m_clangCmpFlags = clang_cmp_flags->GetNodeContent();
                 m_clangCmpFlags.Trim().Trim(false);
             }
 
-            wxXmlNode * clang_c_cmp_flags = XmlUtils::FindFirstByTagName(completion, wxT("ClangCmpFlagsC"));
+            wxXmlNode* clang_c_cmp_flags = XmlUtils::FindFirstByTagName(completion, wxT("ClangCmpFlagsC"));
             if(clang_c_cmp_flags) {
                 m_clangCmpFlagsC = clang_c_cmp_flags->GetNodeContent();
                 m_clangCmpFlagsC.Trim().Trim(false);
@@ -89,47 +93,48 @@ BuildConfig::BuildConfig(wxXmlNode *node)
             }
 
             m_clangC11 = XmlUtils::ReadBool(completion, wxT("EnableCpp11"));
+            m_clangC14 = XmlUtils::ReadBool(completion, wxT("EnableCpp14"));
         }
 
-        wxXmlNode *compile = XmlUtils::FindFirstByTagName(node, wxT("Compiler"));
-        if (compile) {
+        wxXmlNode* compile = XmlUtils::FindFirstByTagName(node, wxT("Compiler"));
+        if(compile) {
             m_compilerRequired = XmlUtils::ReadBool(compile, wxT("Required"), true);
             m_precompiledHeader = XmlUtils::ReadString(compile, wxT("PreCompiledHeader"));
-            m_pchInCommandLine  = XmlUtils::ReadBool(compile, wxT("PCHInCommandLine"), false);
+            m_pchInCommandLine = XmlUtils::ReadBool(compile, wxT("PCHInCommandLine"), false);
             m_pchCompileFlags = XmlUtils::ReadString(compile, wxT("PCHFlags"));
             m_pchPolicy = (ePCHPolicy)XmlUtils::ReadLong(compile, "PCHFlagsPolicy", m_pchPolicy);
         }
 
-        wxXmlNode *linker = XmlUtils::FindFirstByTagName(node, wxT("Linker"));
-        if (linker) {
+        wxXmlNode* linker = XmlUtils::FindFirstByTagName(node, wxT("Linker"));
+        if(linker) {
             m_linkerRequired = XmlUtils::ReadBool(linker, wxT("Required"), true);
         }
 
-        wxXmlNode *resCmp = XmlUtils::FindFirstByTagName(node, wxT("ResourceCompiler"));
-        if (resCmp) {
+        wxXmlNode* resCmp = XmlUtils::FindFirstByTagName(node, wxT("ResourceCompiler"));
+        if(resCmp) {
             m_isResCmpNeeded = XmlUtils::ReadBool(resCmp, wxT("Required"), true);
         }
 
         // read the postbuild commands
-        wxXmlNode *debugger = XmlUtils::FindFirstByTagName(node, wxT("Debugger"));
+        wxXmlNode* debugger = XmlUtils::FindFirstByTagName(node, wxT("Debugger"));
         m_isDbgRemoteTarget = false;
 
-        if (debugger) {
+        if(debugger) {
             m_isDbgRemoteTarget = XmlUtils::ReadBool(debugger, wxT("IsRemote"));
             m_dbgHostName = XmlUtils::ReadString(debugger, wxT("RemoteHostName"));
             m_dbgHostPort = XmlUtils::ReadString(debugger, wxT("RemoteHostPort"));
             m_debuggerPath = XmlUtils::ReadString(debugger, wxT("DebuggerPath"));
             m_isDbgRemoteExtended = XmlUtils::ReadBool(debugger, wxT("IsExtended"));
 
-            wxXmlNode *child = debugger->GetChildren();
-            while (child) {
-                if (child->GetName() == wxT("StartupCommands")) {
+            wxXmlNode* child = debugger->GetChildren();
+            while(child) {
+                if(child->GetName() == wxT("StartupCommands")) {
                     m_debuggerStartupCmds = child->GetNodeContent();
-                    
-                } else if (child->GetName() == wxT("PostConnectCommands")) {
+
+                } else if(child->GetName() == wxT("PostConnectCommands")) {
                     m_debuggerPostRemoteConnectCmds = child->GetNodeContent();
-                    
-                } else if ( child->GetName() == "DebuggerSearchPaths" ) {
+
+                } else if(child->GetName() == "DebuggerSearchPaths") {
                     wxArrayString searchPaths = ::wxStringTokenize(child->GetNodeContent(), "\r\n", wxTOKEN_STRTOK);
                     m_debuggerSearchPaths.swap(searchPaths);
                 }
@@ -139,11 +144,11 @@ BuildConfig::BuildConfig(wxXmlNode *node)
         }
 
         // read the prebuild commands
-        wxXmlNode *preBuild = XmlUtils::FindFirstByTagName(node, wxT("PreBuild"));
-        if (preBuild) {
-            wxXmlNode *child = preBuild->GetChildren();
-            while (child) {
-                if (child->GetName() == wxT("Command")) {
+        wxXmlNode* preBuild = XmlUtils::FindFirstByTagName(node, wxT("PreBuild"));
+        if(preBuild) {
+            wxXmlNode* child = preBuild->GetChildren();
+            while(child) {
+                if(child->GetName() == wxT("Command")) {
                     bool enabled = XmlUtils::ReadBool(child, wxT("Enabled"));
 
                     BuildCommand cmd(child->GetNodeContent(), enabled);
@@ -153,11 +158,11 @@ BuildConfig::BuildConfig(wxXmlNode *node)
             }
         }
         // read the postbuild commands
-        wxXmlNode *postBuild = XmlUtils::FindFirstByTagName(node, wxT("PostBuild"));
-        if (postBuild) {
-            wxXmlNode *child = postBuild->GetChildren();
-            while (child) {
-                if (child->GetName() == wxT("Command")) {
+        wxXmlNode* postBuild = XmlUtils::FindFirstByTagName(node, wxT("PostBuild"));
+        if(postBuild) {
+            wxXmlNode* child = postBuild->GetChildren();
+            while(child) {
+                if(child->GetName() == wxT("Command")) {
                     bool enabled = XmlUtils::ReadBool(child, wxT("Enabled"));
                     BuildCommand cmd(child->GetNodeContent(), enabled);
                     m_postBuildCommands.push_back(cmd);
@@ -170,35 +175,35 @@ BuildConfig::BuildConfig(wxXmlNode *node)
         SetDbgEnvSet(USE_GLOBAL_SETTINGS);
 
         // read the environment page
-        wxXmlNode *envNode = XmlUtils::FindFirstByTagName(node, wxT("Environment"));
-        if (envNode) {
-            SetEnvVarSet( XmlUtils::ReadString(envNode, wxT("EnvVarSetName")) );
-            SetDbgEnvSet( XmlUtils::ReadString(envNode, wxT("DbgSetName")) );
+        wxXmlNode* envNode = XmlUtils::FindFirstByTagName(node, wxT("Environment"));
+        if(envNode) {
+            SetEnvVarSet(XmlUtils::ReadString(envNode, wxT("EnvVarSetName")));
+            SetDbgEnvSet(XmlUtils::ReadString(envNode, wxT("DbgSetName")));
             m_envvars = envNode->GetNodeContent();
         }
 
-        wxXmlNode *customBuild = XmlUtils::FindFirstByTagName(node, wxT("CustomBuild"));
-        if (customBuild) {
+        wxXmlNode* customBuild = XmlUtils::FindFirstByTagName(node, wxT("CustomBuild"));
+        if(customBuild) {
             m_enableCustomBuild = XmlUtils::ReadBool(customBuild, wxT("Enabled"), false);
-            wxXmlNode *child = customBuild->GetChildren();
-            while (child) {
-                if (child->GetName() == wxT("BuildCommand")) {
+            wxXmlNode* child = customBuild->GetChildren();
+            while(child) {
+                if(child->GetName() == wxT("BuildCommand")) {
                     m_customBuildCmd = child->GetNodeContent();
-                } else if (child->GetName() == wxT("CleanCommand")) {
+                } else if(child->GetName() == wxT("CleanCommand")) {
                     m_customCleanCmd = child->GetNodeContent();
-                } else if (child->GetName() == wxT("RebuildCommand")) {
+                } else if(child->GetName() == wxT("RebuildCommand")) {
                     m_customRebuildCmd = child->GetNodeContent();
-                } else if (child->GetName() == wxT("SingleFileCommand")) {
+                } else if(child->GetName() == wxT("SingleFileCommand")) {
                     m_singleFileBuildCommand = child->GetNodeContent();
-                } else if (child->GetName() == wxT("PreprocessFileCommand")) {
+                } else if(child->GetName() == wxT("PreprocessFileCommand")) {
                     m_preprocessFileCommand = child->GetNodeContent();
-                } else if (child->GetName() == wxT("WorkingDirectory")) {
+                } else if(child->GetName() == wxT("WorkingDirectory")) {
                     m_customBuildWorkingDir = child->GetNodeContent();
-                } else if (child->GetName() == wxT("ThirdPartyToolName")) {
+                } else if(child->GetName() == wxT("ThirdPartyToolName")) {
                     m_toolName = child->GetNodeContent();
-                } else if (child->GetName() == wxT("MakefileGenerationCommand")) {
+                } else if(child->GetName() == wxT("MakefileGenerationCommand")) {
                     m_makeGenerationCommand = child->GetNodeContent();
-                } else if (child->GetName() == wxT("Target")) {
+                } else if(child->GetName() == wxT("Target")) {
                     wxString target_name = child->GetPropVal(wxT("Name"), wxT(""));
                     wxString target_cmd = child->GetNodeContent();
                     if(target_name.IsEmpty() == false) {
@@ -211,40 +216,39 @@ BuildConfig::BuildConfig(wxXmlNode *node)
             m_enableCustomBuild = false;
         }
 
-        wxXmlNode *customPreBuild = XmlUtils::FindFirstByTagName(node, wxT("AdditionalRules"));
-        if (customPreBuild) {
-            wxXmlNode *child = customPreBuild->GetChildren();
-            while (child) {
-                if (child->GetName() == wxT("CustomPreBuild")) {
+        wxXmlNode* customPreBuild = XmlUtils::FindFirstByTagName(node, wxT("AdditionalRules"));
+        if(customPreBuild) {
+            wxXmlNode* child = customPreBuild->GetChildren();
+            while(child) {
+                if(child->GetName() == wxT("CustomPreBuild")) {
                     m_customPreBuildRule = child->GetNodeContent();
                     m_customPreBuildRule.Trim().Trim(false);
 
-                } else if (child->GetName() == wxT("CustomPostBuild")) {
+                } else if(child->GetName() == wxT("CustomPostBuild")) {
                     m_customPostBuildRule = child->GetNodeContent();
                     m_customPostBuildRule.Trim().Trim(false);
-
                 }
                 child = child->GetNext();
             }
         }
 
-        wxXmlNode *general = XmlUtils::FindFirstByTagName(node, wxT("General"));
-        if (general) {
-            m_outputFile            = XmlUtils::ReadString(general, wxT("OutputFile"));
+        wxXmlNode* general = XmlUtils::FindFirstByTagName(node, wxT("General"));
+        if(general) {
+            m_outputFile = XmlUtils::ReadString(general, wxT("OutputFile"));
             m_intermediateDirectory = XmlUtils::ReadString(general, wxT("IntermediateDirectory"), wxT("."));
-            m_command               = XmlUtils::ReadString(general, wxT("Command"));
-            m_commandArguments      = XmlUtils::ReadString(general, wxT("CommandArguments"));
-            m_workingDirectory      = XmlUtils::ReadString(general, wxT("WorkingDirectory"), wxT("."));
-            m_pauseWhenExecEnds     = XmlUtils::ReadBool  (general, wxT("PauseExecWhenProcTerminates"), true);
-            m_useSeparateDebugArgs  = XmlUtils::ReadBool  (general, wxT("UseSeparateDebugArgs"), false);
-            m_debugArgs             = XmlUtils::ReadString(general, wxT("DebugArguments"));
-            m_isGUIProgram          = XmlUtils::ReadBool  (general, "IsGUIProgram", false);
-            m_isProjectEnabled      = XmlUtils::ReadBool( general, "IsEnabled", true);
+            m_command = XmlUtils::ReadString(general, wxT("Command"));
+            m_commandArguments = XmlUtils::ReadString(general, wxT("CommandArguments"));
+            m_workingDirectory = XmlUtils::ReadString(general, wxT("WorkingDirectory"), wxT("."));
+            m_pauseWhenExecEnds = XmlUtils::ReadBool(general, wxT("PauseExecWhenProcTerminates"), true);
+            m_useSeparateDebugArgs = XmlUtils::ReadBool(general, wxT("UseSeparateDebugArgs"), false);
+            m_debugArgs = XmlUtils::ReadString(general, wxT("DebugArguments"));
+            m_isGUIProgram = XmlUtils::ReadBool(general, "IsGUIProgram", false);
+            m_isProjectEnabled = XmlUtils::ReadBool(general, "IsEnabled", true);
         }
 
     } else {
 
-        //create default project settings
+        // create default project settings
         m_commonConfig.SetCompileOptions(wxT("-g -Wall"));
         m_commonConfig.SetLinkOptions(wxT("-O0"));
         m_commonConfig.SetLibPath(wxT(".;Debug"));
@@ -273,15 +277,15 @@ BuildConfig::BuildConfig(wxXmlNode *node)
         m_debugArgs = wxEmptyString;
 
         SetEnvVarSet(wxT("<Use Workspace Settings>"));
-        SetDbgEnvSet(wxT("<Use Global Settings>")   );
+        SetDbgEnvSet(wxT("<Use Global Settings>"));
 
         BuildSettingsConfigCookie cookie;
         CompilerPtr cmp = BuildSettingsConfigST::Get()->GetFirstCompiler(cookie);
-        if (cmp) {
+        if(cmp) {
             m_compilerType = cmp->GetName();
         }
         wxArrayString dbgs = DebuggerMgr::Get().GetAvailableDebuggers();
-        if (dbgs.GetCount() > 0) {
+        if(dbgs.GetCount() > 0) {
             m_debuggerType = dbgs.Item(0);
         }
         m_buildCmpWithGlobalSettings = APPEND_TO_GLOBAL_SETTINGS;
@@ -290,22 +294,20 @@ BuildConfig::BuildConfig(wxXmlNode *node)
     }
 }
 
-BuildConfig::~BuildConfig()
-{
-}
+BuildConfig::~BuildConfig() {}
 
-BuildConfig *BuildConfig::Clone() const
+BuildConfig* BuildConfig::Clone() const
 {
-    wxXmlNode *node = ToXml();
-    BuildConfig *cloned = new BuildConfig(node);
+    wxXmlNode* node = ToXml();
+    BuildConfig* cloned = new BuildConfig(node);
     delete node;
     return cloned;
 }
 
-wxXmlNode *BuildConfig::ToXml() const
+wxXmlNode* BuildConfig::ToXml() const
 {
     // Create the common nodes
-    wxXmlNode *node = m_commonConfig.ToXml();
+    wxXmlNode* node = m_commonConfig.ToXml();
 
     node->AddProperty(wxT("Name"), m_name);
     node->AddProperty(wxT("CompilerType"), m_compilerType);
@@ -315,122 +317,122 @@ wxXmlNode *BuildConfig::ToXml() const
     node->AddProperty(wxT("BuildLnkWithGlobalSettings"), m_buildLnkWithGlobalSettings);
     node->AddProperty(wxT("BuildResWithGlobalSettings"), m_buildResWithGlobalSettings);
 
-    wxXmlNode *compile = XmlUtils::FindFirstByTagName(node, wxT("Compiler"));
-    if (compile) {
-        compile->AddProperty(wxT("Required"),          BoolToString(m_compilerRequired));
+    wxXmlNode* compile = XmlUtils::FindFirstByTagName(node, wxT("Compiler"));
+    if(compile) {
+        compile->AddProperty(wxT("Required"), BoolToString(m_compilerRequired));
         compile->AddProperty(wxT("PreCompiledHeader"), m_precompiledHeader);
-        compile->AddProperty(wxT("PCHInCommandLine"),  BoolToString(m_pchInCommandLine));
+        compile->AddProperty(wxT("PCHInCommandLine"), BoolToString(m_pchInCommandLine));
         compile->AddProperty(wxT("PCHFlags"), m_pchCompileFlags);
         compile->AddProperty("PCHFlagsPolicy", wxString() << (int)m_pchPolicy);
     }
 
-    wxXmlNode *link = XmlUtils::FindFirstByTagName(node, wxT("Linker"));
-    if (link) {
+    wxXmlNode* link = XmlUtils::FindFirstByTagName(node, wxT("Linker"));
+    if(link) {
         link->AddProperty(wxT("Required"), BoolToString(m_linkerRequired));
     }
 
-    wxXmlNode *resCmp = XmlUtils::FindFirstByTagName(node, wxT("ResourceCompiler"));
-    if (resCmp) {
+    wxXmlNode* resCmp = XmlUtils::FindFirstByTagName(node, wxT("ResourceCompiler"));
+    if(resCmp) {
         resCmp->AddProperty(wxT("Required"), BoolToString(m_isResCmpNeeded));
     }
 
-    wxXmlNode *general = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("General"));
+    wxXmlNode* general = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("General"));
     general->AddProperty(wxT("OutputFile"), m_outputFile);
     general->AddProperty(wxT("IntermediateDirectory"), m_intermediateDirectory);
-    general->AddProperty(wxT("Command"), m_command );
+    general->AddProperty(wxT("Command"), m_command);
     general->AddProperty(wxT("CommandArguments"), m_commandArguments);
     general->AddProperty(wxT("UseSeparateDebugArgs"), BoolToString(m_useSeparateDebugArgs));
-    general->AddProperty(wxT("DebugArguments"),   m_debugArgs);
+    general->AddProperty(wxT("DebugArguments"), m_debugArgs);
     general->AddProperty(wxT("WorkingDirectory"), m_workingDirectory);
     general->AddProperty(wxT("PauseExecWhenProcTerminates"), BoolToString(m_pauseWhenExecEnds));
     general->AddProperty("IsGUIProgram", BoolToString(m_isGUIProgram));
     general->AddProperty("IsEnabled", BoolToString(m_isProjectEnabled));
-    
+
     node->AddChild(general);
 
-    wxXmlNode *debugger = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Debugger"));
+    wxXmlNode* debugger = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Debugger"));
     debugger->AddProperty(wxT("IsRemote"), BoolToString(m_isDbgRemoteTarget));
     debugger->AddProperty(wxT("RemoteHostName"), m_dbgHostName);
     debugger->AddProperty(wxT("RemoteHostPort"), m_dbgHostPort);
     debugger->AddProperty(wxT("DebuggerPath"), m_debuggerPath);
     debugger->AddProperty(wxT("IsExtended"), BoolToString(m_isDbgRemoteExtended));
 
-    wxXmlNode *envNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Environment"));
-    envNode->AddProperty(wxT("EnvVarSetName"),  GetEnvVarSet());
-    envNode->AddProperty(wxT("DbgSetName"),     GetDbgEnvSet());
+    wxXmlNode* envNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Environment"));
+    envNode->AddProperty(wxT("EnvVarSetName"), GetEnvVarSet());
+    envNode->AddProperty(wxT("DbgSetName"), GetDbgEnvSet());
 
     // Add CDATA section with project environment variables
-    wxXmlNode *envContent = new wxXmlNode(wxXML_CDATA_SECTION_NODE, wxEmptyString, m_envvars);
+    wxXmlNode* envContent = new wxXmlNode(wxXML_CDATA_SECTION_NODE, wxEmptyString, m_envvars);
     envNode->AddChild(envContent);
     node->AddChild(envNode);
 
-    wxXmlNode *dbgStartupCommands = new wxXmlNode(debugger, wxXML_ELEMENT_NODE, wxT("StartupCommands"));
+    wxXmlNode* dbgStartupCommands = new wxXmlNode(debugger, wxXML_ELEMENT_NODE, wxT("StartupCommands"));
     XmlUtils::SetNodeContent(dbgStartupCommands, m_debuggerStartupCmds);
 
-    wxXmlNode *dbgPostConnectCommands = new wxXmlNode(debugger, wxXML_ELEMENT_NODE, wxT("PostConnectCommands"));
+    wxXmlNode* dbgPostConnectCommands = new wxXmlNode(debugger, wxXML_ELEMENT_NODE, wxT("PostConnectCommands"));
     XmlUtils::SetNodeContent(dbgPostConnectCommands, m_debuggerPostRemoteConnectCmds);
 
-    wxXmlNode *dbgSearchPaths = new wxXmlNode(debugger, wxXML_ELEMENT_NODE, wxT("DebuggerSearchPaths"));
+    wxXmlNode* dbgSearchPaths = new wxXmlNode(debugger, wxXML_ELEMENT_NODE, wxT("DebuggerSearchPaths"));
     XmlUtils::SetNodeContent(dbgSearchPaths, ::wxImplode(m_debuggerSearchPaths, "\n"));
 
     node->AddChild(debugger);
 
-    //add prebuild commands
-    wxXmlNode *preBuild = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("PreBuild"));
+    // add prebuild commands
+    wxXmlNode* preBuild = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("PreBuild"));
     node->AddChild(preBuild);
 
     BuildCommandList::const_iterator iter = m_preBuildCommands.begin();
-    for (; iter != m_preBuildCommands.end(); iter++) {
-        wxXmlNode *command = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Command"));
+    for(; iter != m_preBuildCommands.end(); iter++) {
+        wxXmlNode* command = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Command"));
         command->AddProperty(wxT("Enabled"), BoolToString(iter->GetEnabled()));
         XmlUtils::SetNodeContent(command, iter->GetCommand());
         preBuild->AddChild(command);
     }
 
-    //add postbuild commands
-    wxXmlNode *postBuild = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("PostBuild"));
+    // add postbuild commands
+    wxXmlNode* postBuild = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("PostBuild"));
     node->AddChild(postBuild);
     iter = m_postBuildCommands.begin();
-    for (; iter != m_postBuildCommands.end(); iter++) {
-        wxXmlNode *command = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Command"));
+    for(; iter != m_postBuildCommands.end(); iter++) {
+        wxXmlNode* command = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Command"));
         command->AddProperty(wxT("Enabled"), BoolToString(iter->GetEnabled()));
         XmlUtils::SetNodeContent(command, iter->GetCommand());
         postBuild->AddChild(command);
     }
 
-    //add postbuild commands
-    wxXmlNode *customBuild = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("CustomBuild"));
+    // add postbuild commands
+    wxXmlNode* customBuild = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("CustomBuild"));
     node->AddChild(customBuild);
     customBuild->AddProperty(wxT("Enabled"), BoolToString(m_enableCustomBuild));
 
-    //add the working directory of the custom build
-    wxXmlNode *customBuildWd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("WorkingDirectory"));
+    // add the working directory of the custom build
+    wxXmlNode* customBuildWd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("WorkingDirectory"));
     XmlUtils::SetNodeContent(customBuildWd, m_customBuildWorkingDir);
 
-    //add the makefile generation command
-    wxXmlNode *toolName = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("ThirdPartyToolName"));
+    // add the makefile generation command
+    wxXmlNode* toolName = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("ThirdPartyToolName"));
     XmlUtils::SetNodeContent(toolName, m_toolName);
 
-    //add the makefile generation command
-    wxXmlNode *makeGenCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("MakefileGenerationCommand"));
+    // add the makefile generation command
+    wxXmlNode* makeGenCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("MakefileGenerationCommand"));
     XmlUtils::SetNodeContent(makeGenCmd, m_makeGenerationCommand);
 
-    //add the makefile generation command
-    wxXmlNode *singleFileCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("SingleFileCommand"));
+    // add the makefile generation command
+    wxXmlNode* singleFileCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("SingleFileCommand"));
     XmlUtils::SetNodeContent(singleFileCmd, m_singleFileBuildCommand);
 
-    //add the makefile generation command
-    wxXmlNode *preprocessFileCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("PreprocessFileCommand"));
+    // add the makefile generation command
+    wxXmlNode* preprocessFileCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("PreprocessFileCommand"));
     XmlUtils::SetNodeContent(preprocessFileCmd, m_preprocessFileCommand);
 
-    //add build and clean commands
-    wxXmlNode *bldCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("BuildCommand"));
+    // add build and clean commands
+    wxXmlNode* bldCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("BuildCommand"));
     XmlUtils::SetNodeContent(bldCmd, m_customBuildCmd);
 
-    wxXmlNode *clnCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("CleanCommand"));
+    wxXmlNode* clnCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("CleanCommand"));
     XmlUtils::SetNodeContent(clnCmd, m_customCleanCmd);
 
-    wxXmlNode *rebldCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("RebuildCommand"));
+    wxXmlNode* rebldCmd = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("RebuildCommand"));
     XmlUtils::SetNodeContent(rebldCmd, m_customRebuildCmd);
 
     // add all 'Targets'
@@ -439,96 +441,61 @@ wxXmlNode *BuildConfig::ToXml() const
         wxString target_name = ir->first;
         wxString target_cmd = ir->second;
 
-        wxXmlNode *customTarget = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("Target"));
+        wxXmlNode* customTarget = new wxXmlNode(customBuild, wxXML_ELEMENT_NODE, wxT("Target"));
         customTarget->AddProperty(wxT("Name"), target_name);
         XmlUtils::SetNodeContent(customTarget, target_cmd);
     }
 
-    //add the additional rules
-    wxXmlNode *additionalCmds = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("AdditionalRules"));
+    // add the additional rules
+    wxXmlNode* additionalCmds = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("AdditionalRules"));
     node->AddChild(additionalCmds);
 
-    wxXmlNode *preCmd = new wxXmlNode(additionalCmds, wxXML_ELEMENT_NODE, wxT("CustomPreBuild"));
+    wxXmlNode* preCmd = new wxXmlNode(additionalCmds, wxXML_ELEMENT_NODE, wxT("CustomPreBuild"));
     XmlUtils::SetNodeContent(preCmd, m_customPreBuildRule);
-    wxXmlNode *postCmd = new wxXmlNode(additionalCmds, wxXML_ELEMENT_NODE, wxT("CustomPostBuild"));
+    wxXmlNode* postCmd = new wxXmlNode(additionalCmds, wxXML_ELEMENT_NODE, wxT("CustomPostBuild"));
     XmlUtils::SetNodeContent(postCmd, m_customPostBuildRule);
 
     // Set the completion flags
-    wxXmlNode *completion = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Completion"));
+    wxXmlNode* completion = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Completion"));
     node->AddChild(completion);
     completion->AddProperty(wxT("EnableCpp11"), BoolToString(m_clangC11));
+    completion->AddProperty(wxT("EnableCpp14"), BoolToString(m_clangC14));
 
-    wxXmlNode * search_paths = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("SearchPaths"));
+    wxXmlNode* search_paths = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("SearchPaths"));
     XmlUtils::SetNodeContent(search_paths, m_ccSearchPaths);
 
-    wxXmlNode * clang_pp = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("ClangPP"));
+    wxXmlNode* clang_pp = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("ClangPP"));
     XmlUtils::SetNodeContent(clang_pp, m_clangPPFlags);
 
-    wxXmlNode * clang_cmp_flags = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("ClangCmpFlags"));
+    wxXmlNode* clang_cmp_flags = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("ClangCmpFlags"));
     XmlUtils::SetNodeContent(clang_cmp_flags, m_clangCmpFlags);
 
-    wxXmlNode * clang_c_cmp_flags = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("ClangCmpFlagsC"));
+    wxXmlNode* clang_c_cmp_flags = new wxXmlNode(completion, wxXML_ELEMENT_NODE, wxT("ClangCmpFlagsC"));
     XmlUtils::SetNodeContent(clang_c_cmp_flags, m_clangCmpFlagsC);
 
     return node;
 }
 
-void BuildConfig::SetPreprocessor(const wxString &pre)
-{
-    m_commonConfig.SetPreprocessor(pre);
-}
+void BuildConfig::SetPreprocessor(const wxString& pre) { m_commonConfig.SetPreprocessor(pre); }
 
-void BuildConfig::SetIncludePath(const wxString &path)
-{
-    m_commonConfig.SetIncludePath(path);
-}
+void BuildConfig::SetIncludePath(const wxString& path) { m_commonConfig.SetIncludePath(path); }
 
-void BuildConfig::SetLibraries(const wxString &libs)
-{
-    m_commonConfig.SetLibraries(libs);
-}
+void BuildConfig::SetLibraries(const wxString& libs) { m_commonConfig.SetLibraries(libs); }
 
-void BuildConfig::SetLibPath(const wxString &paths)
-{
-    m_commonConfig.SetLibPath(paths);
-}
+void BuildConfig::SetLibPath(const wxString& paths) { m_commonConfig.SetLibPath(paths); }
 
-wxString BuildConfig::GetLibPath() const
-{
-    return m_commonConfig.GetLibPath();
-}
+wxString BuildConfig::GetLibPath() const { return m_commonConfig.GetLibPath(); }
 
-wxString BuildConfig::GetLibraries() const
-{
-    return m_commonConfig.GetLibraries();
-}
+wxString BuildConfig::GetLibraries() const { return m_commonConfig.GetLibraries(); }
 
-wxString BuildConfig::GetIncludePath() const
-{
-    return m_commonConfig.GetIncludePath();
-}
+wxString BuildConfig::GetIncludePath() const { return m_commonConfig.GetIncludePath(); }
 
-wxString BuildConfig::GetPreprocessor() const
-{
-    return m_commonConfig.GetPreprocessor();
-}
+wxString BuildConfig::GetPreprocessor() const { return m_commonConfig.GetPreprocessor(); }
 
-wxString BuildConfig::GetOutputFileName() const
-{
-    return NormalizePath(m_outputFile);
-}
+wxString BuildConfig::GetOutputFileName() const { return NormalizePath(m_outputFile); }
 
-wxString BuildConfig::GetIntermediateDirectory() const
-{
-    return NormalizePath(m_intermediateDirectory);
-}
+wxString BuildConfig::GetIntermediateDirectory() const { return NormalizePath(m_intermediateDirectory); }
 
-wxString BuildConfig::GetWorkingDirectory() const
-{
-    return NormalizePath(m_workingDirectory);
-}
+wxString BuildConfig::GetWorkingDirectory() const { return NormalizePath(m_workingDirectory); }
 
-CompilerPtr BuildConfig::GetCompiler() const
-{
-    return BuildSettingsConfigST::Get()->GetCompiler(GetCompilerType());
-}
+CompilerPtr BuildConfig::GetCompiler() const { return BuildSettingsConfigST::Get()->GetCompiler(GetCompilerType()); }
