@@ -22,16 +22,17 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
- #ifndef BUILDMANAGER_H
+#ifndef BUILDMANAGER_H
 #define BUILDMANAGER_H
 
 #include <map>
 #include <list>
 #include "wx/string.h"
 #include "singleton.h"
+#include "codelite_exports.h"
 #include "builder.h"
 
-//class BuildManager;
+// class BuildManager;
 
 /**
  * \ingroup SDK
@@ -49,27 +50,32 @@
  * \author Eran
  *
  */
-class BuildManager {
+class WXDLLIMPEXP_SDK BuildManager
+{
 
-	friend class Singleton<BuildManager>;
-	std::map<wxString, BuilderPtr> m_builders;
+    friend class BuildManagerST;
+    std::map<wxString, BuilderPtr> m_builders;
 
 public:
-	typedef std::map<wxString, BuilderPtr>::const_iterator ConstIterator;
+    typedef std::map<wxString, BuilderPtr>::const_iterator ConstIterator;
 
 private:
-	BuildManager();
-	virtual ~BuildManager();
+    BuildManager();
+    virtual ~BuildManager();
 
 public:
-	void AddBuilder(BuilderPtr builder);
-	void RemoveBuilder(const wxString &name);
-	void GetBuilders(std::list<wxString> &list);
-	BuilderPtr GetBuilder(const wxString &name);
-	BuilderPtr GetSelectedBuilder();
+    void AddBuilder(BuilderPtr builder);
+    void RemoveBuilder(const wxString& name);
+    void GetBuilders(std::list<wxString>& list);
+    BuilderPtr GetBuilder(const wxString& name);
+    BuilderPtr GetSelectedBuilder();
 };
 
-typedef Singleton<BuildManager> BuildManagerST;
+class WXDLLIMPEXP_SDK BuildManagerST
+{
+public:
+    static BuildManager* Get();
+    static void Free();
+};
 
 #endif // BUILDMANAGER_H
-
