@@ -23,14 +23,16 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "conffilelocator.h"
- #include "configtool.h"
+#include "configtool.h"
 #include "xmlutils.h"
 #include "serialized_object.h"
 #include "wx/filename.h"
 #include "wx/ffile.h"
+#include "editor_config.h"
+#include "wx_xml_compatibility.h"
 
 ConfigTool::ConfigTool()
-: m_fileName(wxEmptyString)
+    : m_fileName(wxEmptyString)
 {
 }
 
@@ -40,55 +42,36 @@ ConfigTool::~ConfigTool()
 
 bool ConfigTool::Load(const wxString &basename, const wxString &version)
 {
-	wxString initialSettings = ConfFileLocator::Instance()->Locate(basename);
-	bool loaded = m_doc.Load(initialSettings);
-	wxString xmlVersion = m_doc.GetRoot()->GetPropVal(wxT("Version"), wxEmptyString);
-	if ( xmlVersion != version ) {
-		loaded = m_doc.Load(ConfFileLocator::Instance()->GetDefaultCopy(basename));
-	}
-	m_fileName = ConfFileLocator::Instance()->GetLocalCopy(basename);
-	return loaded;
+    wxString initialSettings = ConfFileLocator::Instance()->Locate(basename);
+    bool loaded = m_doc.Load(initialSettings);
+    wxString xmlVersion;
+    if ( loaded ) {
+        xmlVersion = m_doc.GetRoot()->GetPropVal(wxT("Version"), wxEmptyString);
+    }
+    
+    if ( xmlVersion != version ) {
+        loaded = m_doc.Load(ConfFileLocator::Instance()->GetDefaultCopy(basename));
+    }
+    m_fileName = ConfFileLocator::Instance()->GetLocalCopy(basename);
+    return loaded;
 }
 
 bool ConfigTool::WriteObject(const wxString &name, SerializedObject *obj)
 {
-	if(m_doc.IsOk() == false){
-		return false;
-	}
-	Archive arch;
-	wxXmlNode *child = XmlUtils::FindNodeByName(m_doc.GetRoot(), wxT("ArchiveObject"), name);
-	if (child) {
-		wxXmlNode *n = m_doc.GetRoot();
-		n->RemoveChild(child);
-		delete child;
-	}
+    if(m_doc.IsOk() == false) {
+        return false;
+    }
 
-	//create new xml node for this object
-	child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("ArchiveObject"));
-	m_doc.GetRoot()->AddChild(child);
-	child->AddProperty(wxT("Name"), name);
-
-	arch.SetXmlNode(child);
-	//serialize the object into the archive
-	obj->Serialize(arch);
-	//save the archive
-	return m_doc.Save(m_fileName);
+    if(!XmlUtils::StaticWriteObject(m_doc.GetRoot(), name, obj))
+        return false;
+    return m_doc.Save(m_fileName);
 }
 
-
 bool ConfigTool::ReadObject(const wxString &name, SerializedObject *obj)
 {
-	if(m_doc.IsOk() == false){
-		return false;
-	}
+    if(m_doc.IsOk() == false) {
+        return false;
+    }
 
-	//find the object node in the xml file
-	wxXmlNode *node = XmlUtils::FindNodeByName(m_doc.GetRoot(), wxT("ArchiveObject"), name);
-	if (node) {
-		Archive arch;
-		arch.SetXmlNode(node);
-		obj->DeSerialize(arch);
-		return true;
-	}
-	return false;
+    return XmlUtils::StaticReadObject(m_doc.GetRoot(), name, obj);
 }
