@@ -40,6 +40,7 @@
 #include "macros.h"
 #include <wx/propgrid/propgrid.h>
 
+class IManager;
 class wxStyledTextCtrl;
 class IProcess;
 class IProcessCallback;
@@ -192,7 +193,7 @@ WXDLLIMPEXP_SDK wxString ExpandVariables(const wxString& expression, ProjectPtr
  * \return an expanded string. If a macro is unknown it is replaced by empty string
  */
 WXDLLIMPEXP_SDK wxString ExpandAllVariables(const wxString& expression,
-                                            Workspace* workspace,
+                                            clCxxWorkspace* workspace,
                                             const wxString& projectName,
                                             const wxString& selConf,
                                             const wxString& fileName);
@@ -369,7 +370,7 @@ public:
  * @return the amended entries
  */
 WXDLLIMPEXP_SDK wxArrayString
-ReturnWithStringPrepended(const wxArrayString& oldarray, const wxString& str, const size_t maxsize);
+    ReturnWithStringPrepended(const wxArrayString& oldarray, const wxString& str, const size_t maxsize);
 
 /**
  * @brief return true if filename is a symbolic link
@@ -446,13 +447,13 @@ WXDLLIMPEXP_SDK void LaunchTerminalForDebugger(const wxString& title, wxString&
  * @return wxRichMessageDialog::ShowModal() return value
  */
 WXDLLIMPEXP_SDK wxStandardID
-PromptForYesNoDialogWithCheckbox(const wxString& message,
-                                 const wxString& dlgId,
-                                 const wxString& yesLabel = _("Yes"),
-                                 const wxString& noLabel = _("No"),
-                                 const wxString& checkboxLabel = _("Remember my answer and don't ask me again"),
-                                 long style = wxYES_NO | wxICON_QUESTION | wxYES_DEFAULT,
-                                 bool checkboxInitialValue = false);
+    PromptForYesNoDialogWithCheckbox(const wxString& message,
+                                     const wxString& dlgId,
+                                     const wxString& yesLabel = _("Yes"),
+                                     const wxString& noLabel = _("No"),
+                                     const wxString& checkboxLabel = _("Remember my answer and don't ask me again"),
+                                     long style = wxYES_NO | wxICON_QUESTION | wxYES_DEFAULT,
+                                     bool checkboxInitialValue = false);
 
 /**
  * @brief wrap string with quotes if needed
@@ -506,4 +507,21 @@ WXDLLIMPEXP_SDK void wxPGPropertyBooleanUseCheckbox(wxPropertyGrid* grid);
  * @param ctrl
  */
 WXDLLIMPEXP_SDK void clRecalculateSTCHScrollBar(wxStyledTextCtrl* ctrl);
+
+WXDLLIMPEXP_SDK wxString clGetTextFromUser(const wxString& title,
+                                           const wxString& message,
+                                           const wxString& initialValue = "",
+                                           int charsToSelect = wxNOT_FOUND,
+                                           wxWindow* parent = NULL);
+/**
+ * @brief return the instance to the plugin manager. A convinience method
+ */
+WXDLLIMPEXP_SDK IManager* clGetManager();
+/**
+ * @brief set the plugin manager
+ * @param manager
+ */
+WXDLLIMPEXP_SDK void clSetManager(IManager* manager);
+
 #endif // GLOBALS_H
+
