@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : open_resource_dialog.cpp
 //
 // -------------------------------------------------------------------------
@@ -78,6 +78,9 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
     m_textCtrlResourceName->SetFocus();
     SetLabel(_("Open resource..."));
 
+    SetMinClientSize(wxSize(600, 400));
+    GetSizer()->Fit(this);
+
     SetName("OpenResourceDialog");
     WindowAttrManager::Load(this);
 
@@ -118,6 +121,7 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
     bool showSymbols = clConfig::Get().Read("OpenResourceDialog/ShowSymbols", true);
     m_checkBoxFiles->SetValue(showFiles);
     m_checkBoxShowSymbols->SetValue(showSymbols);
+    CentreOnParent();
 }
 
 OpenResourceDialog::~OpenResourceDialog()
@@ -221,21 +225,17 @@ void OpenResourceDialog::DoPopulateTags()
         if(tag->GetKind() == wxT("function") || tag->GetKind() == wxT("prototype")) {
             fullname = wxString::Format(
                 wxT("%s::%s%s"), tag->GetScope().c_str(), tag->GetName().c_str(), tag->GetSignature().c_str());
-            item = DoAppendLine(tag->GetName(),
-                                fullname,
-                                (tag->GetKind() == wxT("function")),
-                                new OpenResourceDialogItemData(
+            item = DoAppendLine(tag->GetName(), fullname, (tag->GetKind() == wxT("function")),
+                new OpenResourceDialogItemData(
                                     tag->GetFile(), tag->GetLine(), tag->GetPattern(), tag->GetName(), tag->GetScope()),
-                                DoGetTagImg(tag));
+                DoGetTagImg(tag));
         } else {
 
             fullname = wxString::Format(wxT("%s::%s"), tag->GetScope().c_str(), tag->GetName().c_str());
-            item = DoAppendLine(tag->GetName(),
-                                fullname,
-                                false,
-                                new OpenResourceDialogItemData(
+            item = DoAppendLine(tag->GetName(), fullname, false,
+                new OpenResourceDialogItemData(
                                     tag->GetFile(), tag->GetLine(), tag->GetPattern(), tag->GetName(), tag->GetScope()),
-                                DoGetTagImg(tag));
+                DoGetTagImg(tag));
         }
 
         if((m_userFilters.GetCount() == 1) && (m_userFilters.Item(0).CmpNoCase(name) == 0) && !gotExactMatch) {
@@ -253,7 +253,9 @@ void OpenResourceDialog::DoPopulateWorkspaceFile()
     if(!m_userFilters.IsEmpty()) {
 
         std::multimap<wxString, wxString>::iterator iter = m_files.begin();
-        for(; iter != m_files.end(); iter++) {
+        const int maxFileSize = 100;
+        int counter = 0;
+        for(; (iter != m_files.end()) && (counter < maxFileSize); iter++) {
 
             if(!MatchesFilter(iter->second)) continue;
 
@@ -280,11 +282,9 @@ void OpenResourceDialog::DoPopulateWorkspaceFile()
             default:
                 break;
             }
-            DoAppendLine(fn.GetFullName(),
-                         fn.GetFullPath(),
-                         false,
-                         new OpenResourceDialogItemData(fn.GetFullPath(), -1, wxT(""), fn.GetFullName(), wxT("")),
-                         imgId);
+            DoAppendLine(fn.GetFullName(), fn.GetFullPath(), false,
+                new OpenResourceDialogItemData(fn.GetFullPath(), -1, wxT(""), fn.GetFullName(), wxT("")), imgId);
+            ++counter;
         }
     }
 }
@@ -319,7 +319,7 @@ void OpenResourceDialog::OnKeyDown(wxKeyEvent& event)
     if(m_dataviewModel->IsEmpty()) return;
 
     if(event.GetKeyCode() == WXK_DOWN || event.GetKeyCode() == WXK_UP || event.GetKeyCode() == WXK_NUMPAD_UP ||
-       event.GetKeyCode() == WXK_NUMPAD_DOWN) {
+        event.GetKeyCode() == WXK_NUMPAD_DOWN) {
         event.Skip(false);
         bool down = (event.GetKeyCode() == WXK_DOWN || event.GetKeyCode() == WXK_NUMPAD_DOWN);
         wxDataViewItemArray children;
@@ -368,10 +368,10 @@ void OpenResourceDialog::DoSelectItem(const wxDataViewItem& item)
 }
 
 wxDataViewItem OpenResourceDialog::DoAppendLine(const wxString& name,
-                                                const wxString& fullname,
-                                                bool boldFont,
-                                                OpenResourceDialogItemData* clientData,
-                                                const wxBitmap& bmp)
+    const wxString& fullname,
+    bool boldFont,
+    OpenResourceDialogItemData* clientData,
+    const wxBitmap& bmp)
 {
     wxString prefix;
     clientData->m_impl = boldFont;
@@ -448,7 +448,7 @@ void OpenResourceDialog::OnCheckboxshowsymbolsCheckboxClicked(wxCommandEvent& ev
 void OpenResourceDialog::OnEnter(wxCommandEvent& event)
 {
     wxDataViewItem item = m_dataview->GetSelection();
-    
+
     if(item.IsOk()) {
         EndModal(wxID_OK);
     }
