@@ -46,7 +46,7 @@ public:
         Opt_IconSet_FreshFarm = 0x00000040,
         Opt_IconSet_Classic = 0x00000100,
         Opt_AutoCompleteDoubleQuotes = 0x00000200,
-        Opt_NavKey_Shift = 0x00000400,
+        Opt_NavKey_Shift = 0x00000400, // (No longer actively used)
         Opt_NavKey_Alt = 0x00000800,
         Opt_NavKey_Control = 0x00001000,
         Opt_IconSet_Classic_Dark = 0x00002000,
@@ -65,6 +65,8 @@ public:
         Opt_FoldHighlightActiveBlock = 0x04000000,
         Opt_EnsureCaptionsVisible = 0x08000000,
         Opt_DisableMouseCtrlZoom = 0x10000000,
+        Opt_UseBlockCaret =   0x20000000,
+        Opt_TabStyleMinimal = 0x40000000,
     };
 
 protected:
