@@ -30,7 +30,7 @@ void WordCompletionThread::ProcessRequest(ThreadRequest* request)
 void WordCompletionThread::ParseBuffer(const wxString& buffer, wxStringSet_t& suggest)
 {
     wxArrayString filteredWords;
-    wxArrayString words = ::wxStringTokenize(buffer, "\r\n \t->./\\'\"[]()<>*&^%#!@+=:,;{}", wxTOKEN_STRTOK);
+    wxArrayString words = ::wxStringTokenize(buffer, "\r\n \t->./\\'\"[]()<>*&^%#!@+=:,;{}|/", wxTOKEN_STRTOK);
     for(size_t i=0; i<words.size(); ++i) {
         if(!wxIsdigit(words.Item(i).at(0))) {
             filteredWords.Add(words.Item(i));
