@@ -172,6 +172,24 @@ TEST_FUNC(test_word_completion)
     return true;
 }
 
+// test word completion of a local variable (or anything) after a 
+// casting
+TEST_FUNC(test_word_completion_after_casting)
+{
+    PHPSourceFile sourceFile(wxFileName("../Tests/test_word_completion_after_casting.php"));
+    sourceFile.SetParseFunctionBody(true);
+    sourceFile.Parse();
+    lookup.UpdateSourceFile(sourceFile);
+    PHPExpression expr(sourceFile.GetText());
+    PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
+    
+    CHECK_BOOL(resolved);
+    CHECK_BOOL(resolved->GetShortName().IsEmpty());
+    CHECK_WXSTRING(resolved->GetFullName(), "\\");
+    CHECK_WXSTRING(expr.GetFilter(), "$test_word_complet");
+    return true;
+}
+
 // test word completion when inside a namespace
 // namespace bla;
 // part_w + CTRL+SPACE
@@ -213,6 +231,19 @@ TEST_FUNC(test_class_members)
     return true;
 }
 
+TEST_FUNC(test_class_member_initialized)
+{
+    PHPSourceFile sourceFile(wxFileName("../Tests/test_class_member_initialized.php"));
+    sourceFile.SetParseFunctionBody(true);
+    sourceFile.Parse();
+    lookup.UpdateSourceFile(sourceFile);
+    PHPExpression expr(sourceFile.GetText());
+    PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
+    CHECK_BOOL(resolved);
+    CHECK_WXSTRING(resolved->GetShortName(), "MemberClass");
+    return true;
+}
+
 // test completing class members, but this time the class is defined inside a namespace
 TEST_FUNC(test_class_with_members_inside_namespace)
 {
@@ -508,7 +539,7 @@ TEST_FUNC(test_simple_trait)
     sourceFile.SetParseFunctionBody(true);
     sourceFile.Parse();
     lookup.UpdateSourceFile(sourceFile);
-    
+
     PHPEntityBase::Ptr_t tr = lookup.FindClass("\\test_simple_trait");
     CHECK_BOOL(tr);
     return true;
@@ -520,11 +551,11 @@ TEST_FUNC(test_use_trait)
     sourceFile.SetParseFunctionBody(true);
     sourceFile.Parse();
     lookup.UpdateSourceFile(sourceFile);
-    
+
     PHPExpression expr(sourceFile.GetText());
     PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
     CHECK_BOOL(resolved);
-    
+
     PHPEntityBase::List_t matches;
     expr.Suggest(resolved, lookup, matches);
 
@@ -538,11 +569,11 @@ TEST_FUNC(test_goto_def_with_trait)
     sourceFile.SetParseFunctionBody(true);
     sourceFile.Parse();
     lookup.UpdateSourceFile(sourceFile);
-    
+
     PHPExpression expr(sourceFile.GetText());
     PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
     CHECK_BOOL(resolved);
-    
+
     PHPEntityBase::List_t matches;
     expr.Suggest(resolved, lookup, matches);
 
@@ -556,12 +587,12 @@ TEST_FUNC(test_trait_alias)
     sourceFile.SetParseFunctionBody(true);
     sourceFile.Parse();
     lookup.UpdateSourceFile(sourceFile);
-    
+
     PHPExpression expr(sourceFile.GetText());
     PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
     CHECK_BOOL(resolved);
-    CHECK_STRING(resolved->GetFullName(), "\\Aliased_Talker");
-    
+    CHECK_STRING(resolved->GetFullName().c_str(), "\\Aliased_Talker");
+
     PHPEntityBase::List_t matches;
     expr.Suggest(resolved, lookup, matches);
 
@@ -583,11 +614,11 @@ TEST_FUNC(test_partial_namespace)
     sourceFile.SetParseFunctionBody(false);
     sourceFile.Parse();
     lookup.UpdateSourceFile(sourceFile);
-    
+
     PHPExpression expr(sourceFile.GetText());
     PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
     CHECK_BOOL(resolved);
-    
+
     PHPEntityBase::List_t matches;
     expr.Suggest(resolved, lookup, matches);
 
@@ -595,17 +626,50 @@ TEST_FUNC(test_partial_namespace)
     return true;
 }
 
+TEST_FUNC(test_php7_function_return_value)
+{
+    PHPSourceFile sourceFile(wxFileName("../Tests/test_php7_function_return_value.php"));
+    sourceFile.SetParseFunctionBody(false);
+    sourceFile.Parse();
+    lookup.UpdateSourceFile(sourceFile);
+
+    PHPExpression expr(sourceFile.GetText());
+    PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
+    CHECK_BOOL(resolved);
+    CHECK_STRING(resolved->GetFullName().c_str(), "\\test_php7_function_return_value_class");
+    return true;
+}
+
+TEST_FUNC(test_php7_function_arg_hinting)
+{
+    PHPSourceFile sourceFile(wxFileName("../Tests/test_php7_function_arg_hinting.php"));
+    sourceFile.SetParseFunctionBody(false);
+    sourceFile.Parse();
+    lookup.UpdateSourceFile(sourceFile);
+
+    PHPExpression expr(sourceFile.GetText());
+    PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
+    CHECK_BOOL(resolved);
+    CHECK_STRING(resolved->GetFullName().c_str(), "\\test_php7_function_arg_hinting_type2");
+    
+    PHPEntityBase::List_t matches;
+    expr.Suggest(resolved, lookup, matches);
+
+    CHECK_SIZE(matches.size(), 2);
+    return true;
+}
+
 /*TEST_FUNC(test_cc_with_keywords)
 {
     PHPSourceFile sourceFile(wxFileName("../Tests/test_cc_with_keywords.php"));
     sourceFile.SetParseFunctionBody(true);
     sourceFile.Parse();
     lookup.UpdateSourceFile(sourceFile);
-    
+
     PHPExpression expr(sourceFile.GetText());
     PHPEntityBase::Ptr_t resolved = expr.Resolve(lookup, sourceFile.GetFilename().GetFullPath());
     CHECK_BOOL(resolved);
-    
+
     PHPEntityBase::List_t matches;
     expr.Suggest(resolved, lookup, matches);
 //
@@ -617,10 +681,9 @@ TEST_FUNC(test_partial_namespace)
 // Main
 //======================-------------------------------------------------
 
-static const wxString PERFORMANCE_CODE = 
-"<?php\n"
-"$app = new \\Illuminate\\Foundation\\Application();\n"
-"$app->";
+static const wxString PERFORMANCE_CODE = "<?php\n"
+                                         "$app = new \\Illuminate\\Foundation\\Application();\n"
+                                         "$app->";
 
 int main(int argc, char** argv)
 {
