@@ -45,7 +45,7 @@
 static PhpPlugin* thePlugin = NULL;
 
 // Define the plugin entry point
-extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
     if(thePlugin == 0) {
         thePlugin = new PhpPlugin(manager);
@@ -53,17 +53,17 @@ extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
     return thePlugin;
 }
 
-extern "C" EXPORT PluginInfo GetPluginInfo()
+CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
-    PluginInfo info;
-    info.SetAuthor(wxT("The CodeLite Team"));
+    static PluginInfo info;
+    info.SetAuthor(wxT("Eran Ifrah"));
     info.SetName(wxT("PHP"));
     info.SetDescription(_("Enable PHP support for codelite IDE"));
     info.SetVersion(wxT("v1.0"));
-    return info;
+    return &info;
 }
 
-extern "C" EXPORT int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
+CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
 PhpPlugin::PhpPlugin(IManager* manager)
     : IPlugin(manager)
@@ -73,6 +73,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
     , m_xdebugLocalsView(NULL)
     , m_xdebugEvalPane(NULL)
     , m_showWelcomePage(false)
+    , m_toggleToolbar(false)
 {
     m_lint.Reset(new PHPLint(this));
 
@@ -88,7 +89,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
     PHPWorkspace::Get()->SetPluginManager(m_mgr);
     XDebugManager::Initialize(this);
 
-    BitmapLoader::RegisterImage(FileExtManager::TypeWorkspacePHP, images.Bitmap("m_bmpPhpWorkspace"));
+    // BitmapLoader::RegisterImage(FileExtManager::TypeWorkspacePHP, images.Bitmap("m_bmpPhpWorkspace"));
 
     // Add our UI
     // create tab (possibly detached)
@@ -126,9 +127,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
     EventNotifier::Get()->Connect(
         wxEVT_CMD_GET_WORKSPACE_FILES, wxCommandEventHandler(PhpPlugin::OnGetWorkspaceFiles), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
-                                  wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles),
-                                  NULL,
-                                  this);
+        wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
     EventNotifier::Get()->Connect(
         wxEVT_CMD_GET_ACTIVE_PROJECT_FILES, wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
     EventNotifier::Get()->Connect(
@@ -162,7 +161,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
         PHPConfigurationData config;
         if(!fnSampleFile.Exists() || // the sample file does not exists
                                      // Or the resource file (PHP.zip) is newer than the sample file
-           (phpResources.GetModificationTime().GetTicks() > fnSampleFile.GetModificationTime().GetTicks())) {
+            (phpResources.GetModificationTime().GetTicks() > fnSampleFile.GetModificationTime().GetTicks())) {
 
             targetDir.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
             zipReader.Extract("*", targetDir.GetPath());
@@ -250,9 +249,7 @@ void PhpPlugin::UnPlug()
     EventNotifier::Get()->Disconnect(
         wxEVT_CMD_FIND_IN_FILES_DISMISSED, clCommandEventHandler(PhpPlugin::OnFindInFilesDismissed), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
-                                     wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles),
-                                     NULL,
-                                     this);
+        wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
     EventNotifier::Get()->Disconnect(
         wxEVT_CMD_GET_ACTIVE_PROJECT_FILES, wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVED, clCommandEventHandler(PhpPlugin::OnFileSaved), NULL, this);
@@ -317,8 +314,7 @@ void PhpPlugin::OnNewWorkspace(clCommandEvent& e)
             wxFileName workspaceFile(newWspDlg.GetWorkspacePath());
             if(!workspaceFile.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL)) {
                 ::wxMessageBox(wxString::Format(_("Could not create workspace folder:\n%s"), workspaceFile.GetPath()),
-                               "CodeLite",
-                               wxICON_ERROR | wxOK | wxCENTER);
+                    "CodeLite", wxICON_ERROR | wxOK | wxCENTER);
                 return;
             }
             PHPWorkspace::Get()->Create(newWspDlg.GetWorkspacePath());
@@ -397,10 +393,8 @@ void PhpPlugin::DoOpenWorkspace(const wxString& filename, bool createIfMissing,
 
     // Open the PHP workspace
     if(!PHPWorkspace::Get()->Open(filename, createIfMissing)) {
-        wxMessageBox(_("Failed to open workspace: corrupted workspace file"),
-                     wxT("CodeLite"),
-                     wxOK | wxICON_WARNING | wxCENTER,
-                     FRAME);
+        wxMessageBox(_("Failed to open workspace: corrupted workspace file"), wxT("CodeLite"),
+            wxOK | wxICON_WARNING | wxCENTER, FRAME);
         return;
     }
 
@@ -437,10 +431,8 @@ void PhpPlugin::OnOpenResource(wxCommandEvent& e)
                 IEditor* editor = m_mgr->OpenFile(itemData->filename.GetFullPath());
                 if(editor) {
                     if(itemData->line != wxNOT_FOUND) {
-                        if(!editor->FindAndSelect(itemData->displayName,
-                                                  itemData->displayName,
-                                                  editor->PosFromLine(itemData->line),
-                                                  NULL)) {
+                        if(!editor->FindAndSelect(itemData->displayName, itemData->displayName,
+                               editor->PosFromLine(itemData->line), NULL)) {
                             editor->CenterLine(itemData->line);
                         }
                     }
@@ -537,16 +529,10 @@ void PhpPlugin::DoPlaceMenuBar(wxMenuBar* menuBar)
         menuBar->Insert(helpLoc, phpMenuBarMenu, _("P&HP"));
     }
 
-    phpMenuBarMenu->Connect(wxID_PHP_SETTINGS,
-                            wxEVT_COMMAND_MENU_SELECTED,
-                            wxCommandEventHandler(PhpPlugin::OnMenuCommand),
-                            NULL,
-                            (wxEvtHandler*)this);
-    phpMenuBarMenu->Connect(wxID_PHP_RUN_XDEBUG_DIAGNOSTICS,
-                            wxEVT_COMMAND_MENU_SELECTED,
-                            wxCommandEventHandler(PhpPlugin::OnRunXDebugDiagnostics),
-                            NULL,
-                            (wxEvtHandler*)this);
+    phpMenuBarMenu->Connect(wxID_PHP_SETTINGS, wxEVT_COMMAND_MENU_SELECTED,
+        wxCommandEventHandler(PhpPlugin::OnMenuCommand), NULL, (wxEvtHandler*)this);
+    phpMenuBarMenu->Connect(wxID_PHP_RUN_XDEBUG_DIAGNOSTICS, wxEVT_COMMAND_MENU_SELECTED,
+        wxCommandEventHandler(PhpPlugin::OnRunXDebugDiagnostics), NULL, (wxEvtHandler*)this);
 }
 
 void PhpPlugin::OnMenuCommand(wxCommandEvent& e)
@@ -620,12 +606,22 @@ void PhpPlugin::OnDebugEnded(XDebugEvent& e)
         m_mgr->GetDockingManager()->LoadPerspective(m_savedPerspective);
         m_savedPerspective.Clear();
     }
+
+    if(m_toggleToolbar) {
+        m_mgr->ShowToolBar(false);
+        m_toggleToolbar = false;
+    }
 }
 
 void PhpPlugin::OnDebugStarted(XDebugEvent& e)
 {
     e.Skip();
     DoEnsureXDebugPanesVisible();
+    m_toggleToolbar = !m_mgr->IsToolBarShown();
+    if(m_toggleToolbar) {
+        // toolbar not shown
+        m_mgr->ShowToolBar();
+    }
 }
 
 void PhpPlugin::OnXDebugDeleteAllBreakpoints(clDebugEvent& e)
@@ -775,25 +771,23 @@ void PhpPlugin::OnRunXDebugDiagnostics(wxCommandEvent& e)
 void PhpPlugin::FinalizeStartup()
 {
     // Create the debugger windows (hidden)
-    m_debuggerPane = new PHPDebugPane(EventNotifier::Get()->TopFrame());
-    m_mgr->GetDockingManager()->AddPane(m_debuggerPane,
-                                        wxAuiPaneInfo()
-                                            .Name("XDebug")
-                                            .Caption("Call Stack & Breakpoints")
-                                            .Hide()
-                                            .CloseButton()
-                                            .MaximizeButton()
-                                            .Bottom()
-                                            .Position(3));
+    wxWindow* parent = m_mgr->GetDockingManager()->GetManagedWindow();
+    m_debuggerPane = new PHPDebugPane(parent);
+    m_mgr->GetDockingManager()->AddPane(m_debuggerPane, wxAuiPaneInfo()
+                                                            .Name("XDebug")
+                                                            .Caption("Call Stack & Breakpoints")
+                                                            .Hide()
+                                                            .CloseButton()
+                                                            .MaximizeButton()
+                                                            .Bottom()
+                                                            .Position(3));
 
-    m_xdebugLocalsView = new LocalsView(EventNotifier::Get()->TopFrame());
-    m_mgr->GetDockingManager()->AddPane(
-        m_xdebugLocalsView,
+    m_xdebugLocalsView = new LocalsView(parent);
+    m_mgr->GetDockingManager()->AddPane(m_xdebugLocalsView,
         wxAuiPaneInfo().Name("XDebugLocals").Caption("Locals").Hide().CloseButton().MaximizeButton().Bottom());
 
-    m_xdebugEvalPane = new EvalPane(EventNotifier::Get()->TopFrame());
-    m_mgr->GetDockingManager()->AddPane(
-        m_xdebugEvalPane,
+    m_xdebugEvalPane = new EvalPane(parent);
+    m_mgr->GetDockingManager()->AddPane(m_xdebugEvalPane,
         wxAuiPaneInfo().Name("XDebugEval").Caption("PHP").Hide().CloseButton().MaximizeButton().Bottom().Position(2));
 
     // Check to see if the have a PHP executable setup
