@@ -22,6 +22,7 @@ PHPFileLayoutTree::PHPFileLayoutTree(wxWindow* parent, IEditor* editor, IManager
     , m_manager(manager)
 {
     MSWSetNativeTheme(this);
+    m_keyboard.reset(new clTreeKeyboardInput(this));
 }
 
 PHPFileLayoutTree::PHPFileLayoutTree(wxWindow* parent)
@@ -34,9 +35,10 @@ PHPFileLayoutTree::PHPFileLayoutTree(wxWindow* parent)
     , m_manager(NULL)
 {
     MSWSetNativeTheme(this);
+    m_keyboard.reset(new clTreeKeyboardInput(this));
 }
 
-PHPFileLayoutTree::~PHPFileLayoutTree() {}
+PHPFileLayoutTree::~PHPFileLayoutTree() { m_keyboard.reset(nullptr); }
 
 void PHPFileLayoutTree::Construct()
 {
