@@ -1,3 +1,28 @@
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+//
+// Copyright            : (C) 2015 Eran Ifrah
+// File name            : php_workspace_view.h
+//
+// -------------------------------------------------------------------------
+// A
+//              _____           _      _     _ _
+//             /  __ \         | |    | |   (_) |
+//             | /  \/ ___   __| | ___| |    _| |_ ___
+//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
+//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
+//              \____/\___/ \__,_|\___\_____/_|\__\___|
+//
+//                                                  F i l e
+//
+//    This program is free software; you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 of the License, or
+//    (at your option) any later version.
+//
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
 #ifndef __php_workspace_view__
 #define __php_workspace_view__
 
@@ -8,6 +33,7 @@
 #include "php_event.h"
 #include <cl_command_event.h>
 #include "wx_ordered_map.h"
+#include "clTreeKeyboardInput.h"
 
 class IManager;
 class ItemData;
@@ -19,6 +45,7 @@ class PHPWorkspaceView : public PHPWorkspaceViewBase
     wxOrderedMap<wxTreeItemId, bool> m_itemsToSort;
     std::map<wxString, wxTreeItemId> m_filesItems;
     std::map<wxString, wxTreeItemId> m_foldersItems;
+    clTreeKeyboardInput::Ptr_t m_keyboardHelper;
 
 private:
     enum {
@@ -43,6 +70,8 @@ protected:
     virtual void OnProjectSettings(wxCommandEvent& event);
     virtual void OnActiveProjectSettingsUI(wxUpdateUIEvent& event);
     void DoGetSelectedFiles(wxArrayString& files);
+    void DoGetSelectedFolders(wxArrayString &paths);
+    
     // Helpers
     void DoSortItems();
     wxTreeItemId DoAddFolder(const wxString& project, const wxString& path);
@@ -62,7 +91,7 @@ protected:
 #if USE_SFTP
     void DoOpenSSHAccountManager();
 #endif
-
+    
     /**
      * @brief construct the project in the tree view
      * @param projectItem
@@ -86,6 +115,7 @@ protected:
     void OnCloseWorkspace(wxCommandEvent& e);
     void OnReloadWorkspace(wxCommandEvent& e);
     void OnNewFolder(wxCommandEvent& e);
+    void OnRenameFolder(wxCommandEvent& e);
     void OnNewClass(wxCommandEvent& e);
     void OnDeleteProject(wxCommandEvent& e);
     void OnSetProjectActive(wxCommandEvent& e);
@@ -110,6 +140,7 @@ protected:
     void OnEditorChanged(wxCommandEvent& e);
     void OnFileRenamed(PHPEvent& e);
     void OnWorkspaceRenamed(PHPEvent& e);
+    void OnFindInFilesShowing(clCommandEvent& e);
     void OnToggleAutoUpload(wxCommandEvent& e);
 
     // Php parser events
