@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : gitCommitDlg.cpp
 //
 // -------------------------------------------------------------------------
@@ -30,9 +30,12 @@
 #include "gitentry.h"
 #include "lexer_configuration.h"
 #include "editor_config.h"
+#include "ColoursAndFontsManager.h"
+#include "globals.h"
 
 GitCommitDlg::GitCommitDlg(wxWindow* parent)
     : GitCommitDlgBase(parent)
+    , m_toggleChecks(false)
 {
     // read the configuration
     clConfig conf("git.conf");
@@ -41,9 +44,20 @@ GitCommitDlg::GitCommitDlg(wxWindow* parent)
 
     m_splitterInner->SetSashPosition(data.GetGitCommitDlgHSashPos());
     m_splitterMain->SetSashPosition(data.GetGitCommitDlgVSashPos());
-
-    WindowAttrManager::Load(this, wxT("GitCommitDlg"), NULL);
-    LexerConf::Ptr_t lex = EditorConfigST::Get()->GetLexer("text");
+    
+    LexerConf::Ptr_t diffLexer = ColoursAndFontsManager::Get().GetLexer("diff");
+    if(diffLexer) {
+        diffLexer->Apply(m_stcDiff);
+    }
+    
+    m_choiceRecentCommits->Append(data.GetRecentCommit());
+    if(!data.GetRecentCommit().IsEmpty()) {
+        m_choiceRecentCommits->SetSelection(0);
+    }
+    
+    SetName("GitCommitDlg");
+    WindowAttrManager::Load(this);
+    LexerConf::Ptr_t lex = ColoursAndFontsManager::Get().GetLexer("text");
     lex->Apply(m_stcCommitMessage);
 }
 
@@ -54,12 +68,14 @@ GitCommitDlg::~GitCommitDlg()
     clConfig conf("git.conf");
     GitEntry data;
     conf.ReadItem(&data);
-
+    
+    wxString message = m_stcCommitMessage->GetText();
+    data.AddRecentCommit(message);
     data.SetGitCommitDlgHSashPos(m_splitterInner->GetSashPosition());
     data.SetGitCommitDlgVSashPos(m_splitterMain->GetSashPosition());
     conf.WriteItem(&data);
 
-    WindowAttrManager::Save(this, wxT("GitCommitDlg"), NULL);
+    
 }
 
 /*******************************************************************************/
@@ -90,9 +106,9 @@ void GitCommitDlg::AppendDiff(const wxString& diff)
 
     if(m_diffMap.size() != 0) {
         std::map<wxString, wxString>::iterator it = m_diffMap.begin();
-        m_editor->SetText((*it).second);
+        m_stcDiff->SetText((*it).second);
         m_listBox->Select(0);
-        m_editor->SetReadOnly(true);
+        m_stcDiff->SetReadOnly(true);
     }
 }
 
@@ -117,9 +133,10 @@ void GitCommitDlg::OnChangeFile(wxCommandEvent& e)
 {
     int sel = m_listBox->GetSelection();
     wxString file = m_listBox->GetString(sel);
-    m_editor->SetReadOnly(false);
-    m_editor->SetText(m_diffMap[file]);
-    m_editor->SetReadOnly(true);
+    m_stcDiff->SetReadOnly(false);
+    m_stcDiff->SetText(m_diffMap[file]);
+    ::clRecalculateSTCHScrollBar(m_stcDiff);
+    m_stcDiff->SetReadOnly(true);
 }
 
 void GitCommitDlg::OnCommitOK(wxCommandEvent& event)
@@ -132,3 +149,31 @@ void GitCommitDlg::OnCommitOK(wxCommandEvent& event)
 }
 
 /*******************************************************************************/
+void GitCommitDlg::OnToggleCheckAll(wxCommandEvent& event)
+{
+    for(size_t i=0; i<m_listBox->GetCount(); ++i) {
+        m_listBox->Check(i, m_toggleChecks);
+    }
+    m_toggleChecks = !m_toggleChecks;
+}
+
+void GitCommitDlg::OnRecentCommitSelected(wxCommandEvent& event)
+{
+    m_stcCommitMessage->SetText(m_choiceRecentCommits->GetStringSelection());
+}
+void GitCommitDlg::OnClearGitCommitHistory(wxCommandEvent& event)
+{
+    clConfig conf("git.conf");
+    GitEntry data;
+    conf.ReadItem(&data);
+    
+    data.GetRecentCommit().Clear();
+    conf.WriteItem(&data);
+    
+    m_choiceRecentCommits->Clear();
+}
+
+void GitCommitDlg::OnClearGitCommitHistoryUI(wxUpdateUIEvent& event)
+{
+    event.Enable(!m_choiceRecentCommits->IsEmpty());
+}
