@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : gitCommitListDlg.h
 //
 // -------------------------------------------------------------------------
@@ -49,11 +49,17 @@ class GitCommitListDlg : public GitCommitListDlgBase
     IProcess* m_process;
     wxString m_gitPath;
     wxString m_commitList;
+    int m_skip;
+    std::map<int, wxString> m_history;
+
 protected:
+    virtual void OnNext(wxCommandEvent& event);
+    virtual void OnPrevious(wxCommandEvent& event);
+    virtual void OnPreviousUI(wxUpdateUIEvent& event);
     virtual void OnSearchCommitList(wxCommandEvent& event);
-    void DoLoadCommits(const wxString &filter);
+    void DoLoadCommits(const wxString& filter);
     bool IsMatchFilter(const wxArrayString& filters, const wxArrayString& columns);
-    
+
 public:
     GitCommitListDlg(wxWindow* parent, const wxString& workingDir, GitPlugin* git);
     ~GitCommitListDlg();
