@@ -97,7 +97,7 @@
     },
 
     getProp: function(prop) {
-      if (prop == "__proto__" || prop == "✖") return ANull;
+      if (ignoredProp(prop)) return ANull;
       var found = (this.props || (this.props = Object.create(null)))[prop];
       if (!found) {
         found = this.props[prop] = new AVal;
@@ -540,6 +540,9 @@
   var Obj = exports.Obj = function(proto, name) {
     if (!this.props) this.props = Object.create(null);
     this.proto = proto === true ? cx.protos.Object : proto;
+    if (this.proto && !(this.proto instanceof Obj)) {
+      throw new Error("bad " + Object.keys(this.proto).join())
+    }
     if (proto && !name && proto.name && !(this instanceof Fn)) {
       var match = /^(.*)\.prototype$/.exec(this.proto.name);
       if (match) name = match[1];
@@ -578,7 +581,7 @@
         if (originNode && !found.originNode) found.originNode = originNode;
         return found;
       }
-      if (prop == "__proto__" || prop == "✖") return ANull;
+      if (ignoredProp(prop)) return ANull;
       if (isInteger(prop)) prop = this.normalizeIntegerProp(prop)
 
       var av = this.maybeProps && this.maybeProps[prop];
@@ -600,7 +603,7 @@
     getProp: function(prop) {
       var found = this.hasProp(prop, true) || (this.maybeProps && this.maybeProps[prop]);
       if (found) return found;
-      if (prop == "__proto__" || prop == "✖") return ANull;
+      if (ignoredProp(prop)) return ANull;
       if (isInteger(prop)) prop = this.normalizeIntegerProp(prop)
       var av = this.ensureMaybeProps()[prop] = new AVal;
       av.propertyOf = this;
@@ -683,6 +686,11 @@
     getObjType: function() { return this; }
   });
 
+  var geckoIterators = typeof StopIteration != "undefined";
+  function ignoredProp(name) {
+    return name == "__proto__" || name == "✖" || geckoIterators && name == "__iterator__";
+  }
+
   var Fn = exports.Fn = function(name, self, args, argNames, retval, generator) {
     Obj.call(this, cx.protos.Function, name);
     this.self = self;
@@ -975,7 +983,7 @@
       return withDisabledComputing(fn, function() {
         var oldOrigin = cx.curOrigin;
         cx.curOrigin = fn.origin;
-        var scope = fn.originNode.scope
+        var scope = node.scope
         var scopeCopy = new Scope(scope.prev, scope.originNode);
         for (var v in scope.props) {
           var local = scopeCopy.defProp(v, scope.props[v].originNode);
@@ -1063,7 +1071,7 @@
     return {inner: inner, outer: outer || inner}
   }
 
-  var scopeGatherer = walk.make({
+  var scopeGatherer = exports.scopeGatherer = walk.make({
     VariablePattern: function(node, scopes) {
       if (scopes.inner) addVar(scopes.inner, node)
     },
@@ -1079,6 +1087,7 @@
       c(node.right, scope, "Expression")
     },
     Function: function(node, scope, c) {
+      if (scope.inner) throw new Error("problem at " + node.start + " " + node.type)
       var inner = node.scope = new Scope(scope, node)
       var argVals = [], argNames = []
       for (var i = 0; i < node.params.length; ++i) {
@@ -1221,7 +1230,7 @@
     return scope.hasProp(node.name) || cx.topScope.defProp(node.name, node)
   }
 
-  var inferPatternVisitor = {
+  var inferPatternVisitor = exports.inferPatternVisitor = {
     Identifier: function(node, scope, source) {
       source.propagate(ensureVar(node, scope))
     },
@@ -1319,7 +1328,7 @@
     var tuple = elements.length > 1 && elements.length < 6
     if (tuple) {
       var homogenous = true, litType
-      for (var i = 0; homogenous && i < elements.length; i++) {
+      for (var i = 0; i < elements.length; i++) {
         var elt = elements[i]
         if (!elt)
           tuple = false
@@ -1361,7 +1370,7 @@
     };
   }
 
-  var inferExprVisitor = {
+  var inferExprVisitor = exports.inferExprVisitor = {
     ArrayExpression: ret(function(node, scope) {
       return arrayLiteralType(node.elements, scope, infer)
     }),
@@ -1387,7 +1396,7 @@
       withSuper(null, waitForProto || proto, function() {
         for (var i = 0; i < node.properties.length; ++i) {
           var prop = node.properties[i], key = prop.key;
-          if (prop.value.name == "✖" || prop.key.name == "__proto__") continue;
+          if (ignoredProp(prop.key.name)) continue;
 
           var name = propName(prop, scope), target
           if (name == "<i>" || prop.kind == "set") {
@@ -1611,7 +1620,7 @@
     return init.type == "VariableDeclaration" ? init.declarations[0].id : init
   }
 
-  var inferWrapper = walk.make({
+  var inferWrapper = exports.inferWrapper = walk.make({
     Expression: function(node, scope) {
       infer(node, node.scope || scope, ANull);
     },
@@ -1828,7 +1837,7 @@
     return maybeIterator(fn, result)
   }
 
-  var typeFinder = {
+  var typeFinder = exports.typeFinder = {
     ArrayExpression: function(node, scope) {
       return arrayLiteralType(node.elements, scope, findType)
     },
@@ -1888,6 +1897,11 @@
       if (propN == "<i>") return ANull;
       return findByPropertyName(propN);
     },
+    MethodDefinition: function(node) {
+      var propN = node.key.name, obj = getThis(node.value.scope).getType();
+      if (obj) return obj.getProp(propN);
+      return ANull;
+    },
     Identifier: function(node, scope) {
       return scope.hasProp(node.name) || ANull;
     },
@@ -1993,7 +2007,7 @@
     }
   };
 
-  var findTypeFromContext = {
+  var findTypeFromContext = exports.findTypeFromContext = {
     ArrayExpression: function(parent, _, get) { return get(parent, true).getProp("<i>"); },
     ObjectExpression: function(parent, node, get) {
       for (var i = 0; i < parent.properties.length; ++i) {
@@ -2084,15 +2098,37 @@
   });
 
   exports.findPropRefs = function(ast, scope, objType, propName, f) {
+    // Find the type which owns the property in hierarchy
+    while (objType && !objType.props[propName] && !(objType.maybeProps && objType.maybeProps[propName])) {
+      objType = objType.proto;
+    }
+    if (!objType) throw new Error("Couldn't locate property in the base object type.");
+
+    function isObjTypeProto(type) {
+      // Check whether the found type has objType in its hierarchy
+      while (type && type != objType) {
+        // Ff property is overriden higher in the hierarchy, return false
+        if (type.props[propName] || (type.maybeProps && type.maybeProps[propName])) {
+          return false;
+        }
+        type = type.proto;
+      }
+      return type;
+    }
+
     walk.simple(ast, {
       MemberExpression: function(node, scope) {
         if (node.computed || node.property.name != propName) return;
-        if (findType(node.object, scope).getType() == objType) f(node.property);
+        if (isObjTypeProto(findType(node.object, scope).getType())) f(node.property, scope);
       },
       ObjectExpression: function(node, scope) {
         if (findType(node, scope).getType() != objType) return;
         for (var i = 0; i < node.properties.length; ++i)
-          if (node.properties[i].key.name == propName) f(node.properties[i].key);
+          if (node.properties[i].key.name == propName) f(node.properties[i].key, scope);
+      },
+      MethodDefinition: function(node) {
+        if (node.key.name != propName) return;
+        if (node.value && isObjTypeProto(getThis(node.value.scope).getType())) f(node.key, node.value.scope);
       }
     }, simpleWalker, scope);
   };
