@@ -29,7 +29,8 @@
     reuseInstances: true,
     stripCRs: false,
     ecmaVersion: 6,
-    projectDir: "/"
+    projectDir: "/",
+    parent: null
   };
 
   var queryTypes = {
@@ -106,6 +107,7 @@
     this.projectDir = options.projectDir.replace(/\\/g, "/")
     if (!/\/$/.test(this.projectDir)) this.projectDir += "/"
 
+    this.parent = options.parent;
     this.handlers = Object.create(null);
     this.files = [];
     this.fileMap = Object.create(null);
@@ -136,7 +138,7 @@
       if (file) {
         this.needsPurge.push(file.name);
         this.files.splice(this.files.indexOf(file), 1);
-        delete this.fileMap[name];
+        delete this.fileMap[file.name];
       }
     },
     reset: function() {
@@ -166,7 +168,7 @@
     },
 
     findFile: function(name) {
-      return this.fileMap[name];
+      return this.fileMap[this.normalizeFilename(name)];
     },
 
     flush: function(c) {
@@ -192,6 +194,14 @@
       if (this.cx) this.reset()
     },
 
+    deleteDefs: function(name) {
+      for (var i = 0; i < this.defs.length; i++) if (this.defs[i]["!name"] == name) {
+        this.defs.splice(i, 1);
+        if (this.cx) this.reset();
+        return;
+      }
+    },
+
     loadPlugin: function(name, options) {
       if (arguments.length == 1) options = this.options.plugins[name] || true
       if (name in this.plugins || !(name in plugins) || !options) return
@@ -206,7 +216,7 @@
     },
 
     normalizeFilename: function(name) {
-      var norm = this.options.normalizeFilename(name).replace(/\\/g, "//")
+      var norm = this.options.normalizeFilename(name).replace(/\\/g, "/")
       if (norm.indexOf(this.projectDir) == 0) norm = norm.slice(this.projectDir.length)
       return norm
     }
@@ -224,6 +234,7 @@
     if (files.length) ++srv.uses;
     for (var i = 0; i < files.length; ++i) {
       var file = files[i];
+      file.name = srv.normalizeFilename(file.name)
       if (file.type == "delete")
         srv.delFile(file.name);
       else
@@ -248,18 +259,18 @@
       if (queryType.fullFile && file.type == "part")
         return c("Can't run a " + query.type + " query on a file fragment");
 
-      function run() {
-        var result;
+      infer.resetGuessing()
+      infer.withContext(srv.cx, function() {
+        var result, run = function() { result = queryType.run(srv, query, file); };
         try {
-          result = queryType.run(srv, query, file);
+          if (timeBudget) infer.withTimeout(timeBudget[0], run);
+          else run();
         } catch (e) {
           if (srv.options.debug && e.name != "TernError") console.error(e.stack);
           return c(e);
         }
         c(null, result);
-      }
-      infer.resetGuessing()
-      infer.withContext(srv.cx, timeBudget ? function() { infer.withTimeout(timeBudget[0], run); } : run);
+      });
     });
   }
 
@@ -412,11 +423,11 @@
 
     var file = localFiles[isRef[1]];
     if (!file || file.type == "delete") throw ternError("Reference to unknown file " + name);
-    if (file.type == "full") return srv.findFile(file.name);
+    if (file.type == "full") return srv.fileMap[file.name];
 
     // This is a partial file
 
-    var realFile = file.backing = srv.findFile(file.name);
+    var realFile = file.backing = srv.fileMap[file.name];
     var offset = file.offset;
     if (file.offsetLines) offset = {line: file.offsetLines, ch: 0};
     file.offset = offset = resolvePos(realFile, file.offsetLines == null ? file.offset : {line: file.offsetLines, ch: 0}, true);
@@ -482,7 +493,7 @@
   function parentDepth(srv, parent) {
     var depth = 0;
     while (parent) {
-      parent = srv.findFile(parent).parent;
+      parent = srv.fileMap[parent].parent;
       ++depth;
     }
     return depth;
@@ -490,7 +501,7 @@
 
   function budgetName(srv, file) {
     for (;;) {
-      var parent = srv.findFile(file.parent);
+      var parent = srv.fileMap[file.parent];
       if (!parent.parent) break;
       file = parent;
     }
@@ -770,6 +781,19 @@
     return {completions: found};
   }
 
+  function inBody(node, pos) {
+    var body = node.body, start, end
+    if (!body) return false
+    if (Array.isArray(body)) {
+      start = body[0].start
+      end = body[body.length - 1].end
+    } else {
+      start = body.start
+      end = body.end
+    }
+    return start <= pos && end >= pos
+  }
+
   var findExpr = exports.findQueryExpr = function(file, query, wide) {
     if (query.end == null) throw ternError("missing .query.end field");
 
@@ -780,12 +804,14 @@
     } else {
       var start = query.start && resolvePos(file, query.start), end = resolvePos(file, query.end);
       var expr = infer.findExpressionAt(file.ast, start, end, file.scope);
-      if (expr) return expr;
-      expr = infer.findExpressionAround(file.ast, start, end, file.scope);
-      if (expr && (expr.node.type == "ObjectExpression" || wide ||
-                   (start == null ? end : start) - expr.node.start < 20 || expr.node.end - end < 20))
-        return expr;
-      return null;
+      if (!expr) {
+        var around = infer.findExpressionAround(file.ast, start, end, file.scope);
+        if (around && !inBody(around.node, end) &&
+            (around.node.type == "ObjectExpression" || wide ||
+             (start == null ? end : start) - around.node.start < 20 || around.node.end - end < 20))
+          expr = around
+      }
+      return expr
     }
   };
 
@@ -843,6 +869,8 @@
         exprName = expr.node.name;
       else if (expr.node.type == "MemberExpression" && !expr.node.computed)
         exprName = expr.node.property.name;
+      else if (expr.node.type == "MethodDefinition" && !expr.node.computed)
+        exprName = expr.node.key.name
     }
 
     if (query.depth != null && typeof query.depth != "number")
@@ -911,7 +939,7 @@
       target.start = query.lineCharPositions ? {line: Number(m[2]), ch: Number(m[3])} : Number(m[1]);
       target.end = query.lineCharPositions ? {line: Number(m[5]), ch: Number(m[6])} : Number(m[4]);
     } else {
-      var file = srv.findFile(span.origin);
+      var file = srv.fileMap[span.origin];
       target.start = outputPos(query, file, span.node.start);
       target.end = outputPos(query, file, span.node.end);
     }
@@ -932,7 +960,7 @@
     }
 
     if (span && span.node) { // refers to a loaded file
-      var spanFile = span.node.sourceFile || srv.findFile(span.origin);
+      var spanFile = span.node.sourceFile || srv.fileMap[span.origin];
       var start = outputPos(query, spanFile, span.node.start), end = outputPos(query, spanFile, span.node.end);
       result.start = start; result.end = end;
       result.file = span.origin;
@@ -981,17 +1009,25 @@
       infer.findRefs(scope.originNode, scope, name, scope, storeRef(file));
     } else {
       type = "global";
-      for (var i = 0; i < srv.files.length; ++i) {
-        var cur = srv.files[i];
-        infer.findRefs(cur.ast, cur.scope, name, scope, storeRef(cur));
+      if (query.onlySourceFile) {
+        infer.findRefs(file.ast, file.scope, name, scope, storeRef(file));
+      } else {
+        for (var i = 0; i < srv.files.length; ++i) {
+          var cur = srv.files[i];
+          infer.findRefs(cur.ast, cur.scope, name, scope, storeRef(cur));
+        }
       }
     }
 
     return {refs: refs, type: type, name: name};
   }
 
-  function findRefsToProperty(srv, query, expr, prop) {
-    var objType = infer.expressionType(expr).getObjType();
+  function findRefsToProperty(srv, query, sourceFile, expr, prop) {
+    var exprType = infer.expressionType(expr);
+    if (expr.node.type == "MethodDefinition") {
+      exprType = exprType.propertyOf;
+    }
+    var objType = exprType.getObjType();
     if (!objType) throw ternError("Couldn't determine type of base object.");
 
     var refs = [];
@@ -1002,9 +1038,14 @@
                    end: outputPos(query, file, node.end)});
       };
     }
-    for (var i = 0; i < srv.files.length; ++i) {
-      var cur = srv.files[i];
-      infer.findPropRefs(cur.ast, cur.scope, objType, prop.name, storeRef(cur));
+
+    if (query.onlySourceFile) {
+        infer.findPropRefs(sourceFile.ast, sourceFile.scope, objType, prop.name, storeRef(sourceFile));
+    } else {
+      for (var i = 0; i < srv.files.length; ++i) {
+        var cur = srv.files[i];
+        infer.findPropRefs(cur.ast, cur.scope, objType, prop.name, storeRef(cur));
+      }
     }
 
     return {refs: refs, name: prop.name};
@@ -1017,14 +1058,17 @@
     } else if (expr && expr.node.type == "MemberExpression" && !expr.node.computed) {
       var p = expr.node.property;
       expr.node = expr.node.object;
-      return findRefsToProperty(srv, query, expr, p);
+      return findRefsToProperty(srv, query, file, expr, p);
     } else if (expr && expr.node.type == "ObjectExpression") {
       var pos = resolvePos(file, query.end);
       for (var i = 0; i < expr.node.properties.length; ++i) {
         var k = expr.node.properties[i].key;
         if (k.start <= pos && k.end >= pos)
-          return findRefsToProperty(srv, query, expr, k);
+          return findRefsToProperty(srv, query, file, expr, k);
       }
+    } else if (expr && expr.node.type == "MethodDefinition") {
+      var p = expr.node.key;
+      return findRefsToProperty(srv, query, file, expr, p);
     }
     throw ternError("Not at a variable or property name.");
   }
@@ -1052,5 +1096,5 @@
     return {files: srv.files.map(function(f){return f.name;})};
   }
 
-  exports.version = "0.15.1";
+  exports.version = "0.17.1";
 });
