@@ -28,7 +28,6 @@ int main(int argc, char **argv)
 
 	int  max_requests(5000);
 	int  requests(0);
-	bool check_parent(false);
 	long parent_pid (0);
 	if(argc < 2){
 		printf("Usage: %s <string> [--pid]\n",    argv[0]);
@@ -47,7 +46,6 @@ int main(int argc, char **argv)
 	}
 
 	if ( argc == 3 && strcmp( argv[2], "--pid") == 0 ) {
-		check_parent = true;
 		parent_pid = atol( argv[1] );
 		printf("INFO: parent PID is set on %s\n", argv[1]);
 	}
