@@ -1,9 +1,9 @@
 #ifndef __workerthread__
 #define __workerthread__
 
+#include "network/named_pipe.h"
 #include "ethread.h"
 #include "equeue.h"
-#include "network/named_pipe.h"
 
 // ---------------------------------------------
 // parsing thread
@@ -24,9 +24,10 @@ public:
 // is alive thread
 // ---------------------------------------------
 class IsAliveThread : public eThread {
-	int m_pid;
+	int         m_pid;
+	std::string m_socket;
 public:
-	IsAliveThread(int pid) : m_pid(pid){}
+	IsAliveThread(int pid, const std::string &socketName) : m_pid(pid), m_socket(socketName) {}
 	~IsAliveThread(){}
 
 public:
