@@ -341,7 +341,7 @@ public:
     virtual void GetUserScale(double *x, double *y) const { m_pOrig->GetUserScale( x, y ); }
 
     virtual void SetLogicalScale(double x, double y) { m_pOrig->SetLogicalScale( x, y ); }
-    virtual void GetLogicalScale(double *x, double *y) { m_pOrig->GetLogicalScale( x, y ); }
+    virtual void GetLogicalScale(double *x, double *y) const { m_pOrig->GetLogicalScale( x, y ); }
 	
     virtual void SetLogicalOrigin(wxCoord x, wxCoord y) { m_pOrig->SetLogicalOrigin( x, y ); }
     virtual void DoGetLogicalOrigin(wxCoord *x, wxCoord *y) const { m_pOrig->DoGetLogicalOrigin( x, y); }
@@ -518,11 +518,12 @@ public:
 		return m_pOrig->DoGetAsBitmap( subrect );
 	}
 
-#if wxVERSION_NUMBER > 2904
-    virtual void DoDrawLines(int n, const wxPoint points[], wxCoord xoffset, wxCoord yoffset )
+#if wxVERSION_NUMBER < 2905
+    virtual void DoDrawLines(int n, wxPoint points[],
 #else
-    virtual void DoDrawLines(int n, wxPoint points[], wxCoord xoffset, wxCoord yoffset )
-#endif
+    virtual void DoDrawLines(int n, const wxPoint points[],
+#endif	
+                             wxCoord xoffset, wxCoord yoffset )
 	{
         wxPoint *updPoints = new wxPoint[n];
 
@@ -556,12 +557,13 @@ public:
 		delete [] pts;
 	}
 
-
-#if wxVERSION_NUMBER > 2904
-    virtual void DoDrawPolygon(int n, const wxPoint points[], wxCoord xoffset, wxCoord yoffset, wxPolygonFillMode fillStyle = wxODDEVEN_RULE)
+#if wxVERSION_NUMBER < 2905
+    virtual void DoDrawPolygon(int n, wxPoint points[],
 #else
-    virtual void DoDrawPolygon(int n, wxPoint points[], wxCoord xoffset, wxCoord yoffset, wxPolygonFillMode fillStyle = wxODDEVEN_RULE)
+    virtual void DoDrawPolygon(int n, const wxPoint points[],
 #endif
+                           wxCoord xoffset, wxCoord yoffset,
+                           wxPolygonFillMode fillStyle = wxODDEVEN_RULE)
 	{
         wxPoint *updPoints = new wxPoint[n];
 
@@ -576,7 +578,7 @@ public:
         delete [] updPoints;
 	}
 	
-    virtual void DoDrawPolyPolygon(int n, int count[], wxPoint points[],
+    virtual void DoDrawPolyPolygon(int n, const int count[], const wxPoint points[],
                                wxCoord xoffset, wxCoord yoffset,
                                wxPolygonFillMode fillStyle)
 	{
